/* Package main
 * Generated on 2012-05-23T16:07:31+02:00
 * /normalize.css
 * /fonts.css
 * /grille.css
 * /base.css
 * /header.css
 * /article.css
 * /partenaires.css
 * /col_droite.css
 * /ticker.css
 * /couleurs.css
 * /elections.css
 */


/* ----- start file /normalize.css ----- */
/*! normalize.css 2012-01-31T16:06 UTC - http://github.com/necolas/normalize.css */

/* =============================================================================
   HTML5 display definitions
   ========================================================================== */
/*
 * Corrects block display not defined in IE6/7/8/9 & FF3
 */
article, aside, details, figcaption, figure, footer, header, hgroup, nav, section {
    display: block;
}
/*
 * Corrects inline-block display not defined in IE6/7/8/9 & FF3
 */

audio, canvas, video {
    display: inline-block;
    *display: inline;
    *zoom: 1;
}
/*
 * Prevents modern browsers from displaying 'audio' without controls
 */
audio:not([controls]) {
    display: none;
}
/*
 * Addresses styling for 'hidden' attribute not present in IE7/8/9, FF3, S4
 * Known issue: no IE6 support
 */
[hidden] {
    display: none;
}
/* =============================================================================
   Base
   ========================================================================== */
/*
 * 1. Corrects text resizing oddly in IE6/7 when body font-size is set using em units
 *    http://clagnut.com/blog/348/#c790
 * 2. Prevents iOS text size adjust after orientation change, without disabling user zoom
 *    www.456bereastreet.com/archive/201012/controlling_text_size_in_safari_for_ios_without_disabling_user_zoom/
 */
html {
    font-size: 100%; /* 1 */
    -webkit-text-size-adjust: 100%; /* 2 */
    -ms-text-size-adjust: 100%; /* 2 */
}

/*
 * Addresses font-family inconsistency between 'textarea' and other form elements.
 */

html, button, input, select, textarea {
    font-family: sans-serif;
}
/*
 * Addresses margins handled incorrectly in IE6/7
 */
body {
    margin: 0;
}
/* =============================================================================
   Links
   ========================================================================== */
/*
 * Addresses outline displayed oddly in Chrome
 */
a:focus {
    outline: thin dotted;
}

/*
 * Improves readability when focused and also mouse hovered in all browsers
 * people.opera.com/patrickl/experiments/keyboard/test
 */
a:hover,
a:active {
    outline: 0;
}

h1, h2, h3, h4, h5, h6 {
  margin: 0;
  font-weight: bold;
}

p {-webkit-margin-before: 0; -webkit-margin-after: 0}

/*
 * Addresses styling not present in IE7/8/9, S5, Chrome
 */
abbr[title] {
    border-bottom: 1px dotted;
}
/*
 * Addresses style set to 'bolder' in FF3+, S4/5, Chrome
*/
b,  strong {
    font-weight: bold;
}

blockquote {
    margin: 1em 40px;
}
/*
 * Addresses styling not present in S5, Chrome
 */
dfn {
    font-style: italic;
}
/*
 * Addresses styling not present in IE6/7/8/9
 */
mark {
    background: #ff0;
    color: #000;
}
/*
 * Corrects font family set oddly in IE6, S4/5, Chrome
 * en.wikipedia.org/wiki/User:Davidgothberg/Test59
 */
pre, code, kbd, samp {
    font-family: monospace, serif;
    _font-family: 'courier new', monospace;
    font-size: 1em;
}
/*
 * Improves readability of pre-formatted text in all browsers
 */
pre {
    white-space: pre;
    white-space: pre-wrap;
    word-wrap: break-word;
}
/*
 * 1. Addresses CSS quotes not supported in IE6/7
 * 2. Addresses quote property not supported in S4
 */

/* 1 */
q {
    quotes: none;
}

/* 2 */
q:before,
q:after {
    content: '';
    content: none;
}

small {
    font-size: 75%;
}

/*
 * Prevents sub and sup affecting line-height in all browsers
 * gist.github.com/413930
 */

sub, sup {
    font-size: 75%;
    line-height: 0;
    position: relative;
    vertical-align: baseline;
}

sup {
    top: -0.5em;
}

sub {
    bottom: -0.25em;
}

/* =============================================================================
   Lists
   ========================================================================== */

ul, ol {
    margin: 0;
    padding: 0;
  list-style-type: none;
}

dd {
    margin: 0 0 0 40px;
}

nav ul, nav ol {
    list-style: none;
    list-style-image: none;
}

/* =============================================================================
   Embedded content
   ========================================================================== */

/*
 * 1. Removes border when inside 'a' element in IE6/7/8/9, FF3
 * 2. Improves image quality when scaled in IE7
 *    code.flickr.com/blog/2008/11/12/on-ui-quality-the-little-things-client-side-image-resizing/
 */

img {
    border: 0; /* 1 */
    -ms-interpolation-mode: bicubic; /* 2 */
}
/*
 * Corrects overflow displayed oddly in IE9
 */
svg:not(:root) {
    overflow: hidden;
}


/* =============================================================================
   Figures
   ========================================================================== */

/*
 * Addresses margin not present in IE6/7/8/9, S5, O11
 */

figure {
    margin: 0;
}

/* =============================================================================
   Forms
   ========================================================================== */
/*
 * Corrects margin displayed oddly in IE6/7
 */

form {
    margin: 0;
}

/*
 * Define consistent border, margin, and padding
 */

fieldset {
    border: 1px solid #c0c0c0;
    margin: 0 2px;
    padding: 0.35em 0.625em 0.75em;
}

/*
 * 1. Corrects color not being inherited in IE6/7/8/9
 * 2. Corrects text not wrapping in FF3
 * 3. Corrects alignment displayed oddly in IE6/7
 */

legend {
    border: 0; /* 1 */
    padding: 0;
    white-space: normal; /* 2 */
    *margin-left: -7px; /* 3 */
}

/*
 * 1. Corrects font size not being inherited in all browsers
 * 2. Addresses margins set differently in IE6/7, FF3+, S5, Chrome
 * 3. Improves appearance and consistency in all browsers
 */

button, input, select, textarea {
    font-size: 100%; /* 1 */
    margin: 0; /* 2 */
    vertical-align: baseline; /* 3 */
    *vertical-align: middle; /* 3 */
}

/*
 * Addresses FF3/4 setting line-height on 'input' using !important in the UA stylesheet
 */
button, input {
    line-height: normal; /* 1 */
}

/*
 * 1. Improves usability and consistency of cursor style between image-type 'input' and others
 * 2. Corrects inability to style clickable 'input' types in iOS
 * 3. Removes inner spacing in IE7 without affecting normal text inputs
 *    Known issue: inner spacing remains in IE6
 */
button, input[type="button"], input[type="reset"], input[type="submit"] {
    cursor: pointer; /* 1 */
    -webkit-appearance: button; /* 2 */
    *overflow: visible;  /* 3 */
}

/*
 * Re-set default cursor for disabled elements
 */
button[disabled], input[disabled] {
    cursor: default;
}

/*
 * 1. Addresses box sizing set to content-box in IE8/9
 * 2. Removes excess padding in IE8/9
 * 3. Removes excess padding in IE7
      Known issue: excess padding remains in IE6
 */
input[type="checkbox"], input[type="radio"] {
    box-sizing: border-box; /* 1 */
    padding: 0; /* 2 */
    *height: 13px; /* 3 */
    *width: 13px; /* 3 */
}

/*
 * 1. Addresses appearance set to searchfield in S5, Chrome
 * 2. Addresses box-sizing set to border-box in S5, Chrome (include -moz to future-proof)
 */
input[type="search"] {
    -webkit-appearance: textfield; /* 1 */
    -moz-box-sizing: content-box;
    -webkit-box-sizing: content-box; /* 2 */
    box-sizing: content-box;
}

/*
 * Removes inner padding and search cancel button in S5, Chrome on OS X
 */
input[type="search"]::-webkit-search-decoration,
input[type="search"]::-webkit-search-cancel-button {
    -webkit-appearance: none;
}

/*
 * Removes inner padding and border in FF3+
 * www.sitepen.com/blog/2008/05/14/the-devils-in-the-details-fixing-dojos-toolbar-buttons/
 */
button::-moz-focus-inner,
input::-moz-focus-inner {
    border: 0;
    padding: 0;
}

/*
 * 1. Removes default vertical scrollbar in IE6/7/8/9
 * 2. Improves readability and alignment in all browsers
 */
textarea {
    overflow: auto; /* 1 */
    vertical-align: top; /* 2 */
}


/* =============================================================================
   Tables
   ========================================================================== */
/*
 * Remove most spacing between table cells
 */
table {
    border-collapse: collapse;
    border-spacing: 0;
}
/* ----- start file /fonts.css ----- */
@font-face {
   font-family: 'TheSerifOffice';
   src: url('/medias/web/font/svg/TheSerifOffice-OT7_West.svgz#TheSerifOffice')format('svg');
   src: url('/medias/web/font/eot/TheSerifOffice-TT7_.eot');
   src: url('/medias/web/font/eot/TheSerifOffice-TT7_.eot?#iefix') format('embedded-opentype'),
        url('/medias/web/font/woff/TheSerifOffice-TT7_.woff') format('woff');
   font-weight: normal;
   font-style: normal;
}

@font-face {
   font-family: 'FetteEngschrift';
   src: url('/medias/web/font/eot/fetteengschrift.eot');
   src: url('/medias/web/font/eot/fetteengschrift.eot?#iefix') format('embedded-opentype'),
        url('/medias/web/font/woff/fetteengschrift.woff') format('woff');
   font-weight: normal;
   font-style: normal;

}
/*** nouvelle webfont narrow 1/03/12 ***/
.global .bloc_droit .bandeau, .global .bloc_bandeau .bandeau  {
   font-family: 'FetteEngschrift', 'Arial Narrow', sans-serif;
}


/*** titres ****/
.tt40   {
  display: block;
  font-size: 4rem;
  line-height: 105%;
  font-family: 'TheSerifOffice', georgia, serif;
  font-weight: normal;
  margin: 0 0 0.5rem;
}

.ie .tt40 {
  font-size: 40px;
  margin: 0 0 0.5px;
}

.tt32   {
  display: block;
  font-size: 3.2rem;
  line-height: 105%;
  font-family: 'TheSerifOffice', georgia, serif;
  font-weight: normal;

}

.ie .tt32 {
  font-size: 32px;
  margin: 0 0 10px;
}


.tt28   {
  display: block;
  font-size: 2.8rem;
  line-height: 105%;
  font-family: 'TheSerifOffice', georgia, serif;
  font-weight: normal;
  margin: 0 0 1rem;
}

.ie .tt28 {
  font-size: 28px;
  margin: 0 0 10px;
}

.tt26_capital {
  font-size: 2.6rem;
  line-height: 120%;
  font-family: 'FetteEngschrift', 'Arial Narrow', sans-serif;
  font-weight: normal;
  margin: 0 0 0.4rem;
   text-transform: uppercase;
}


.ie  .tt26_capital {
  font-size: 26px;
  margin: 0 0 4px;
}


.tt24  {
  display: block;
  font-size: 2.4rem;
  line-height: 105%;
  font-family: 'TheSerifOffice', georgia, serif;
  font-weight: normal;
  margin: 0 0 0.3rem;
}

.ie .tt24 {
  font-size: 24px;
  margin: 0 0 3px;
}

.tt20  {
  display: block;
  font-size: 2rem;
  line-height: 105%;
  font-family: 'TheSerifOffice', georgia, serif;
  font-weight: normal;
  padding: 0 0 0.3rem;
}

.ie .tt20 {
  font-size: 20px;
  padding: 0 0 3px;
}

.tt17, .tt17_capital {
  display: block;
  font-size: 1.7rem;
  line-height: 120%;
  font-family: 'TheSerifOffice', georgia, serif;
  font-weight: normal;
  margin: 0 0 0.4rem;
}

.tt17_capital {
   font-family: 'FetteEngschrift', 'Arial Narrow', sans-serif;
   text-transform: uppercase;
  margin: 0 0 4px;

}

.ie .tt17,.ie  .tt17_capital {
  font-size: 17px;
}

.tt15_capital {
  display: block;
  font-size: 1.5rem;
  line-height: 120%;
   font-family: 'FetteEngschrift', 'Arial Narrow', sans-serif;
  font-weight: normal;
   text-transform: uppercase;
}

.ie  .tt15_capital {
  font-size: 15px;
  margin: 0 0 4px;
}


.tt13_capital {
  display: block;
  font-size: 1.3rem;
  line-height: 120%;
  font-family: 'FetteEngschrift', 'Arial Narrow', sans-serif;
  font-weight: normal;
  margin: 0 0 0.4rem;
   text-transform: uppercase;
}

.ie  .tt13_capital {
  font-size: 13px;
  margin: 0 0 4px;
}
/**** texte ***/
.txt18 {
  font-size: 1.8rem;
  line-height: 105%;
}

.ie .txt18 {
  font-size: 18px;
}

.txt15_140, .txt15_120 {
  font-size: 1.5rem;
  line-height: 140%;
}

.ie .txt15_140  {
  font-size: 15px;
}

.txt15_120 {
  line-height: 120%;
}


.txt14_140, .txt14_120 {
  font-size: 1.4rem;
  line-height: 140%;
}

.txt14_120 {
  line-height: 120%;
}

.ie .txt14_140, .ie .txt14_120 {
  font-size: 14px;
}

.txt13_140, .txt13_120 {
  font-size: 1.3rem;
  line-height: 140%;
}

.txt13_120 {
  line-height: 120%;
}

.ie .txt13_140, .ie .txt13_120 {
  font-size: 13px;
}


.txt12{
  line-height: 120%;
  font-size: 1.2rem;
}

.ie .txt11 {
  font-size: 12px;
}

.txt11 {
  line-height: 120%;
  font-size: 1.1rem;
}

.ie .txt11 {
  font-size: 11px;
}


.txt10 {
  line-height: 120%;
  font-size: 1rem;
}

.ie .txt10 {
  font-size: 10px;
}


.txt15_120, .txt14_140, .txt14_120, .txt13_140, .txt13_120, .txt12, .txt11, .txt10 {
   font-family: arial, sans-serif;
}
/* ----- start file /grille.css ----- */
/*
  Variable Grid System.
  Learn more ~ http://www.spry-soft.com/grids/
  Based on 960 Grid System - http://960.gs/

  Licensed under GPL and MIT.
*/


/* Containers
----------------------------------------------------------------------------------------------------*/
.container_18 {
  margin: 0 13px;
  width: 974px;
}

/* Grid >> Global
----------------------------------------------------------------------------------------------------*/

.grid_1,
.grid_2,
.grid_3,
.grid_4,
.grid_5,
.grid_6,
.grid_7,
.grid_8,
.grid_9,
.grid_10,
.grid_11,
.grid_12,
.grid_13,
.grid_14,
.grid_15,
.grid_16,
.grid_17,
.grid_18 {
  box-sizing: border-box;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  display:inline;
  float: left;
  position: relative;
  margin-left: 8px;
  margin-right: 8px;
  /*overflow: hidden;*/
}

/* Grid >> Children (Alpha ~ First, Omega ~ Last)
----------------------------------------------------------------------------------------------------*/

.alpha {
  margin-left: 0;
   clear: left;
}

.omega {
  margin-right: 0;
   clear: right;
}

/* Grid >> 18 Columns
----------------------------------------------------------------------------------------------------*/

.container_18 .grid_1 {
  width:39px;
}

.container_18 .grid_2 {
  width:94px;
}

.container_18 .grid_3 {
  width:149px;
}

.container_18 .grid_4 {
  width:204px;
}

.container_18 .grid_5 {
  width:259px;
}

.container_18 .grid_6 {
  width:314px;
}

.container_18 .grid_7 {
  width:369px;
}

.container_18 .grid_8 {
  width:424px;
}

.container_18 .grid_9 {
  width:479px;
}

.container_18 .grid_10 {
  width:534px;
}

.container_18 .grid_11 {
  width:589px;
}

.container_18 .grid_12 {
  width:644px;
}

.container_18 .grid_13 {
  width:699px;
}

.container_18 .grid_14 {
  width:754px;
}

.container_18 .grid_15 {
  width:809px;
}

.container_18 .grid_16 {
  width:864px;
}

.container_18 .grid_17 {
  width:919px;
}

.container_18 .grid_18 {
  width:974px;
}



/* Prefix Extra Space >> 18 Columns
----------------------------------------------------------------------------------------------------*/

.container_18 .prefix_1 {
  padding-left:55px;
}

.container_18 .prefix_2 {
  padding-left:110px;
}

.container_18 .prefix_3 {
  padding-left:165px;
}

.container_18 .prefix_4 {
  padding-left:220px;
}

.container_18 .prefix_5 {
  padding-left:275px;
}

.container_18 .prefix_6 {
  padding-left:330px;
}

.container_18 .prefix_7 {
  padding-left:385px;
}

.container_18 .prefix_8 {
  padding-left:440px;
}

.container_18 .prefix_9 {
  padding-left:495px;
}

.container_18 .prefix_10 {
  padding-left:550px;
}

.container_18 .prefix_11 {
  padding-left:605px;
}

.container_18 .prefix_12 {
  padding-left:660px;
}

.container_18 .prefix_13 {
  padding-left:715px;
}

.container_18 .prefix_14 {
  padding-left:770px;
}

.container_18 .prefix_15 {
  padding-left:825px;
}

.container_18 .prefix_16 {
  padding-left:880px;
}

.container_18 .prefix_17 {
  padding-left:935px;
}



/* Suffix Extra Space >> 18 Columns
----------------------------------------------------------------------------------------------------*/

.container_18 .suffix_1 {
  padding-right:55px;
}

.container_18 .suffix_2 {
  padding-right:110px;
}

.container_18 .suffix_3 {
  padding-right:165px;
}

.container_18 .suffix_4 {
  padding-right:220px;
}

.container_18 .suffix_5 {
  padding-right:275px;
}

.container_18 .suffix_6 {
  padding-right:330px;
}

.container_18 .suffix_7 {
  padding-right:385px;
}

.container_18 .suffix_8 {
  padding-right:440px;
}

.container_18 .suffix_9 {
  padding-right:495px;
}

.container_18 .suffix_10 {
  padding-right:550px;
}

.container_18 .suffix_11 {
  padding-right:605px;
}

.container_18 .suffix_12 {
  padding-right:660px;
}

.container_18 .suffix_13 {
  padding-right:715px;
}

.container_18 .suffix_14 {
  padding-right:770px;
}

.container_18 .suffix_15 {
  padding-right:825px;
}

.container_18 .suffix_16 {
  padding-right:880px;
}

.container_18 .suffix_17 {
  padding-right:935px;
}



/* Push Space >> 18 Columns
----------------------------------------------------------------------------------------------------*/

.container_18 .push_1 {
  left:55px;
}

.container_18 .push_2 {
  left:110px;
}

.container_18 .push_3 {
  left:165px;
}

.container_18 .push_4 {
  left:220px;
}

.container_18 .push_5 {
  left:275px;
}

.container_18 .push_6 {
  left:330px;
}

.container_18 .push_7 {
  left:385px;
}

.container_18 .push_8 {
  left:440px;
}

.container_18 .push_9 {
  left:495px;
}

.container_18 .push_10 {
  left:550px;
}

.container_18 .push_11 {
  left:605px;
}

.container_18 .push_12 {
  left:660px;
}

.container_18 .push_13 {
  left:715px;
}

.container_18 .push_14 {
  left:770px;
}

.container_18 .push_15 {
  left:825px;
}

.container_18 .push_16 {
  left:880px;
}

.container_18 .push_17 {
  left:935px;
}



/* Pull Space >> 18 Columns
----------------------------------------------------------------------------------------------------*/

.container_18 .pull_1 {
  left:-55px;
}

.container_18 .pull_2 {
  left:-110px;
}

.container_18 .pull_3 {
  left:-165px;
}

.container_18 .pull_4 {
  left:-220px;
}

.container_18 .pull_5 {
  left:-275px;
}

.container_18 .pull_6 {
  left:-330px;
}

.container_18 .pull_7 {
  left:-385px;
}

.container_18 .pull_8 {
  left:-440px;
}

.container_18 .pull_9 {
  left:-495px;
}

.container_18 .pull_10 {
  left:-550px;
}

.container_18 .pull_11 {
  left:-605px;
}

.container_18 .pull_12 {
  left:-660px;
}

.container_18 .pull_13 {
  left:-715px;
}

.container_18 .pull_14 {
  left:-770px;
}

.container_18 .pull_15 {
  left:-825px;
}

.container_18 .pull_16 {
  left:-880px;
}

.container_18 .pull_17 {
  left:-935px;
}


/* Clear Floated Elements
----------------------------------------------------------------------------------------------------*/

/* http://sonspring.com/journal/clearing-floats */

.clear {
  clear: both;
  display: block;
  overflow: hidden;
  visibility: hidden;
  width: 0;
  height: 0;
}

/* http://perishablepress.com/press/2008/02/05/lessons-learned-concerning-the-clearfix-css-hack */

.clearfix:after {
  clear: both;
  content: ' ';
  display: block;
  font-size: 0;
  line-height: 0;
  visibility: hidden;
  width: 0;
  height: 0;
}

.clearfix {
  display: inline-block;
}

* html .clearfix {
  height: 1%;
}

.clearfix {
  display: block;
}

/* ----- start file /base.css ----- */
html {font-size: 62.5%;}

body {
  font-size: 1.3rem;
  font-size: 13px;
   line-height: 140%;
   font-family: arial, sans-serif;
  color: #16212c;
  background: #e9edf0;
}

.global {
  width: 1000px;
  margin: 0 auto;
  padding: 20px 0 10px;
  /*overflow: hidden;*/
  background: #fff;
}

/*
** EXPORTS PARTENAIRES, BLOGS, FORUMS, SPORT
*/
/* CETTE CLASS NE SERT QUE POUR LES EXPORTS PARTENAIRES ET IL DOIT EN DEMEURER AINSI
  Par ailleurs il est a noter que la norme pour les selecteurs est le "_", pas le "-". */
.lmd-header {
  position:relative;
  z-index:15;
}
.lmd-footer #bandeau_bas { display:none; } /* temp */
.lmd-header #header { margin-bottom:16px; } /* temp */
/* FIN EXPORTS PARTENAIRES */

.ombre_section, .deroule_edito, .deroule_fleuve , .une_edito{
  -webkit-box-shadow: 0 6px 6px -6px rgba(202,205,209, 1);
    -moz-box-shadow: 0 6px 6px -6px rgba(202,205,209, 1);
      box-shadow: 0 6px 6px -6px rgba(202,205,209, 1);
  padding-top: 0;
  margin-bottom: 16px;
  margin-top: 16px;
  overflow: hidden;
}

a {
  color: #003366;
  text-decoration: none;
  cursor: pointer;
}

a:hover, a:focus, a:active, .lien_focus, .flashy {
  color: #129af0;
}

.bg_fonce a {
   color: #129af0;
   opacity:0.85;
}

.bg_fonce a:hover, .bg_fonce a:focus {
   opacity:1.0;
}

.obf {
  cursor: pointer;
  color: #003366;
}

.lien_interne, .lien_interne:hover {
  color: #000000;
}

p {
  margin: 0;
}

section, article, figure {
  overflow: hidden
}

section article {
  margin: 0 0 16px 0;
}

figure img, article img, .img_bord {
  border: 1px solid #eef1f5;
  vertical-align: bottom;
}

.invisible {
  border: none;
  background: none;
}

.gras {font-weight: bold;}
.caps {text-transform: uppercase}
.centrer {text-align: center;}
.block {display: block;}
.iblock { display:inline-block; }
.adroite{float: right}
.agauche{float: left}
.cache {display: none}

.txt_droite {
  text-align: right;
}

.annotation {
   display: inline-block;
  font-size: 10px;
   line-height: 100%;
  color:#747b83;
}


.type_element, .titre_blog, .nature_edito  {
  font-size: 11px;
  font-size: 1.1rem;
  font-family: arial, sans-serif;
  font-weight: bold;
  color: #a2a9ae;
  text-transform: uppercase;
}

.type_element {
  white-space:nowrap;
}


.nature_edito {
  display: block;
  font-weight: normal;
  font-size: 16px;
  font-family: 'FetteEngschrift', 'Arial Narrow', sans-serif;
}

.titre_blog {
  display: block;
}

.bloc_bg_gris2 {
   background: #f8f9fb;
   padding: 8px 16px;
}

/**********************************************/
/*** marges ***/
/**********************************************/
.mgl5 {margin-left: 5px}
.mgr5 {margin-right: 5px}
.mgb5 {margin-bottom: 5px}
.mgt5 {margin-top: 5px}

.mgl8{ margin-left: 8px; }
.mgr8{ margin-right: 8px; }
.mgt8{ margin-top: 8px; }
.mgb8{ margin-bottom: 8px; }

.mgt10{margin-top: 10px;}
.mgb10{margin-bottom: 10px;}
.mgbt10 {margin: 10px 0}

.mgl16 {margin-left: 16px;}
.mgr16 {margin-right: 16px;}
.mgt16 {margin-top: 16px;}
.mgb16 {margin-bottom: 16px;}
.mgy16 {margin-bottom:16px; margin-top:16px;}

.mgt32 {margin-top: 32px;}
.mgb32 {margin-bottom: 32px;}

.mgb20 {margin-bottom: 20px}
.mgt20 {margin-top: 20px}

.padt8 {padding-top: 8px;}
.padb8 {padding-bottom: 8px;}

.pad_right10 {padding-right: 10px;}
.pad_bot10 {padding-bottom: 10px;}

.padb16 {padding-bottom: 16px;}

.padlr16 {
  padding-left: 16px;
  padding-right: 16px;
}

.pad_top20 { padding-top:20px; }


/*** bordures ***/
.bord_top6_gris{
  border-top: 6px solid #e9edf0;
  padding-top: 16px;
}
.bord_bot6_gris{
  border-bottom: 6px solid #e9edf0;
}
.bord_bot6_gris{
  border-bottom: 6px solid #e9edf0;
}

.bord_top3_gris{
  border-top: 3px solid #e9edf0;
  padding-top: 15px;
}

.bord_top3_politique{
  border-top: 3px solid #1f0d67;
}

.bord_bot3_gris{
  border-bottom: 3px solid #e9edf0;
}

.bord1_gris {
  border: solid 1px #eef1f5;
}

.bord_lrb1_gris_clair {
   border-left: 1px solid #eef1f5;
   border-right: 1px solid #eef1f5;
   border-bottom: 1px solid #eef1f5;
}

.bord_top1_gris{
  border-top: 1px solid #e9edf0;
  padding-top: 10px;
}

.bord_bot1_gris{
  border-bottom: 1px solid #e9edf0;
  padding-bottom: 10px;
}

 .bord_double_gris_blanc {
   display: inline-block;
   line-height: 25px;
   font-size: 12px;
   border: solid #d2d6db;
   border-width: 1px 0;
}

.bord_double_gris_blanc span {
   display: inline-block;
   border: solid #fff;
   border-width: 1px 0;
}

.bord1_gris_clair {
   border: 1px solid #eef1f5;
}

/*double bordure type OU du bloc recherche */
.bord_double_gris_blanc {
   display: inline-block; border: solid #d2d6db; border-width: 1px 0;
}

.bord_double_gris_blanc span {
   display: inline-block; border: solid #fff; border-width: 1px 0;
}

.bloc_abo {
  border-top: 3px solid #ffd500
}



img[width="642"] {
  margin-bottom: 6px;
}

img[width="312"] {
  margin-bottom: 6px;
}


img[width="202"] {
  margin-bottom: 4px;
}


/**********************************************/
/*** boutons ***/
/**********************************************/
.btn, .btn_fonce, .btn_abo, .btn_petit {
display: inline-block;
padding: 4px 10px 4px;
margin-bottom: 0;
color: #000b15;
text-align: center;
font-weight: bold;
/*text-shadow: 0 1px 1px rgba(20, 20, 20, 0.5);*/
vertical-align: middle;
background-color: #f5f5f5;
background-image: -moz-linear-gradient(top, #ffffff, #e6e6e6);
background-image: -ms-linear-gradient(top, #ffffff, #e6e6e6);
background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#ffffff), to(#e6e6e6));
background-image: -webkit-linear-gradient(top, #ffffff, #e6e6e6);
background-image: -o-linear-gradient(top, #ffffff, #e6e6e6);
background-image: linear-gradient(top, #ffffff, #e6e6e6);
background-repeat: repeat-x;
filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffff', endColorstr='#e6e6e6', GradientType=0);
border-color: #e6e6e6 #e6e6e6 #bfbfbf;
border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
filter: progid:dximagetransform.microsoft.gradient(enabled=false);
border: 1px solid #cccccc;
border-bottom-color: #b3b3b3;
-webkit-border-radius: 4px;
-moz-border-radius: 4px;
border-radius: 4px;
-webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
-moz-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
cursor: pointer;
}


.btn_fonce, .bt_fonce a {
color: #fff;
background-color: #000b15;
background-image: -moz-linear-gradient(top, #5d666d, #000b15);
background-image: -ms-linear-gradient(top, #5d666d, #000b15);
background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#5d666d), to(#000b15));
background-image: -webkit-linear-gradient(top, #5d666d, #000b15);
background-image: -o-linear-gradient(top, #5d666d, #000b15);
background-image: linear-gradient(top, #5d666d, #000b15);
background-repeat: repeat-x;
filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#5d666d', endColorstr='#000b15', GradientType=0);
border-color: #000b15;
border-color: rgba(0, 0, 0, 0.1);
filter: progid:dximagetransform.microsoft.gradient(enabled=false);
}


.btn_abo{
color: #000b15;
background-color: #ffc600;
background-image: -moz-linear-gradient(top, #ffe562, #ffc600);
background-image: -ms-linear-gradient(top, #ffe562, #ffc600);
background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#ffe562), to(#ffc600));
background-image: -webkit-linear-gradient(top, #ffe562, #ffc600);
background-image: -o-linear-gradient(top, #ffe562, #ffc600);
background-image: linear-gradient(top, #ffe562, #ffc600);
background-repeat: repeat-x;
filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffe562', endColorstr='#ffc600', GradientType=0);
border-color: #ffc600;
border-color: rgba(0, 0, 0, 0.1);
filter: progid:dximagetransform.microsoft.gradient(enabled=false);
}

.btn.large {
  width: 100%;
  box-sizing: border-box;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
}

.btn_petit {
padding: 2px 4px;
font-size: 11px;
line-height: 16px;
}

.btn:hover, .btn_fonce:hover, .btn_abo:hover, .btn_petit:hover {
text-decoration: none;
background-position: 0 -15px;
-webkit-transition: background-position 0.1s linear;
-moz-transition: background-position 0.1s linear;
-ms-transition: background-position 0.1s linear;
-o-transition: background-position 0.1s linear;
transition: background-position 0.1s linear;
}

.btn:hover, .btn_petit:hover {
color: #2e3942;
background-color: #e6e6e6;
}


.btn:active, .btn.active, .btn.disabled, .btn.disabled:hover, input[type="submit"].disabled,  .btn[disabled], .btn_petit:active ,.btn_petit.active ,.btn_petit[disabled]  {
background-color: #e6e6e6;
color: #d2d6db;
}

input[type="submit"].disabled, .btn.disabled:hover{
  background-image: none;
  background-color: #e6e6e6;
  cursor: default;
}

.btn_fonce:hover, .btn_fonce:active, .btn_fonce.active, .btn_fonce.disabled, .btn_fonce[disabled] {
  color: #fff;
  background-color: #16212c;
}

.btn_abo:hover, .btn_abo:active, .btn_abo.active, .btn_abo.disabled, .btn_abo[disabled] {
color: #2e3942;
background-color: #ffc600;
}

.btn:focus {
outline: thin dotted #333;
outline: 5px auto -webkit-focus-ring-color;
outline-offset: -2px;
}

.btn:active, .btn_fonce:active, .btn_abo:active, .btn_petit:active {
background-image: none;
-webkit-box-shadow: inset 0 2px 4px rgba(0, 0, 0, 0.15), 0 1px 2px rgba(0, 0, 0, 0.05);
-moz-box-shadow: inset 0 2px 4px rgba(0, 0, 0, 0.15), 0 1px 2px rgba(0, 0, 0, 0.05);
box-shadow: inset 0 2px 4px rgba(0, 0, 0, 0.15), 0 1px 2px rgba(0, 0, 0, 0.05);
outline: 0;
}

.btn:active, .btn_petit:active {
  background-color: #e6e6e6;
}

.btn_fonce:active {
  background-color: #000b15;
}


.btn_abo:active {
  background-color: #ffc600;
}

input.btn, input.btn_petit,  input.btn_abo, input.btn_fonce {
  -webkit-box-sizing:content-box;
    -moz-box-sizing:content-box;
      box-sizing:content-box;
}


button::-moz-focus-inner, input[type="submit"]::-moz-focus-inner {
padding: 0;
border: 0;
}


input[type="submit"].btn_petit {
*padding-top: 3px;
*padding-bottom: 3px;
}

.bt_abo {
  display: inline-block;
  padding: 3px 12px;
  background: #ffd500;
  color: #000;
  font-weight: bold;
  color: #665500;
}

.bt_abo:hover{
  background: #ffc600;
  color: #000;
  font-weight: bold;
  cursor: pointer;
  text-decoration: none;
}

.titre_bt_fleche {
  display: inline-block;
  overflow: hidden;
  background: #f5f8f9;
}

.titre_bt_fleche:hover {
  background: #e9edf0;
}

.titre_bt_fleche .bt {
  position: relative;
  display: block;
  float: right;
  width: 42px;
  border-left: 1px solid #e4e6e9;
  background-color: #e9edf0;
  min-height: 64px;
}

.titre_bt_fleche .fleche  {
  position: absolute;
  right: 13px;
  top: 33%;
  background: url('/medias/web/img/sprites/icos_petites.png') no-repeat -1px -108px;
  width: 13px;
  height: 22px;
}

.titre_bt_fleche:hover .fleche  {
  background-position: -15px -108px;
}

.titre_bt_fleche .titre, .titre_bt_fleche  img {
  float: left;
}

.titre_bt_fleche  img {
  margin: 0;
}

.titre_bt_fleche .titre {
  padding: 6px 0 8px;
  width: 50%;
  font-weight: bold;
  margin-left:9px;
}
/**********************************************/
/*** pictos***/
/**********************************************/
.fb20x20, .tw20x20, .google20x20, .mobile20x20, .rss20x20 {
  background: url('/medias/web/img/sprites/pictos20x20.png') no-repeat;
  display: inline-block;
  text-indent: -9999px;
  height: 20px;
  width: 20px;
  vertical-align: middle;
  margin-left:4px;
}
* + html .fb20x20, * + html .tw20x20, * + html .google20x20, * + html .mobile20x20, * + html .rss20x20 { display:inline; }

.fb20x20 {background-position: 0 -40px}
.fb20x20:hover  {background-position: 0 -60px;}
.tw20x20 {background-position: 0 -80px;}
.tw20x20:hover {background-position: 0 -100px;}
.google20x20 {background-position:0 -120px;}
.google20x20:hover {background-position: 0 -140px;}
.mobile20x20 {background-position: 0 -160px;}
.mobile20x20:hover {background-position: 0 -180px;}
.rss20x20 {background-position: 0 -200px;}
.rss20x20:hover {background-position: 0 -220px;}

.nl{
  color: #747b83;
  font-weight: bold;
}
.nl span{
  display: inline-block;
  width: 20px;
  height: 20px;
  margin: 0 0 0 5px;
  line-height: 20px;
  background: url('/medias/web/img/sprites/pictos20x20.png') no-repeat;
}

.nl:hover  span{
  background-position: right -20px;
}


.fb13x13, .tw13x13, .google13x13, .linkedin13x13, .fb13x13_gris, .tw13x13_gris, .fb13x13_blanc, .tw13x13_blanc, .google13x13_blanc, .linkedin13x13_blanc, .tw_bird ,
.nb_reactions .pic, .nb_commentaires .pic, .lien_externe span, .bt_ouvrir, .bt_ouvrir:hover, .bt_fermer, .ico_annee_en_france,
.croix_blanche, .croix_grise, .nl_blanc {
  background: url('/medias/web/img/sprites/icos_petites.png') no-repeat;
  display: inline-block;
  text-indent: -9999px;
  height: 13px;
  width: 13px;
  /* vertical-align: text-top; */
  cursor:pointer;
}

.tw_bird {
  cursor:default;
}

.fb13x13, .tw13x13, .google13x13, .linkedin13x13, .fb13x13_gris, .tw13x13_gris, .fb13x13_blanc, .tw13x13_blanc, .google13x13_blanc, .linkedin13x13_blanc {
   margin:0 2px;
   vertical-align: middle;
}

.fb13x13, .fb13x13_gris {background-position: 0 -38px;}
.fb13x13_gris {background-position: 0 -94px;}
.fb13x13_blanc {background-position: 0 -202px;}
.fb13x13:hover, .fb13x13_gris:hover, .fb13x13_blanc:hover  {background-position: -14px -38px;}
.tw13x13{background-position: 0 -52px;}
.tw13x13_gris {background-position: -14px -94px;}
.tw13x13_blanc {background-position: -14px -202px;}
.tw13x13:hover, .tw13x13_gris:hover, .tw13x13_blanc:hover  {background-position: -14px -52px;}
.google13x13 {background-position: 0 -66px;}
.google13x13_blanc {background-position: 0 -216px;}
.google13x13:hover, .google13x13_blanc:hover {background-position: -14px -66px;}
.linkedin13x13 {background-position: 0 -80px;}
.linkedin13x13_blanc {background-position: -14px -216px;}
.linkedin13x13:hover, .linkedin13x13_blanc:hover {background-position: -14px -80px;}
.tw_bird {
  width: 15px;
  height: 11px;
  vertical-align: middle;
  background-position: -14px -131px;
}

.nb_reactions, span.nb_reactions {
  font-size: 10px;
  font-weight: bold;
  font-family: arial, sans-serif;
  color: #a2a9ae;
  vertical-align: 5%;
  white-space: nowrap;
}
/*** nb_commentaires est specifiques a la page accueil abonnes ***/
.nb_reactions .pic, .nb_commentaires .pic {
  vertical-align: text-bottom;
  margin: 0 3px 0 0;
  width: 12px;
  height: 11px;
  background-position: -13px 0;
}

.lien_externe {
  color: #5d666d;
  font-size: 11px;
}

.lien_externe span {
  width: 13px;
  height: 10px;
  margin: 0 3px 0 5px ;
  background-position: 0 -131px;
}

.az {
  float: right;
  padding: 10px 3px 10px 10px;
  width: 28px;
  height: 15px;
  border-left: 1px solid #e4e6e9;
  font-size: 12px;
  line-height: 12px;
  font-weight: bold;
}

.az:hover {
  background: #a2a9ae;
  cursor: pointer;
}

.bt_ouvrir, .bt_fermer, .bt_ouvrir:hover, .bt_fermer:hover    {
   width: 16px;
  height: 14px;
}

.bt_ouvrir  {background-position: 0 -158px;}
.bt_ouvrir:hover, .az:hover .bt_ouvrir, .conteneur_alterne_bt:hover .bt_ouvrir  {background-position: -17px -158px;}
.bt_fermer  {background-position: -17px -143px;}
.bt_fermer:hover, .az:hover .bt_fermer, .conteneur_alterne_bt:hover .bt_fermer  {background-position: -34px -143px;}


.picto_lien  {
  display: inline-block;
  width: 12px;
  height: 13px;
  margin: 0 5px 0 0;
  background: url('/medias/web/img/sprites/icos_petites.png') no-repeat 0 -142px;
  vertical-align: middle;
}

.croix_blanche {
  background-position: 0 -191px;
  width: 10px;
  height: 10px;
  vertical-align: baseline;
}

.croix_grise {
  width:10px;
  height:10px;
   margin-bottom:-0.1rem;
  background-position:-11px -191px;
  cursor: pointer;
}

.ico_annee_en_france   {
  margin: 0 7px 0 0;
  width: 16px;
  height: 17px;
  background-position: 0 -173px;
}

.nl_blanc {
   background-position:-26px -25px;
   width: 14px;
  height: 10px;
}

.education .nl_blanc_bg {
   padding: 2px 3px 1px;
   border-radius: 2px;
   line-height: 10px;
}/** couleur definie dans culeurs.css pour theme ***/

.bloc_droit .bandeau .ico_annee_en_france {
   vertical-align: text-top;
}


/*** partagez plus icones sociales sur une ligne ***/
.partage_ligne .intitule {
   display: inline-block;
   color: #747b83;
   font-weight: bold;
}

/*** filet gris avec carre bg gris + blanc ***/
.filet_plus {
   border-top: 1px solid #e9edf0;
   font-size: 16px;
   line-height: 1px;
   margin: 20px 0;
   font-weight: bold;
   text-align: center;
}

.filet_plus .bg_plus {
   background: #b9c0c5;
   padding: 0 5px;
}

.filet_plus .plus {
   color: #fff;
}

/**********************************************/
/*** pictos Abonnes***/
/**********************************************/
.pic_debrief_abo {
  display: inline-block;
  margin: 0 8px 0 0;
  vertical-align: text-bottom;
  width: 24px;
  height: 24px;
  background: url('/medias/web/img/sprites/pictos_abos.png') no-repeat 0 -24px;
}

.pic_commentes_abo {
  display: inline-block;
  margin: 0 8px 0 0;
  vertical-align: text-bottom;
  height: 23px;
  width: 32px;
  background: url('/medias/web/img/sprites/pictos_abos.png') no-repeat 0 0;
}

/**********************************************/
/*** listes ***/
/**********************************************/
.liste_bordure li {
  padding: 8px 16px 6px;
  border-bottom: 1px solid #eef1f5;
}

.liste_chevron {
  display: block;
  padding: 0 0 0 10px;
  position: relative;
}

.chevron {
  display: inline-block;
}

.liste_chevron a:before, .liste_chevron .obf:before, .chevron:before  {
  color: #a2a9ae;
  content: '\203A';
  font-family: arial;
  display: inline-block;
  font-size: 13px;
  left: 0;
  position: relative;
  width: 7px;
  font-weight: normal;
}

.liste_chevron a:before, .liste_chevron span:before {
   position: absolute;
}

.chevron_en_dur {
  display: inline-block;
  font-weight: normal;
  color: #a2a9ae;
  width: 5px;
}


.bull:before, .square:before {
  content: '\25A0';
  color: #d2d6db;
  position: relative;
  bottom: 0.2em;
  margin-right: 0.5em;
  font-size: 1.2rem;
}

/*** carres gris ***/
.liste_carre_999 {
  color: #d2d6db;
  padding: 0 0 0 14px;
}

.liste_carre_999 li {
  list-style-type: square;
}

.une_revolutionnaire .liste_carre_999 {
  padding: 0 0 16px 14px;
  overflow: hidden;
}

.une_revolutionnaire .liste_carre_999 li  {
  float: left;
  width: 298px;
  padding: 0 32px 0 0;
}


.une_revolutionnaire .liste_carre_999 li:last-child {
  width: 280px;
  padding: 0;
}

.liste_carre_999 span {
  color: #000b15;
}

.liste_carre_999.liste_une {
  overflow: hidden;
  margin: 10px 0;
  padding: 0 0 0 15px;
}

.liste_carre_999.liste_une  li {
  float: left;
  width: 45%;
  margin: 0 0 10px;
}

.liste_carre_999.liste_une  li:nth-child(2n+2) {
  width: 48%;
  float: right;
}

.liste_carre_999.liste_une  li:nth-child(2n+3) {
  clear:left;
}

.ie .une_normale  .liste_carre_999.liste_une   .ie_pair {float: right; width: 48%;}
.ie .une_normale  .liste_carre_999.liste_une   .ie_impair {clear:left;}


article .liste_carre_999 {
  margin-top: 5px;
}

/*** liste horaire ***/

.liste_horaire li:first-child {
  border-top: 0 none;
}

.liste_horaire li {
  border-top: 1px solid #eef1f5;
  overflow: hidden;
  padding: 10px 15px;
}

.liste_horaire .heure {
  color: #2e3942;
  float: left;
  font-size: 11px;
  height: 14px;
  line-height: 15px;
  width: 40px;
}

.liste_horaire .texte {
  float: left;
  width: 240px;
}

.liste_horaire.bloc_simple .texte {
   float:left;
   width: 282px;
}

.liste_horaire.bloc_simple.liste_scroll .texte {
   width:265px;
}

.liste_horaire.liste_img_lien figure {
   margin:0;
}

.liste_horaire.liste_img_lien figcaption {
   font-weight:normal;
}

.liste_horaire.liste_scroll {
   overflow-y:scroll;
}

/*** presentations de textes, liens... ***/
.reco_article {
   font-size: 1.1rem;
   line-height: 18px;
   display: block;
   color: #fff;
}

.ie .reco_article {font-size: 11px;}

.reco_article .entete {
   display: inline-block;
   background: #ff6e17;
   padding: 0 3px;
}

.deroule_edito.culture .liste_horaire.liste_scroll {
   height:249px;
}

.deroule_edito.politique .liste_horaire  {
  height:507px;
  overflow-y:scroll;
  line-height: 120%;
}

.deroule_edito.politique .liste_horaire a {
  width: 225px;
}

/*** images+titres / images + titres + chapeau ***/
.titre_une {
  margin: 0 0 10px 0;
}

.titre_une figcaption {
  margin: 5px 0 0 0;
}

.titres_abonnes {
  overflow: hidden;
  background: #f8f9fb;
  border-bottom: 6px solid #e9edf0;
}


.titres_abonnes .entete, .entete_exclu_abonnes{
  display: block;
  height: 19px;
  background: #ffd500 url('/medias/web/img/elements_lm/ea_contenu_exclusif.png') no-repeat 8px 4px;
  font-size: 13px;
  text-indent: -9999px;
}

.titres_abonnes .ligne1, .titres_abonnes .ligne2{
  padding: 15px 0 10px;
  overflow: hidden;
}

.titres_abonnes .ligne2{
  border-top: 1px solid #d5d9de;
}

.titres_abonnes .conteneur_bt {
  clear: both;
  padding: 15px 0;
  text-align: center;
}

.titres_abonnes .grid_6 {
  padding: 0 10px;
}

.titres_abonnes img {
  margin-left: -10px;
}

.img_tt_chapo {
  margin-bottom: 16px;
  overflow: hidden;
}

.img_tt_chapo figcaption {
  padding: 10px 0 4px;
}

.liste_img_lien figure {
  margin-bottom: 16px;
  height: 64px;
}

.liste_img_lien img, .liste_img_lien .img_ico {
  float: left;
  margin-right: 8px;
}

.liste_img_lien figcaption {
  display: block;
  height: 63px;
  overflow: hidden;
  font-weight: bold;
}

/**** hauteurs limites ***/
.limite120  {
  height: 120px;
  overflow: hidden;
}

.limite133 {
  height: 133px;
  overflow: hidden;
}

.limite133.bord_bot3_gris div  {
  height: 123px;
  overflow: hidden;
}

.limite160 {
  height: 160px;
  overflow: hidden;
}

.limite210 {
  height: 210px;
  overflow: hidden;
}

.limite281-3{
  height: 278px;
  overflow: hidden;
}



.limite38 {
  height: 50px;
  overflow: hidden;
}


/***  haut de une / deroule ***/
.une_edito {
  padding: 20px 0 10px;
  margin-top: 0;
}

/*** titres de sections deroule ***/
.global .entete_deroule {
  display: block;
  padding: 6px 0;
  margin: 0 0 16px;
  border-bottom: 1px solid #eef1f5;
  text-align: center;
  color: #a2a9ae;
}

.global a.entete_deroule:hover, .global .entete_deroule.obf:hover {
  background: #f5f8f9;
  color: #16212c;
  cursor: pointer;
}

/*** cols droites sections home/rubrique ***/
.global .bloc_droit, .global .bloc_bandeau {
  border: 1px solid #eef1f5;
  overflow: hidden;
  background: #fafbfc;
}

.global .bloc_droit strong {
  display: block;
  height: 31px;
  overflow: hidden;
}

.global .bloc_droit+.bloc_droit {
  margin: 16px 0 0;
}

/*** supplement partenaire ***/
.global .supplement_partenaire, .col_droite .supplement_partenaire {
  margin-top: 16px;
  overflow: hidden;
  border: 1px solid #e9edf0;
  color: #5d666d;
}

.global .supplement_partenaire .entete, .col_droite .supplement_partenaire.entete  {
  height: 25px;
  padding: 0 16px;
  border-bottom: 1px solid #e9edf0;
  font-size: 13px;
  line-height: 24px;
  font-weight: bold;
}

.global .supplement_partenaire .entete .marqueur_pub, .col_droite .supplement_partenaire.entete .marqueur_pub  {
  float: right;
  display: inline-block;
  width: 43px;
  height: 5px;
  margin-top: 10px;
  background: url('/medias/web/img/textes/marqueur_pub_gris43x5.png');
  text-indent: -9999px;
  font-size: 9px;
  text-transform: uppercase;
}

.global .supplement_partenaire .contenu, .col_droite .supplement_partenaire .contenu {
  overflow: hidden;
  padding: 16px 15px;
}

.global .supplement_partenaire .contenu {
  height: 66px;
}

.global .supplement_partenaire .contenu .img, .col_droite .supplement_partenaire .contenu .img  {
  float: left;
  width: 63px;
}

.global .supplement_partenaire .contenu .img img, .col_droite .supplement_partenaire .contenu .img img  {
  border: 1px solid #eef1f5;
}

.global .supplement_partenaire .contenu .annonce, .col_droite .supplement_partenaire .contenu .annonce  {
  float: left;
  margin-left: 10px;
  width: 209px;
}

.global .supplement_partenaire, .col_droite .supplement_partenaire .annonce .accroche {
  display: block;
  margin-bottom: 5px;
  font-weight: bold;
}


.global.economie .bloc_droit, .global.international.bloc_droit  {
  /*height: 223px*/
}


.global .bloc_droit .bandeau, .global .bloc_bandeau .bandeau {
  padding: 0 16px;
  margin: 0;
  font-size: 17px;
  line-height: 26px;
  color: #fff;
  text-transform: uppercase;

}

/*** verifier si encore utile ***/
.global .bloc_droit .titre {
  display: block;
  background: url('/medias/web/img/textes/blog_expert.png') no-repeat;
  text-indent: -99999px;
}

.global .bloc_droit .contenu_droit {
  padding: 18px 14px 10px;
  overflow: hidden;
}

.global .bloc_droit .entree, .global .bloc_droit .entree.auto {
  height: 46px;
  padding: 7px 14px 10px;
  overflow: hidden;
  border-top: 1px solid #e9edf0;
}

.global .bloc_droit .entree.auto, .global .bloc_droit .entree.presidentielle {
  height: auto;
  font-weight: bold;
}

.global .bloc_droit .nature_edito, .global .bloc_droit .type {
  display: block;
}


.global .bloc_droit .entree:first-child {
  border-top: 0;
}

.global.bloc_groupe {
  padding-bottom: 0;
}

.global.bloc_groupe a {
  font-weight: bold;
}

.global.bloc_groupe .entete_deroule {
  margin: 0;
  border-bottom: 1px solid #b9c0c5;
}

.global.bloc_groupe .logo{
  overflow: hidden;
  clear:left;
  display: block;
  height: 31px;
  line-height: 31px;
  background: #f1f5f8;
}

.global.bloc_groupe .logo a {
  display: inline-block;
  vertical-align: middle;
}

.global.bloc_groupe div {
  width: 332px;
  float: left;
  border-right: 1px solid #fff;
  border-left: 1px solid #e4e6e9;
}

.ie .global.bloc_groupe div {
  width: 331px
}

.ie .global.bloc_groupe div:first-child {
  width: 333px
}

.global.bloc_groupe div p, .global.bloc_groupe div figure {
  padding: 10px 16px 6px;
  margin: 0;
}

.global.bloc_groupe  .entete_deroule + div{
  border-left: 0;
}

.global.bloc_groupe div:last-child {
  border-right: 0;
}

.global.videos .grid_6{
  padding-bottom: 16px;
}

.global.videos .grid_6 > a {
  display: block;
}

.global.revue_web {
  padding: 0;
  font-weight: bold;
}

.global.revue_web .entete {
  display: block;
  height: 80px;
  background: url('/medias/web/img/habillage/bandeau_revue_web.png') no-repeat;
}

.global.revue_web .entete a {
  display: inline-block;
  width: 335px;
  height: 80px;
  text-indent: -9999px;
}

.global.revue_web .entete a:first-child {
  width: 664px;
}

.global.revue_web .big_brother {
  display: table-cell;
  float: left;
  width: 664px;
  padding-bottom: 10px;
}

.global.revue_web .big_brother div {
  width: 314px;
  height: 234px;
  float: left;
  padding: 16px 0 0 13px;
}

.global.revue_web .big_brother div+div {
  float: right;
  padding: 16px 13px 0 0;
}

.global.revue_web .bg {
  clear: both;
  height: 130px;
  padding: 8px 10px 6px;
  background: #fafbfc;
}

.global.revue_web .vidberg {
  display: table-cell;
  width: 335px;
  border-left: 1px solid #eef1f5;
  padding-bottom: 10px;
}

.global.revue_web .vidberg ul {
  height: 253px
}

.global.revue_web .vidberg li {
  height: 33px
}

.global.revue_web .vidberg li:last-child {
  border-bottom: 0;
}

.global.debats .entete_deroule {
  margin: 0;
}

.global.debats .bg {
  padding: 13px 0;
  background: #f8f9fb;
  border-bottom: 1px solid #eef1f5;
  overflow: hidden;
}

.global.debats .nature_edito {
  margin: 0 0 5px 0;
}

.global.debats .tt17_capital {
  margin: 0 0 16px;
  padding: 4px 0 4px;
  border-bottom: 1px solid #e9edf0;
  color: #000;
}

/**** lien bas paves deroules ***/
.lien_chaine,.deroule_edito .liens_bas {
  width: 100%;
  clear: both;
  padding: 6px 0 0;
  margin: -3px 0 0;
  border-top: 1px solid #eef1f5;
  text-align: center;

}

.lien_chaine.lien_chaine_sans_bordure {
  border-top:0 !important;
}

.lien_chaine a, .lien_chaine span {
  color: #8b9299;
  font-weight: bold;
  font-size: 14px;
  font-size: 1.4rem;
}

.lien_chaine a:hover, .lien_chaine span:hover {
  text-decoration: underline;
}


.deroule_edito .liens_bas {
  padding: 6px 0;
  color: #d2d6db;
}

/**********************************************/
/*** Bloc dÃ©roulÃ© audience ***/
/**********************************************/
.global.audience .container {
  overflow:hidden;
  height:176px;
}
.global.audience .container>div {
  float:left;
  margin-left:16px;
}
.global.audience .container>div:first-child {
  margin-left:0;
}

/*** opacite hover audience et footer serviciel */
.global.audience .container img:hover, #carousel_footer_serviciel img:hover{
  opacity: 0.7;
  -ms-filter:"progid:DXImageTransform.Microsoft.Alpha(Opacity=70)";
}

/**********************************************/
/*** Bloc supplement partenaire (hors grille) ***/
/**********************************************/
.global.supp_partenaires  {

}
.global.supp_partenaires .entete_deroule {
  padding: 6px 16px;
  margin-bottom: 0;
  text-align: left;
  font-weight: bold;
  font-size: 16px;
  font-family: arial, sans serif;
}

.global.supp_partenaires .entete_deroule .logo {
  float:right;
  padding-left: 40px;
  background: url('/medias/web/img/textes/marqueur_pub_gris43x5.png') 0 12px no-repeat;
}

.global.supp_partenaires .position_pub div {
  float: left;
  width: 301px;
  padding: 16px 12px 16px 16px;
  line-height: 140%;
}

.global.supp_partenaires .position_pub div ~ div {
  width: 285px;
}

.global.supp_partenaires .position_pub div ~ div ~ div  {
  width: 330px;
}

.global.supp_partenaires .position_pub div p+p {
  width: 174px;
  float: left;
}

.global.supp_partenaires .conteneur_img {
  float: left;
  margin: 0 16px 0 0;
}

.global.supp_partenaires img  {
  border: 1px solid #eef1f5;
}

.global.supp_partenaires a {
  font-weight: bold;
  display: block;
}

/**********************************************/
/*** Une revolutionnaire ***/
/**********************************************/
.une_revolutionnaire .tt40{
  text-align: center;
}

.une_revolutionnaire h1+p {
  margin: 0 0 8px;
  text-align: center;
}

.une_revolutionnaire  .titres {
  margin: 18px 0 8px;
}
/**********************************************/
/*** rubrique***/
/**********************************************/
.haut_rubrique {
  margin: 0 0 20px;
  border-bottom: 6px solid #e9edf0;
  padding: 0 0 4px 0;/*** top pour article ***/
}

/**********************************************/
/*** fleuve***/
/**********************************************/
.fleuve .signature, .fleuve time {
  font-size: 1.1rem;
  color: #8b9299;
    margin:0;
}

.fleuve .urgent time{
  color:#fff;
}

.ie .fleuve .signature, .ie .fleuve time {
  font-size: 11px;
}

.ie .fleuve .signature {
  clear: both;
}

.fleuve p {
  margin: 0;
}

.fleuve .enrichi {
  overflow: hidden;
  border-top: 1px solid #eef1f5;
  padding-top:10px;
}

.fleuve .enrichi:first-child, .fleuve .urgent:first-child {
  border-top: none;
}

.fleuve section {
  border-bottom: 6px solid #eef1f5;
}

.fleuve section:last-child {
  border-bottom:none;
}

.fleuve .urgent {
  background: #aa0202;
  padding:0;
}

.fleuve .urgent .grid_1 {
  padding: 10px 0;
  color: #fff;
  text-align: center;
}

.fleuve .urgent .grid_1 .tt13_capital  {
  padding: 0 0 10px;
  border-bottom: 1px solid #cb2626;
}

.fleuve .conteneur_fleuve{
  background: #fff;
  margin-left: 0;
  padding: 0;
  width: 605px;
}

.fleuve .urgent .conteneur_fleuve{
  padding-top:10px;
}

.fleuve .jour_parution {
  background: #fff;
}

.fleuve .jour_parution {
  display: block;
  padding: 0 0 20px;
  color: #2e3942;
  text-transform: uppercase;
  font-weight: bold;

}

.fleuve .atome {
  margin: 0 0 10px 0;
}

.fleuve .liens {
  margin: 16px 0 0;
  color: #a2a9ae;
}

.fleuve .liens>span:first-child {
  float: left;
}

.fleuve .liens .permalien {
  float: left;
  margin-left:8px;
  cursor:pointer;
  height:26px;
}

.fleuve .liens .permalien:hover {
  text-decoration: underline;
}

.fleuve .liens .permalien .saisie {
  display: none;
  margin: -8px 15px 0 0;
  padding: 3px 3px 2px 8px;
  height: 20px;
  width: 250px;
  line-height: 20px;
}

.fleuve .liens .permalien.block .saisie {
  display:inline-block;
}

.fleuve .liens .permalien .invisible {
  width: 210px;
}

.fleuve .liens .partage {
  float: right;
}

.fleuve blockquote {
  display: block;
  padding-left: 16px;
  margin: 20px 0;
  border-left: 3px solid #b9c0c5;
  color: #5d666d;

}

.fleuve .lire, .article .lire {
  padding: 8px 16px 6px;
  clear: both;
  background: #f8f9fb;
  border-left: 1px solid #e4e6e9;
  font-weight: bold;
  margin: 20px 0;
}

.fleuve .twit, .article .twit{
  padding: 8px 16px 6px;
  clear: both;
  overflow: hidden;
  background: #f8f9fb;
  border-left: 3px solid #41c8f5;
  margin: 20px 0;
  font-size: 12px;
   line-height: 18px;
}

.fleuve .twit .img, .article .twit .img{
  float: left;
  width: 58px;
}
.fleuve .twit img, .article .twit img{
  margin-right: 10px;
  border-radius: 4px;
}


.fleuve .twit .texte_twit, .article .twit .texte_twit{
  display: block;
  float: left;
  width: 85%;
  margin: 0;
}

.fleuve .twit .texte_twit .nom, .article .twit .texte_twit .nom{
  display: block;
  color: #41c8f5;
  font-weight: bold;
}

.fleuve .grid_3.titre_video {
  font-weight: bold;
}

.fleuve section article {
  margin-bottom:0;
}
/**********************************************/
/*** generique ***/
/**********************************************/

.saisie {/* styles pour input text et autres champs de saisie */
  background-color: #f8f9fb;
  /*-webkit-box-shadow: inset 3px 3px 3px 5px rgba(250, 250, 250, 0.2), 0 -1px 1px rgba(0, 0, 0, 0.2);
    -moz-box-shadow: inset 3px 3px 3px 5px rgba(250, 250, 250, 0.2), 0 -1px 1px rgba(0, 0, 0, 0.2);
      box-shadow: inset 3px 3px 3px 5px rgba(250, 250, 250, 0.2), 0 -1px 1px rgba(0, 0, 0, 0.2);*/
  border: 1px solid #b9c0c5;
  -webkit-border-radius: 4px;
-moz-border-radius: 4px;
  border-radius: 4px;
  padding: 3px 3px;
  font-size: 1.2rem;
  color: #747b83;
  outline:0;
}
.saisie:focus {
   border-color:#8b9299;
}

.radio_ou_checkbox, input[type="radio"], input[type="checkbox"] {
  cursor:pointer;
}
input[type="radio"], input[type="checkbox"] {
  vertical-align: bottom;
   margin-bottom: 0.2rem;
}

.erreur {
  padding: 10px;
  background: #f2dede;
  color: #d50303;
}

.txt_erreur, .saisie_erreur label {
  color: #d50303;
  text-shadow: 0px 1px 3px #d2d6db;
}

.saisie_erreur, .saisie_erreur input {
  border-color:#d50303;
}

.saisie_erreur input {
  color: #000;
  text-shadow: 0 0 0 transparent;
}

.champs_erreur {
  border: 1px solid #d50303;
}

.confirmation {
  position: relative;
  padding: 10px;
  background: #dff0d8;
  color: #468847
}

.confirmation .fermer {
  position: absolute;
  right: 10px;
  top: 10px;
  width: 10px;
  height: 10px;
  background: url("/medias/web/img/sprites/icos_petites.png") no-repeat -22px -191px;
  text-indent: -9999px;
  cursor: pointer;
}

.bandeau_info_importante {
  padding:10px;
  background:#fff1ae;
  color:#c09853;
}

.bandeau_important {
  padding: 6px 16px;
  background: #d50303;
  color: #fff;
  font-weight: bold;
}


input[disabled="disabled"] {
  background: #eef1f5;
}

.entete_abonnes {
  display: block;
  padding-top: 8px;
  padding-bottom: 9px;
  border-top: 3px solid #ffd500;
  border-bottom: 1px solid #e9edf0;
  color: #464f57;
  font-weight: bold;
}

.entete_abonnes_bg {
  display: block;
  padding: 4px 16px 2px;
  background: #ffd500;
  color: #464f57;
  font-weight: bold;
}

.rnd5 {
  -webkit-border-radius:5px;
    -moz-border-radius:5px;
    -ms-border-radius:5px;
    -o-border-radius:5px;
      border-radius:5px;
}
.rnd4 {
  -webkit-border-radius:4px;
    -moz-border-radius:4px;
    -ms-border-radius:4px;
    -o-border-radius:4px;
      border-radius:4px;
}

.conteneur_autocompletion {
   position:relative;
}
.conteneur_autocompletion > ul {
   position:absolute;
   top:-4px !important;
   max-height:160px;
   overflow:auto;
   padding:16px 8px 8px;
   border:solid #b9c0c5;
   border-color:#8b9299;
   border-width:0 1px 1px;
   background:#f8f9fb;
   -webkit-box-shadow:0px 4px 8px -3px #444;
   -moz-box-shadow:0px 4px 8px -3px #444;
   -o-box-shadow:0px 4px 8px -3px #444;
   -ms-box-shadow:0px 4px 8px -3px #444;
   box-shadow:0px 4px 8px -3px #444;
   -webkit-border-bottom-right-radius: 4px;
   -webkit-border-bottom-left-radius: 4px;
   -moz-border-radius-bottomright: 4px;
   -moz-border-radius-bottomleft: 4px;
   border-bottom-right-radius: 4px;
   border-bottom-left-radius: 4px;
}

/**********************************************/
/*** Pictos ***/
/**********************************************/
/*** superposees aux images ****/
.img_ico {
  position: relative;
  display: block;
  margin: 0;
}

.liste_img_lien .img_ico {
  float: left;
  width: 92px;
  height: 61px;
}

.ico_portfolio, .ico_infographie, .ico_video, .ico_live {
  display: inline-block;
  background-image: url('/medias/web/img/sprites/icos_medias.png');
  text-indent: -9999px;
  position: absolute;
}

.ico63x63 {
  bottom: 3%;
  left: 2%;
  width: 63px;
  height: 63px;
}

.ico48x48 {
  bottom: 3%;
  left: 2%;
  width: 48px;
  height: 48px;
}

.ico29x29 {
  bottom: 2%;
  left: 5%;
  width: 29px;
  height: 29px;
}


img[height="321"]+.ico63x63 {
  bottom: 4%;
  left: 1.5%;
}

img[height="156"]+.ico48x48 {
  bottom: 6%;
  left: 2.2%;
}

img[height="100"]+.ico29x29 {
   bottom:10%;
   left:3%;
}

img[height="97"]+.ico29x29 {
  bottom: 6%;
  left: 3.5%;
}

.une_revolutionnaire .ico63x63 {
  bottom: 4%;
  left: 1%;
}

.ico_video.ico63x63  {
  background-position: 0 -129px;
}

.ico_video.ico48x48 {
  background-position: -64px -129px;
}

.ico_video.ico29x29{
  background-position: -113px -129px;
}

.ico_infographie.ico63x63  {
  background-position: 0 -64px;
}

.ico_infographie.ico48x48 {
  background-position: -64px  -64px;
}

.ico_infographie.ico29x29{
  background-position: -113px -64px;
}

.ico_portfolio.ico63x63  {
  background-position: 0 0;
}

.ico_portfolio.ico48x48 {
  background-position: -64px 0;
}

.ico_portfolio.ico29x29{
  background-position: -113px 0;
}

.ico_live.ico63x63  {
  background-position: 0 -192px;;
}

.ico_live.ico48x48 {
  background-position: -64px -192px;;
}

.ico_live.ico29x29{
  background-position: -113px -192px;
}

.ico_univers_cine {
  display: inline-block;
  background-image: url('/medias/web/img/partenaires/evenement/logo-universcine-lemonde.png');
  text-indent: -9999px;
  position: absolute;
        bottom: 8%;
  right: 2%;
  width: 80px;
  height: 44px;
}


/*** superposees aux images ****/

/** nature edito ***/
.ico_portfolio_mini, .ico_infographie_mini, .ico_video_mini, .ico_live_mini {
  display: inline-block;
  background-image: url('/medias/web/img/sprites/icos_medias.png');
}

.ico_portfolio_mini{
  width: 17px;
  height: 12px;
  margin: 0 5px 0 0;
  background-position: -143px 0;
  vertical-align: baseline;
}

.ico_infographie_mini{
  width: 11px;
  height: 10px;
  margin: 0 5px 0 0;
  background-position: -143px -64px;
  vertical-align: baseline;
}

.ico_video_mini{
  width: 13px;
  height: 13px;
  margin: 1px 5px 0 0;
  background-position: -143px -128px;
  vertical-align: text-bottom;
}

.ico_live_mini{
  width: 13px;
  height: 13px;
  margin: 1px 5px 0 0;
  background-position: -143px -192px;
  vertical-align: text-bottom;
}


.voir_plus.hovered {
  background: #f1f5f8;
  cursor: pointer;
}
.deplier {
  display:block;
  visibility:hidden;
  height:16px;
  margin:10px 0 0;
  text-indent:-9999px;
  background:#e4e6e9 url('/medias/web/img/pictos/chevrons_double_haut_bas.png') no-repeat 50% 3px;
  border-top:1px solid #a2a9ae;
}
.deplier.visible {
  visibility:visible;
}
.deplier.ouvert {
  background-position:50% -13px;
}
.deplier:hover {
  cursor:pointer;
}

/*********************************************/
/*** Plier/deplier pour les blocs de deroule */
/*********************************************/
.edito_ensemble_liste p {
   min-height:45px;
}
.edito_ensemble_lien {
   cursor:pointer;
}
.edito_ensemble_lien .double_chevron {
   display:inline-block;
   width:9px;
   height:9px;
   margin-left:10px;
   background:url('/medias/web/img/pictos/chevrons_double_haut_bas.png') no-repeat;
}
.edito_ensemble_lien.resize_mini .double_chevron {
   transform:rotate(0deg);
   -ms-transform:rotate(0deg); /* Internet Explorer */
   -moz-transform:rotate(0deg); /* Firefox */
   -webkit-transform:rotate(0deg); /* Safari and Chrome */
   -o-transform:rotate(0deg); /* Opera */

   /* Fonctionne dÃ©jÃ  sur webkit */
   -webkit-transition-property: transform;
   -webkit-transition-duration: 0.5s;
   -webkit-transition-timing-function: ease-in;

   /* BientÃ´t supportÃ© par Firefox */
   -moz-transition-property: transform;
   -moz-transition-duration: 0.5s;
   -moz-transition-timing-function: ease-in;

   /* â€¦ et lorsque ce sera standardisÃ© */
   transition-property: transform;
   transition-duration: 0.5s;
   transition-timing-function: ease-in;
}
.edito_ensemble_lien.resize_maxi .double_chevron {
   transform:rotate(180deg);
   -ms-transform:rotate(180deg); /* Internet Explorer */
   -moz-transform:rotate(180deg); /* Firefox */
   -webkit-transform:rotate(180deg); /* Safari and Chrome */
   -o-transform:rotate(180deg); /* Opera */

   /* Fonctionne dÃ©jÃ  sur webkit */
   -webkit-transition-property: transform;
   -webkit-transition-duration: 0.5s;
   -webkit-transition-timing-function: ease-in;

   /* BientÃ´t supportÃ© par Firefox */
   -moz-transition-property: transform;
   -moz-transition-duration: 0.5s;
   -moz-transition-timing-function: ease-in;

   /* â€¦ et lorsque ce sera standardisÃ© */
   transition-property: transform;
   transition-duration: 0.5s;
   transition-timing-function: ease-in;
}

/**********************************************/
/*** Onglets: degrade gris sur courant, pas de contour sur non actif ***/
/**********************************************/
.conteneur_onglets {
   height:35px;
   border:solid #d2d6db;
   border-width:0 0 1px;
}

.conteneur_onglets .onglet {
   float:left;
   background:#fff;
   text-align:center;
}

.conteneur_onglets .onglet.adroite {
   float:right;
}

.conteneur_onglets .onglet.courant {
   margin:0 4px 0 0;
   border:solid #d2d6db;
   border-width:1px 1px 0;
   -webkit-border-top-left-radius: 4px;
   -webkit-border-top-right-radius: 4px;
   -moz-border-radius-topleft: 4px;
   -moz-border-radius-topright: 4px;
   border-top-left-radius: 4px;
   border-top-right-radius: 4px;
   background: #fff;
   background: -moz-linear-gradient(top, #f1f5f8 0%, #ffffff 100%);
   background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#f1f5f8), color-stop(100%,#ffffff));
   background: -webkit-linear-gradient(top, #f1f5f8 0%, #ffffff 100%);
   background: -o-linear-gradient(top, #f1f5f8 0%, #ffffff 100%);
   background: -ms-linear-gradient(top, #f1f5f8 0%, #ffffff 100%);
   background: linear-gradient(top, #f1f5f8 0%, #ffffff 100%);
   filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#f1f5f8', endColorstr='#ffffff',GradientType=0 )
}

.conteneur_onglets .onglet > span, .conteneur_onglets .onglet > a, .conteneur_onglets .onglet .interieur_onglet {
   display:block;
   height:35px;
   line-height:36px;
   padding:0 8px;
   cursor:pointer;
}

.conteneur_onglets .onglet > a:hover, .conteneur_onglets .onglet > a:focus {
   cursor:pointer;
   color:#2e3942;
}

.conteneur_onglets .onglet.desactive > span {
   cursor:default;
   color:#b8c0c3;
}

.conteneur_onglets .onglet.courant > a {
   font-weight:bold;
   color:#2e3942;
   cursor:default;
}

/**********************************************/
/*** logos /  textes image ***/
/**********************************************/
.lien_img314x64{
  display: block;
  width: 314px;
  height: 64px;
  margin-bottom: 16px;
}

.lien_img314x64:hover{
  opacity: 0.7;
  -ms-filter:"progid:DXImageTransform.Microsoft.Alpha(Opacity=70)";
}

.abonne_cartouche44x12 {
  display: inline-block;
  width: 44px;
  height: 12px;
  margin: 0 0 0 5px;
  background: url('/medias/web/img/elements_lm/abonne_cartouche44x12.png');
  text-indent: -9999px;
  font-size: 13px;
  vertical-align: middle;
}

.ea109x13 {
  display: inline-block;
  width: 109px;
  height: 13px;
  background: url('/medias/web/img/elements_lm/edition_abonnes109x13.png');
  text-indent: -9999px;
  font-size: 13px;
  vertical-align: baseline;
}


.logo_lm_abo95x16, .logo_lm95x16 {
  display: inline-block;
  width: 95px;
  height: 16px;
  background: url('/medias/web/img/elements_lm/logo_lm95x16.png');
  text-indent: -9999px;
  font-size: 13px;
  vertical-align: baseline;
}

.logo_lm95x16 {
  background: url('/medias/web/img/elements_lm/logo_lm95x16.png') 0 -16px;
}

.ea_article {
  position: absolute;
  left: -18px;
  top: 3px;
  display: inline-block;
  width: 55px;
  height: 59px;
  text-indent: -9999px;
  background: url('/medias/web/img/elements_lm/marqueur_ea_article.png');
}

.huffington148x10 {
  display: inline-block;
  width: 148px;
  height: 10px;
  text-indent: -9999px;
  background: url('/medias/web/img/groupe/logo_huffington149x10.png');
}

.telerama47x18 {
   display:inline-block;
   width:47px;
   height:18px;
   text-indent:-9999px;
   background:url('/medias/web/img/groupe/logo_teleramafr47x18.png');
}

.courrier72x21 {
  display: inline-block;
  width: 72px;
  height: 21px;
  text-indent: -9999px;
  background: url('/medias/web/img/groupe/logo_courrier72x21.png');
}


/*** evenementiel ***/
.lien_img314x64.festival_cannes_une {
   background: url('/medias/web/img/evenementiel/festival_de_cannes_2012/widget_une.png');
   text-indent: -9999px;
}

.lien_img314x64.legislatives_2012_une {
   background: url('/medias/web/img/evenementiel/legislatives_2012/widget_une.png');
   text-indent: -9999px;
}


/**********************************************/
/*** en ce moment ***/
/**********************************************/
#en_ce_moment {
  height: 33px;
  overflow: hidden;
  background: #2d3143; /* Old browsers */
  background: -moz-linear-gradient(top, #2d3143 0%, #10141d 100%); /* FF3.6+ */
  background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#2d3143), color-stop(100%,#10141d)); /* Chrome,Safari4+ */
  background: -webkit-linear-gradient(top, #2d3143 0%,#10141d 100%); /* Chrome10+,Safari5.1+ */
  background: -o-linear-gradient(top, #2d3143 0%,#10141d 100%); /* Opera 11.10+ */
  background: -ms-linear-gradient(top, #2d3143 0%,#10141d 100%); /* IE10+ */
  background: linear-gradient(top, #2d3143 0%,#10141d 100%); /* W3C */
}

#en_ce_moment ul {
  padding: 0 13px 0 0;
}

#en_ce_moment li {
  display: block;
  float:left;
}

.ie #en_ce_moment li:first-child  {
  font-size: 12px;
}

#en_ce_moment a, #en_ce_moment li:first-child span {
  display: inline-block;
  height: 23px;
  padding: 10px 8px 0;
  color: #d2d6db;
  font-size: 1.3rem;
  line-height: 100%;
  font-weight: bold;
}

.ie #en_ce_moment a {
  font-size: 13px;
}

#en_ce_moment a:hover {
  color: #CB2626;
}

#en_ce_moment li:first-child {
  background: url('/medias/web/img/sprites/sous_nav.png') no-repeat right -70px;
  padding: 0 13px 0 5px;
}

#en_ce_moment li:first-child span  {
  height: 22px;
  padding: 11px 8px 0;
  text-transform: uppercase;
  color: #fff;
  font-size: 1.2rem;
}



/**********************************************/
/*** carousel navigation ***/
/**********************************************/
.carousel_petit .navigation {
  margin: 10px 0;
  line-height: 10px;
  text-align: center;
}

.carousel_petit .precedent, .carousel_petit .suivant, .carousel_petit .repere   {
  display: inline-block;
  vertical-align: middle;
  background: url('/medias/web/img/sprites/carousel_petit.png') no-repeat;
  text-indent: -9999px;
}

.carousel_petit .precedent, .carousel_petit .suivant {
  width: 8px;
  height: 11px;
}

.carousel_petit .suivant {
  background-position: -10px 0
}
.carousel_petit .repere {
  background-position: 0 -24px;
  width: 9px;
  height: 8px;
  margin: 0 3px;
}

.carousel_petit .precedent:hover, .carousel_petit .precedent.actif {
  background-position: -1px -12px;
  cursor: pointer;
}

.carousel_petit .suivant:hover, .carousel_petit .suivant.actif {
  background-position: -10px -12px;
  cursor: pointer;
}

.carousel_petit .repere.actif {
  background-position: -11px -24px;
  cursor: pointer;
}

/**********************************************/
/*** pagination ***/
/**********************************************/
.conteneur_pagination {
  background: #f8f9fb;
  font-weight: bold;
  border: 1px solid #d2d6db;
  border-radius: 4px;
  height: 26px;
  margin-top:20px;
}

.pagination_large {
  margin-top:10px;
}

.pagination a:hover, .pagination span:hover{
  cursor: pointer;
}

.pagination li  {
  display: block;
  float: left;
}

.pagination .adroite {
  float: right;
}

.pagination>li {
  background: #f8f9fb;
}

.pagination>li:hover {
  background: #e4e6e9;
}

.pagination .page {
  display: block;
  float: left;
  padding: 0 9px;
  height: 26px;
  border: solid #e4e6e9;
  border-width: 0 0 0 1px;
  text-align: center;
  line-height: 26px;
  font-size: 12px;
}


.conteneur_pagination   .prev, .conteneur_pagination   .next {
   display: block;
   float: left;
   width: 27px;
   height: 26px;
   text-shadow: 0 1px 1px rgba(255, 255, 255, 0.75);
   background-color: #fafafa;
   background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#fefefe), color-stop(25%, #fefefe), to(#e4e6e9));
   background-image: -webkit-linear-gradient(#fefefe, #fefefe 25%, #e4e6e9);
   background-image: -moz-linear-gradient(left, #fefefe, #fefefe 25%, #e4e6e9);
   background-image: -ms-linear-gradient(#fefefe, #fefefe 25%, #e4e6e9);
   background-image: -o-linear-gradient(#fefefe, #fefefe 25%, #e4e6e9);
   background-image: linear-gradient(#fefefe, #fefefe 25%, #e4e6e9);
   background-repeat: no-repeat;
   filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fefefe', endColorstr='#e4e6e9', GradientType=0);
   text-align: center;
   line-height: 26px;
   font-size: 15px;
   color: #2e3942;
}

.conteneur_pagination  .prev:hover, .conteneur_pagination  .next:hover {
color: #2e3942;
text-decoration: none;
background-color: #e4e6e9;
background-position: 0 -15px;
-webkit-transition: background-position 0.1s linear;
-moz-transition: background-position 0.1s linear;
-ms-transition: background-position 0.1s linear;
-o-transition: background-position 0.1s linear;
transition: background-position 0.1s linear;
}

.conteneur_pagination .prev {
  border-right: 1px solid #d2d6db;
}
.conteneur_pagination .next {
  border-left:1px solid #d2d6db;
  float: right
}

.conteneur_pagination .prev.inactif, .conteneur_pagination .next.inactif {
  color: #b9c0c5;
}

.conteneur_pagination .inactif:hover {
  color: #b9c0c5;
  background-color: #f8f9fb;
  background-position: 0 0;
-webkit-transition: none;
-moz-transition: none;
-ms-transition: none;
-o-transition: none;
transition: none;
}

.pagination {
  float: left;
  width: 586px;
}

.conteneur_pagination.reactions .pagination {
  width:476px;
}

.pagination_large .pagination {
  float:left;
  width:918px;
}

.pagination a:hover, .pagination span:hover{
  cursor: pointer;
}

.pagination li  {
  display: block;
  float: left;
}

.pagination>li {
  background: #f8f9fb;
}

.pagination>li:hover {
  background: #e4e6e9;
}

.pagination .page {
  display: block;
  float: left;
  padding: 0 9px;
  height: 26px;
  border-left: 1px solid #e4e6e9;
  text-align: center;
  line-height: 26px;
  font-size: 12px;
}

.pagination>li>a, .pagination>li>span{
  color: #5d666d;
}

.pagination .page.actif {
  height: 28px;
  margin-top: -1px;
  padding-top: 1px;
  background: #fff;
  border-color: #fff;
  color: #b9c0c5;
}

.pagination .plus {
  position: relative;
}

.pagination .plus div {
  display: none;
  position: absolute;
  top: 24px;
  right: -70px;
}

.pagination .plus ul {
  background: #a2a9ae;
  border-radius: 4px;
  height: 26px;
}

.pagination .plus ul li {
  border-left: 1px solid #a2a9ae;
}

.pagination .plus ul li:first-child {
  border-radius: 4px 0 0 4px;
}

.pagination .plus ul li:hover {
  background: #5d666d;
}

.pagination .plus .pointeur {
  display: block;
  height: 12px;
  background: url('/medias/web/img/pictos/pagination_fle.png') no-repeat 554px 0;
}

.pagination_large .plus .pointeur {
  background-position: 884px 0;
}

.pagination .plus:hover div {
  display: block
}

.pagination .plus ul .page {
  border: solid #b9c0c5;
  border-width: 0 1px 0 0;
  text-align: center;
  line-height: 26px;
  font-size: 12px;
  color: #fff;
}

.toute-l-actualite {
  color: #d2d6db;
  padding: 13px 13px 0;
  font-size: 11px;
  line-height: 120%;
}
.toute-l-actualite h2,
.toute-l-actualite h3 {
  display: inline;
  font-size: 11px;
  font-weight: normal;
}


/**********************************************/
/*** footer ***/
/**********************************************/
/* footer services */
#footer_services {
  overflow: hidden;
  padding: 16px 13px 0;
  width: 974px;
  margin: 16px auto 50px;
  font-size: 11px;
  text-align: left;
  background: #fff;
}

#footer_services .carousel {
  width: 9000px;
  height: 177px;
  overflow: hidden;
}

#footer_services .carousel li {
  height: 176px;
}
#footer_services .carousel .alpha {
  clear:none;
  margin-right:16px;
}

#footer_services .bloc {
  position: relative;
  height: 176px;
  border-top: 3px solid #16212c;
}

#footer_services .contenu_bloc, #footer_services .img_bloc {
  height: 142px;
  padding: 5px 16px 5px;
  border: solid #e4e6e9;
  border-width: 0 1px 1px;
  background: #fafbfc;
}


#footer_services .img_bloc {
  padding: 0;
  height: 151px;
}

#footer_services .entete{
  display: block;
  height: 21px;
  padding: 0 16px;
  border: solid #e4e6e9;
  border-width: 0 1px;
  background: #eef1f5;
  color: #16212c;
  line-height: 20px;
  font-size: 12px;
  font-weight: bold;
}

#footer_services .opacite {
  position: absolute;
  bottom: 0;
  left: 0;
  background: rgba(255, 255, 255, 0.7);
  height: 35px;
  padding-top: 5px;
  width: 100%;
  line-height: 120%;
}

#footer_services .opacite  img {
  float: left;
  margin: 0 10px 0 0;
}

#footer_services .opacite span {
  float: left;
  width: 165px;
  margin: 5px 0 0;
  color: #464f57;
  font-size: 12px;
  line-height: 14px;
  font-weight: bold;
}


#footer_services .btn_fonce {
  position: absolute;
  bottom: 6px;
  right: 6px;
}

#footer_services .entete .obf {
  color: #16212c;
}

#footer_services .entete .obf:hover {
  text-decoration: underline;
}

#footer_services .entete .lien {
  float: right;
  color: #a2a9ae;
  font-size: 11px;
  font-weight: normal;
}

#footer_services label {
  display: block;
  margin: 0 0 5px;
  font-weight: bold;
  color: #8b9299;
  font-sioze: 11px;
}

#footer_services form .saisie {
  width: 210px;

}

#footer_services form .btn {

  font-size: 10px;
}

#footer_services .trafic {
  text-align:right;
  color:#8b9299;
}
#footer_services .trafic .opacite a {
  display:block;
  float:left;
  text-align:left;
}

#footer_services .meteo {
  margin: 16px 0 0 -10px;
  padding: 10px;
  background: #fff;
  font-weight: bold;
}

#footer_services .meteo td{
  color: #16212c;
  width: 90px;
  vertical-align: top;
}

#footer_services .meteo td+td {
  width: 170px;
  line-height: 14px;
}

#footer_services .meteo .ciel {
  vertical-align: middle;
}

#footer_services .meteo .temperature {
  font-size: 17px;
}

#footer_services .intitule {
  color: #8b9299;
}

/*** sprite programme tv ***/
#footer_services  .conteneur_liste_tv {
   height: 150px;
   border: solid #eef1f5;
   border-width: 0 1px 1px 1px;
}

#footer_services  .conteneur_liste_tv .footer {
   display: block;
   color: #747b83;
   font-size: 11px;
   text-align: right;
   padding: 2px 16px 0 0;
}

#footer_services .carousel .liste_tv {
   position: relative;
   height: 128px;
   overflow-y:auto;
   overflow-x:none;
   border-bottom: 1px solid #eef1f5;
}

#footer_services .carousel .liste_tv li {
   height: auto;
   overflow: hidden;
   padding: 5px 3px;
}


#footer_services .liste_tv  .logo+p {
   width: 230px;
   display: inline-block;
   line-height: 14px;
   font-weight: bold;
}

#footer_services .liste_tv  .logo+p span {
   font-size: 10px;
}

#footer_services .liste_tv  .logo+p b {
   display: block;
   font-size: 11px;
}

#footer_services .liste_tv .logo, #footer_services .liste_tv .note{
   display: inline-block;
   margin: 0 5px 0 0;
   width: 47px;
  height: 27px;
   background: url('/medias/web/img/sprites/tv.png') no-repeat 0 0;
   text-indent: -9999px;
   vertical-align: baseline;
}

#footer_services .liste_tv .note {
   float: left;
   margin-top: 2px;
}

#footer_services .liste_tv  .logo_france_2 {
   background-position: 0 -28px;
}

#footer_services .liste_tv  .logo_france_3 {
   background-position: 0 -56px;
}

#footer_services .liste_tv .logo_canal {
   background-position: 0 -84px;
}

#footer_services .liste_tv  .logo_france_5 {
   background-position: 0 -112px;
}

#footer_services .liste_tv  .logo_arte {
   background-position: 0 -140px;
}

#footer_services .liste_tv  .logo_m6 {
   background-position: 0 -168px;
}

#footer_services .liste_tv  .logo_direct_8 {
   background-position: 0 -196px;
}

#footer_services .liste_tv  .logo_w9 {
   background-position: 0 -224px;
}

#footer_services .liste_tv  .logo_tmc {
   background-position: 0 -252px;
}

#footer_services .liste_tv  .logo_nt1 {
   background-position: 0 -280px;
}

#footer_services .liste_tv  .logo_nrj_12 {
   background-position: 0 -308px;
}

#footer_services .liste_tv .logo_france_4 {
   background-position: 0 -336px;
}

#footer_services .liste_tv .logo_la_chaine_parlementaire {
   background-position: 0 -364px;
}

#footer_services .liste_tv  .logo_bfm_tv  {
   background-position: 0 -392px;
}


#footer_services .liste_tv  .logo_direct_star {
   background-position:  0 -420px;
}

#footer_services .liste_tv  .logo_gulli {
   background-position:0 -448px;
}

#footer_services .liste_tv  .logo_france_o {
   background-position: 0 -476px ;
}


#footer_services .liste_tv  .logo_itele{
   background-position: 0 -504px;
}

 #footer_services .liste_tv .note.ico_1_tv {
   width: 8px;
  height: 8px;
   background-position: 0 -550px;
   float: left;
}

 #footer_services .liste_tv .note.ico_2_tv {
   width: 15px;
  height: 8px;
   background-position: 0 -541px;
}

#footer_services .liste_tv .note.ico_3_tv {
   width: 18px;
  height: 8px;
   background-position: 0 -532px;
}

/* footer */
#footer {
  width: 1000px;
  margin: 0 auto 50px;
  font-size: 11px;
  text-align: left;
}

.ie #footer  {
  font-size: 11px;
}

#footer a:hover, #footer .obf:hover {
  text-decoration: underline;
}

#footer .footer_gratuit {
  overflow: hidden;
}

#footer .abonnement{
  float: left;
  width: 673px;
  height: 155px;
  background: url('/medias/web/img/elements_lm/footer_supports.jpg') no-repeat right bottom;
}

#footer .zone_abo {
  display: block;
  float: left;
  width: 673px;
  height: 155px;
  background: url('/medias/web/img/elements_lm/footer_supports_haut.png') no-repeat 385px top;
}

#footer .zone_abo:hover {
  text-decoration: none;
}

#footer .abonnement .contenu {
  margin: 35px 0 0;
  padding: 30px 346px 0 13px;
  background: url('/medias/web/img/elements_lm/le_monde_abonements_227x22.png') no-repeat 13px top;
  color: #16212c;
  line-height: 120%;
}

#footer .abonnement  .bt {
  padding: 5px 0 0 13px;
}

#footer .deja_abonne {
  float: left;
  width: 183px;
  height: 110px;
  padding: 10px 125px 10px 16px;
  margin: 25px 0 0;
  background: #fafbfc url('/medias/web/img/elements_lm/footer_deja_abo.jpg') no-repeat right top;
}

#footer .deja_abonne .accroche {
  display: block;
  font-weight: bold;
  font-size: 17px;
  padding: 0 0 8px;
}

#footer .deja_abonne .obf, #footer .deja_abonne .trigger_boite_login {
  display: block;
  padding: 0 0 0 10px;
  position: relative;
}

#footer .deja_abonne .obf:before, #footer .deja_abonne .trigger_boite_login:before {
  color: #5d666d;
  content: '\203A';
  display: block;
  float: left;
  font-size: 1.2rem;
  left: 0;
  position: absolute;
  width: 10px;
}

#footer .deja_abonne .obf:hover {
  text-decoration: none;
}

#footer .footer_listes {
  overflow: hidden;
  padding: 0 13px;
  background: #16212c;
  color: #2e3942;
  line-height: 120%;
}

#footer .footer_listes div {
  float: left;
  width: 152px;
  padding: 10px 16px 10px 0;
}

#footer .footer_listes div:nth-child(2n+2)  {
  width: 303px;
}

#footer .footer_listes .titre {
  display: block;
  margin: 0 0 4px 0;
  font-weight: bold;
  color: #eef1f5;
}

#footer .footer_listes a, #footer .footer_listes span, #footer .footer_bas a, #footer .footer_bas span, #footer .footer_listes li {
  color: #a2a9ae;
}

#footer .footer_bas .nl:hover {
  text-decoration: none;
  color: #747b83;
}

#footer .footer_bas {
  overflow: hidden;
  padding: 5px 13px 10px;
  border-top: 1px solid #2e3942;
  background: #16212c;
  color: #a2a9ae;
}

#footer .footer_bas  p, #footer .footer_bas  div {
  float: left;
}

#footer  .sociaux {
  float: left;
  margin: 10px 0 0;
  width: 295px;
  color: #747b83;
  font-weight: bold;
  font-size: 12px;
}

#footer  .lien_nl {
  width: 200px;
  margin: 10px 0 0;
  font-size: 12px;
}

#footer  .index {
  width: 475px;
}

#footer .copy {
  padding: 8px 10px 3px;
  color: #464f57;
}

#footer .copy a {
  color: #464f57;
}

#footer  .description {
  color: #a2a9ae;
  padding: 3px 13px;
  line-height: 120%;
}

#header_facebook, #header_google, #header_twitter{
  position: relative;
}

.conteneur_popinbox {
  position:absolute;
  z-index:10;
  top:20px;
  left: -145px;
  padding: 11px 0 0;
  -webkit-box-shadow: -1px 4px 3px -2px rgba(0, 11, 21, 0.5);
    -moz-box-shadow: -1px 4px 3px -2px rgba(0, 11, 21, 0.5);
      box-shadow: -1px 4px 3px -2px rgba(0, 11, 21, 0.5);
  background: transparent url('/medias/web/img/habillage/lightbox_sociaux_coche.png') no-repeat center top;
  display:none;
}

.popinbox {
  padding: 10px;
  background: #fff;
  overflow:visible;
}

.sociaux .popinbox {
  width:292px;
  text-indent:0;
}
#header_facebook_contenu {
  position:relative;
  height:258px;
}


/**********************************************/
/*** PUB ***/
/**********************************************/
.position_pub{
  position: relative;
  line-height:0;
}
.position_pub:hover {
  z-index: 3;
}

.position_pub.bottom2{
  width: 1000px;
  margin: 0 auto;
  text-align: center;
}

.position_pub.bottom2.filled{
  margin: 16px auto;
}

.position_pub.top{
  width: 1000px;
  min-height: 16px;
  margin:0 auto;
}

.position_pub.x01{
   height: 0;
  z-index: 2147483647;
}

.position_pub.top1{
  width: 1000px;
  margin-left: auto;
  margin-right: auto;
  text-align: center;
  min-height: 90px;
}

.app_abonnes .position_pub.top1{
  min-height: 0;
}

/* filled est ajoutÃ© dynamiquement quand la position contient une publicitÃ© */
.col_droite .position_pub.filled{
margin-bottom: 25px;
padding: 7px 7px 13px;
background: #e9edf0 url('/medias/web/img/textes/marqueur_pub_col_droite.png') no-repeat bottom right;
}

/* noborder enlÃ¨ve le fond (bordure autour de la pub) */
.col_droite .position_pub.filled.noborder{
  background: none;
  padding: 0;
}

.conteneur_ligatus {
  margin:25px 0;
}
.conteneur_ligatus * {
  vertical-align:bottom;
}

/**********************************************/
/*** CARROUSELS: GENERIQUE***/
/*
  * Structure (a noter que "navigation" peut etre insere ailleurs
  * tant qu'il est dans "conteneur_carrousel" et hors de "carrousel"):
  * <tag id="UNIQUE" class="conteneur_carrousel">
  *   <tag class="carrousel">
  *     [<tag>]
  *     <tag class="elt"></tag>
  *     <tag class="elt"></tag>
  *     [</tag>]
  *   </tag>
  *   <tag id="UNIQUE" class="navigation">
  *     <tag class="precedent"></tag>
  *     <tag class="reperes">
  *       <tag class="repere"></tag>
  *     </tag>
  *     <tag class="suivant"></tag>
  *   </tag>
  * </tag>
*/
/**********************************************/
.conteneur_carrousel {
   position:relative;
   overflow:hidden;
   height: 321px;
}
.carrousel {
   /* la largeur est fixee en js */ width:6000px;
   position:relative;
}
.carrousel .elt {
   /* il faut specifier la largeur des elements au cas par cas
      a noter qu'il faut aussi gerer la marge en cas de vue multiple
    */ width:644px;
   float:left; /* il faudra gerer en surchargeant les slideshow verticaux*/
   position:relative;
}

/* Navigation.
 * Par defaut, deux fleches avec des puces au centre
 */
.conteneur_carrousel .navigation {
   text-align:center;
   clear:both;
   -webkit-user-select:none;
}
.conteneur_carrousel .navigation .precedent, .conteneur_carrousel .navigation .suivant {
   display:inline-block;
   vertical-align: middle;
   /*text-indent: -9999px;*/
}
.conteneur_carrousel .navigation .precedent span, .conteneur_carrousel .navigation .suivant span, .conteneur_carrousel .navigation .reperes, .conteneur_carrousel .navigation .repere {
   display:inline-block;
   vertical-align: middle;
   /*background-image:url('/medias/web/img/sprites/carousel_petit.png');
   background-repeat:no-repeat;
   text-indent: -9999px;*/
}
.conteneur_carrousel .navigation .reperes {
   display:inline;
   background:none;
}

.conteneur_carrousel .precedent span, .conteneur_carrousel .suivant span {
   width: 8px;
  height: 11px;
   font-weight: bold;
}

.conteneur_carrousel .suivant span {
   background-position: -10px 0
}

.conteneur_carrousel .repere {
   background-position: 0 -24px;
   width: 9px;
  height: 11px;
   margin:2px 3px 1px;
}

.conteneur_carrousel .precedent:hover span, .conteneur_carrousel .precedent.actif span{
   background-position: -1px -12px;

}

.conteneur_carrousel .suivant:hover span, .conteneur_carrousel .suivant.actif span {
   background-position: -10px -12px;
}

.conteneur_carrousel .precedent.active:hover, .conteneur_carrousel .suivant.active:hover {
   cursor: pointer;
}


.conteneur_carrousel .repere:hover, .conteneur_carrousel .repere.actif {
   background-position: -11px -24px;
   cursor: pointer;
}

.conteneur_carrousel img {
   display:block;
   border:0;
}




/**********************************************/
/*** CARROUSELS: PORTFOLIO D'APPEL REVOLUTIONNAIRE ***
 *
 * Specificites:
 * - fleches de navigation a droite et a gauche en surimpression
 * - les folie precedent et suivant sont partiellement visibles
 */
/**********************************************/
.portfolio_appel_revolutionnaire.conteneur_carrousel .navigation .reperes, .portfolio_appel_revolutionnaire .portfolio_data_container h2 {
   display:none; /* pour le portfolio presidentielle */
}
.portfolio_appel_revolutionnaire .portfolio_data_container {
   position:absolute;
   left:0;
   right:0;
   bottom:0;
   background:#000;
   background:rgba(0, 0, 0, 0.8);
   color:#fff;
   text-shadow:0 1px 0 #000;
   padding:16px;
    -ms-filter:"progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
   opacity:0.0;
   -webkit-transition:opacity 1s;
   -moz-transition:opacity 1s;
   -o-transition:opacity 1s;
   transition:opacity 1s;
}
.portfolio_appel_revolutionnaire .elt.shown .portfolio_data_container {
    -ms-filter:"progid:DXImageTransform.Microsoft.Alpha(Opacity=80)";
   opacity:0.8;
}
.portfolio_appel_revolutionnaire .portfolio_data_container .credits {
   opacity:0.5;
   padding-left:4px;
}
.portfolio_appel_revolutionnaire .carrousel {
   /* margin-left:-483px; */
}
.portfolio_appel_revolutionnaire .carrousel .elt {
   width:644px;
   height:322px;
}
.portfolio_appel_revolutionnaire.conteneur_carrousel .navigation .precedent, .portfolio_appel_revolutionnaire.conteneur_carrousel .navigation .suivant {
   position:absolute;
   top:0;
   left:0;
   width:165px;
   height:322px;
    background:#000;
    -ms-filter:"progid:DXImageTransform.Microsoft.Alpha(Opacity=60)";
   background:rgba(0, 0, 0, .6);
}
.portfolio_appel_revolutionnaire.conteneur_carrousel .navigation .precedent:hover, .portfolio_appel_revolutionnaire.conteneur_carrousel .navigation .suivant:hover {
   cursor:pointer;
}
.portfolio_appel_revolutionnaire.conteneur_carrousel .navigation .precedent span, .portfolio_appel_revolutionnaire.conteneur_carrousel .navigation .suivant span {
   display:block;
   margin:111px 0 0;
   text-indent:0;
   font-size:72px;
   width:40px;
   height:100px;
   line-height:95px;
   text-align:center;
   background: #fff;
   background: -moz-linear-gradient(left, #eee 0%, #fff 50%, #fff 100%);
   background: -webkit-gradient(linear, left center, right center, color-stop(0%,#eee), color-stop(50%,#fff), color-stop(100%,#fff));
   background: -webkit-linear-gradient(left, #eee 0%,#fff 50%,#fff 100%);
   background: -o-linear-gradient(left, #eee 0%,#fff 50%,#fff 100%);
   background: -ms-linear-gradient(left, #eee 0%,#fff 50%,#fff 100%);
   background: linear-gradient(left, #eee 0%,#fff 50%,#fff 100%);
   filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#eeeeee', endColorstr='#ffffff',GradientType=0 );
   border:solid #ddd;
   border-width:0 0 0 1px;
   box-shadow:0 0 1px 1px #000;
    -ms-filter:"progid:DXImageTransform.Microsoft.Alpha(Opacity=20)";
   opacity:0.2;
   -webkit-transition:opacity 1s;
   -moz-transition:opacity 1s;
   -o-transition:opacity 1s;
   transition:opacity 1s;
}
.portfolio_appel_revolutionnaire.conteneur_carrousel .navigation .suivant span {
   border-width:0 1px 0 0;
   margin:111px 0 0 124px;
   background: -moz-linear-gradient(left, #fff 0%, #fff 55%, #eee 100%);
   background: -webkit-gradient(linear, left center, right center, color-stop(0%,#fff), color-stop(55%,#fff), color-stop(100%,#eee));
   background: -webkit-linear-gradient(left, #fff 0%,#fff 55%,#eee 100%);
   background: -o-linear-gradient(left, #fff 0%,#fff 55%,#eee 100%);
   background: -ms-linear-gradient(left, #fff 0%,#fff 55%,#eee 100%);
   background: linear-gradient(left, #fff 0%,#fff 55%,#eee 100%);
   filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#ffffff', endColorstr='#eeeeee',GradientType=0 );
}
.portfolio_appel_revolutionnaire.conteneur_carrousel .navigation .precedent:hover span, .portfolio_appel_revolutionnaire.conteneur_carrousel .navigation .suivant:hover span {
    -ms-filter:"progid:DXImageTransform.Microsoft.Alpha(Opacity=90)";
   opacity:0.9;
   color:#222;
}
.portfolio_appel_revolutionnaire.conteneur_carrousel .navigation .suivant {
   left:auto;
   right:0;
}
.portfolio_appel_revolutionnaire a .legende.bg_fonce {
   color:#fff;
}

/* ----- start file /header.css ----- */
/* Securite pub */
#header, #barre_titre, #nav {
   position:relative;
}
#header { z-index:3; }
#barre-titre { z-index:2; }
#nav { z-index:1; }

#header {
  font-size: 12px;
  text-align: left;
}

#header a {
  display: inline-block;
}


.conteneur_haut {
  width: 1000px;
  margin: 0 auto;
}


#surheader, #surheader .conteneur_haut{
  background:#000b15;
  background: #1e5799; /* Old browsers */
  background: -moz-linear-gradient(top,  #1e5799 0%, #2d3841 0%, #010c16 100%); /* FF3.6+ */
  background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#1e5799), color-stop(0%,#2d3841), color-stop(100%,#010c16)); /* Chrome,Safari4+ */
  background: -webkit-linear-gradient(top,  #1e5799 0%,#2d3841 0%,#010c16 100%); /* Chrome10+,Safari5.1+ */
  background: -o-linear-gradient(top,  #1e5799 0%,#2d3841 0%,#010c16 100%); /* Opera 11.10+ */
  background: -ms-linear-gradient(top,  #1e5799 0%,#2d3841 0%,#010c16 100%); /* IE10+ */
  background: linear-gradient(top,  #1e5799 0%,#2d3841 0%,#010c16 100%); /* W3C */
  filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#2d3841', endColorstr='#010c16',GradientType=0 ); /* IE6-9 */
  height:25px;
  line-height:25px;
}

#surheader .droit {
  width:400px;
  float: right;
}

#surheader .gauche{
  width:600px;
  float: left;
}

#surheader a, #surheader span {
  color:#fff;
  font-size:11px;
}

#surheader .gauche a, #surheader .gauche span {
  display: block;
  float: left;
  padding: 0 10px;
  border-left: 1px solid #626a72;
  border-right: 1px solid #16212c;
}

#surheader .gauche .actif, #surheader .gauche a:hover, #surheader .gauche .obf:hover{
  background: #000b15;
  color: #fff;
}

* + html #surheader > a,
#surheader .bt_abo {
  display: block;
  float: right;
  padding: 0 16px;
  color: #000;
}

#surheader  .droit .services {
  float: right;
  height: 25px;
}

#surheader  .droit .services > li {
  border-left: 1px solid #626a72;
  border-right: 1px solid #16212c;
}

#surheader  .droit .services>li:hover {
  border-right: 1px solid #fff;
}

#surheader  .droit .services:hover {
  background: #fff;
}

#surheader  .droit .services > li > .obf {
  padding: 0 10px;
  height: 24px;
  line-height: 24px;
}


#surheader  .droit .services:hover>li>a {
  border-right: 1px solid #fff;
}


#surheader  .droit .services:hover a {
  color: #000b15;
}

#surheader .services li {
  position: relative;
  line-height: 25px;
}

#surheader .services div {
  display: none;
  position: absolute;
  right: 0;
  top: 25px;
  -webkit-box-shadow: 0px 2px 4px rgba(0,11,21, 0.5);
     -moz-box-shadow: 0px 2px 4px rgba(0,11,21, 0.5);
      box-shadow: 0px 2px 4px rgba(0,11,21, 0.5);
  width: 340px;
  z-index:10;
  background: #fff;
}
#surheader .services.droite div {
   right:auto;
   left:0;
}

#surheader .services li:hover div {
  display: block;
}

#surheader .services div ul {
  width: 170px;
  float: left;
  padding: 10px 0;
  font-size: 11px;
  line-height: 18px;
}

#surheader .services div ul+ul {
  width: 169px;
  border-left: 1px solid #eef1f5;
}
#surheader .services ul a {
  display: block;
  padding: 0 12px;
  color: #747b83;
}

#surheader .services ul a:hover {
  background: #e9ecf0;
  color: #000b15;
  font-weight: bold;
}

#surheader .services ul strong {
  padding: 0 12px;
}

#header .logo_lm_abo95x16, #header .logo_lm95x16 {
  float: left;
  margin: 7px 16px 0 0;
}

#header_utilisateur {
  height: 34px;
  border-bottom: 1px solid #d2d6db;
  background: #fff;
}

#header_utilisateur .recherche {
  margin-top: 5px;
  padding:0; /* Frankenstein's fix */
  float: left;
}

#header_utilisateur .recherche label {
  display: none;
}

#header_utilisateur .recherche p {
  width: 195px;
  margin:0; /* Frankenstein's fix */
  padding: 2px 5px;
  background-color: #f8f9fb;
  /*-webkit-box-shadow: inset 0 3px 3px 5px rgba(250, 250, 250, 0.2), 0 -1px 1px rgba(0, 0, 0, 0.2);
    -moz-box-shadow: inset 0 3px 3px 5px rgba(250, 250, 250, 0.2), 0 -1px 1px rgba(0, 0, 0, 0.2);
      box-shadow: inset 0 3px 3px 5px rgba(250, 250, 250, 0.2), 0 -1px 1px rgba(0, 0, 0, 0.2);*/
  border: 1px solid #d2d6db;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  overflow:hidden;
}

#header_utilisateur .recherche input[type="search"] {
  border: none;
  background:none;
  width: 165px;
  float:left;
  -webkit-box-sizing:border-box;
}

#header_utilisateur .recherche input[type="search"]:focus {
   outline: none;
}

#header_utilisateur .loupe {
  width: 15px;
  height: 15px;
  margin: 0 0 0 5px;
  border: none;
  background: url('/medias/web/img/sprites/icos_petites.png') no-repeat -17px -173px;
   text-indent: -9999px;
   font-size: 0;
   color: #f8f9fb;
  float:right;
}
* + html #header_utilisateur .loupe { float:none; }

#header_utilisateur .sociaux{
  float: left;
  margin: 7px 20px 0;
  color: #747b83;
  font-weight: bold;
  font-size: 12px;
}

#header_utilisateur .sociaux span, #header_utilisateur .sociaux a {
  vertical-align: middle;
  margin-right: 7px;
}

.sociaux .obf,
.sociaux .obf strong, .sociaux .obf span,
.sociaux .obf:hover strong, .sociaux .obf:hover span, .sociaux .obf:focus strong, .sociaux .obf:focus span {
   color:#000;
   text-decoration:none;
}

.sociaux .obf {
   color:#003366;
}

.sociaux .obf:hover, .sociaux .obf .obf:focus {
   color:#900;
}

#header_utilisateur #header_twitter_contenu .txt15_140 {
   margin:0 0 5px;
   padding:0 0 5px;
   color:#000;
   border-bottom:solid 1px #d2d6db;
}
#header_twitter_contenu .liste_img_lien {
   margin:9px 0 0;
   overflow:hidden;
   white-space:nowrap;
}

#header_twitter_contenu .liste_img_lien .block {
   display:block;
   margin:0 0 5px;
}

#header_twitter_contenu {
   padding:10px;
   border:solid 1px #d2d6db;
}

#header_utilisateur .identifier {
  float: right;
  margin: 3px 0 0;
}

#header_utilisateur .nl {
  float: left;
  margin: 7px 0 0;
}

#header_utilisateur .nl:hover  {
  background-position: right -20px;
}

#header_utilisateur .meteo {
  margin: 8px 0 0;
  float:right;
  text-align: right;
}

#header_utilisateur .meteo a {
  margin: 0 15px 0 0;
  padding: 0 0 3px 0;
  color: #747b83;
}

#header_utilisateur .meteo a:last-child {
  margin: 0;
}

#header_utilisateur .meteo a img {
  vertical-align: text-bottom;
}

#header_utilisateur a:hover, #header_utilisateur .obf:hover {
  color: #16212c;
}

#header_abonne {
  height: 34px;
  background: #ffd500;
  border-bottom: 1px solid #ccaa00;
   position:relative;
   z-index:1;
}


#header_abonne .acces_rapides {
  float: left;
  margin: 6px 0 0;
   line-height: 17px;
}

#header_abonne .acces_rapides a, #header_abonne .acces_rapides strong {
   color: #000;
  line-height: 20px;
  margin: 2px 16px 0 0
}

#header_abonne .acces_rapides a:hover {
   color: #000;
   text-decoration: underline;
}

#header_abonne .acces_rapides strong {
  margin: 2px 6px 0 0;
}

#header_abonne .ea109x13 {
  margin: 0 14px 0 0;
}


#header .acces_compte {
  position:relative;
  float: right;
}

#header .acces_compte:hover {
  cursor: pointer;
}

#header .acces_compte .avatar_nom {
  height: 26px;
  margin: 3px 0 0;
  background-color: #fafafa;
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#fefefe), color-stop(25%, #fefefe), to(#e4e6e9));
  background-image: -webkit-linear-gradient(#fefefe, #fefefe 25%, #e4e6e9);
  background-image: -moz-linear-gradient(top, #fefefe, #fefefe 25%, #e4e6e9);
  background-image: -ms-linear-gradient(#fefefe, #fefefe 25%, #e4e6e9);
  background-image: -o-linear-gradient(#fefefe, #fefefe 25%, #e4e6e9);
  background-image: linear-gradient(#fefefe, #fefefe 25%, #e4e6e9);
  background-repeat: no-repeat;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffff', endColorstr='#e4e6e9', GradientType=0);
  border: 1px solid #d2d6db;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
}

#header .acces_compte .avatar_nom span {
  display: block;
  height: 26px;
  line-height: 26px;
  float: left;
}

#header .acces_compte .avatar {
  width: 28px;
  border-right: 1px solid #d2d6db
}

#header .acces_compte .avatar  img {
  display: block;
  margin: 4px auto 0;
}

#header .acces_compte .avatar  img {
  vertical-align: middle;
}
#header .acces_compte .nom {
  padding: 0 16px;
  border-right: 1px solid #d2d6db;
  border-left: 1px solid #fff;
}

#header .acces_compte .fle {
  width: 28px;
  background: url('/medias/web/img/pictos/fle_bas_noir7x4.png') no-repeat 50% 50%;
}

#header .acces_compte ul {
  position:absolute;
  right:0;
  top:29px;
  width: 98%;
  background:#fff;
  list-style-type:none;
  text-align:left;
  display:none;
  border: 1px solid #d2d6db;
  border-radius: 0 0 3px 3px;
}

#header .acces_compte:hover ul {
  display:block;
}

#header .acces_compte li {
  padding: 8px;
   border-bottom: 1px solid #eef1f5;
}

#header .acces_compte li:hover {
  background: #e9ecf0;
}

#header .acces_compte a {
  display: block;
  color: #000;
}

#header .acces_compte a:hover {
  color: #000;
  font-weight: bold;
}

/**********************************************/
/*** login box ***/
/**********************************************/

/* Style generiques boite surimpression */
.filtre_page {
   position:fixed;
   width:100%;
   height:100%;
   z-index:15; /* ce z-index est infatue a cause des exports partenaires */
   left:0;
   top:0;
   background:rgba(0, 0, 0, 0.5);
}
.lightbox_ext {
   background:#fff;
   width:770px;
   margin:0 auto;
   position:absolute;
   top:100px;
   left:25%;
   z-index:15; /* ce z-index est infatue a cause des exports partenaires */
   -webkit-box-shadow:0 0 15px #000;
   -moz-box-shadow:0 0 15px #000;
   box-shadow:0 0 15px #000;
}


.lightbox_ext, .loginbox {
  overflow: hidden;
  background: #f5f8f9;
}

.lightbox_ext h2, .loginbox h2 {
  padding: 7px 16px 5px;
  background: #16212c;
  border-top: 3px solid #747b83;
  color: #fff;
}

.lightbox_ext .fermer, .loginbox .fermer {
   float:right;
  font-size: 11px;
  line-height: 18px;
  color: #747b83;
   cursor:pointer;
}

.lightbox_ext .fermer span, .loginbox .fermer span {
  display: inline-block;
  width: 10px;
  height: 10px;
  margin: 0 0 0 3px;
  background: url('/medias/web/img/sprites/icos_petites.png') no-repeat -11px -191px;
}


.lightbox_ext .fermer:hover , .loginbox .ferme:hover  {
   color: #fff;
   text-decoration: none;
}

.lightbox_ext .fermer:hover span, .loginbox .fermer:hover span {
   background-position: 0 -191px;
}

.loginbox .message {
  padding:10px;
  background:#eef1f5;
}


.loginbox .login_form {
  position: relative;
  float: left;
  width: 245px;
  height: 235px;
  padding: 10px 15px;
  border-right: 1px solid #fff;
}

.lightbox_ext .intitule, .loginbox  .intitule {
  margin: 0 0 15px 0;
  font-size: 18px;
  line-height: 18px;
  color: #000;
  font-weight: bold;
}

.loginbox span {
   display:block;
}

.loginbox label {
   display:block;
  margin: 0 15px 5px 0;
  color: #747b83;
}

.loginbox .choix {
  margin: 15px 0;
  font-size: 11px;
}

.loginbox .choix label {
  float: left
}

label i {
   display:none;
   font-style:normal;
   display:none;
}
.saisie_erreur label i {
   display:inline;
}


.boite_formulaire .erreur {
   display:none;
}

.loginbox .back {
   padding:0 15px;
   line-height:4rem;
   border-top:1px solid #d2d6db;
}

.loginbox #login_error_email {
   background: #f2dede;
  border:solid 1px #c00;
   color:#c00;
   text-align:center;
}


.loginbox .signup {
  float: left;
  width: 180px;
  height: 230px;
  padding: 10px 40px 10px 15px;
  border-right: 1px solid #fff;
  border-left: 1px solid #e4e6e9;
  font-size: 14px;
  line-height: 140%;
}

.loginbox .accroche {
  display: block;
  margin: 20px 0 15px;
  color: #464f57;
}

.loginbox .abonne_journal {
  position: relative;
  float: left;
  width: 185px;
  height: 235px;
  padding: 10px 55px 10px 16px;
  font-size: 14px;
  line-height: 140%;
  background: url('/medias/web/img/elements_lm/login_box_journal.jpg') no-repeat right 130px;
  border-left: 1px solid #e4e6e9;
}


.loginbox .login_form  .btn_abo, .loginbox .abonne_journal .btn {
  position: absolute;
  bottom: 15px;
  left: 16px;
}
.loginbox .rmdp .btn {
   position:static;
   margin:15px 0;
}
.loginbox #password_recover_box_email {
   width:300px;
}

.rmdp {
   padding:0 15px;
}

/**** fin suheader ***/

/*** ombrelle ***/
#barre_titre {
   background:#fff;
  text-align:center;
   padding:10px 0;
}

#barre_titre .conteneur_haut {
   overflow:hidden;
}

#barre_titre #logo {
  display:block;
  width:240px;
  height:42px;
  margin:16px auto 5px;
  background: url('/medias/web/img/elements_lm/logo_lm240x42.png') no-repeat;
  font-size:46px;
  text-indent: -9999px;
}

#barre_titre #logo.abonnes {
  background-position:0 -42px;
}

#nav_principale, #nav_principale .conteneur_haut {
   background:#f8fafb;
}

#nav_principale {
   border-top:2px solid #d2d6db;
}

#nav_principale .conteneur_haut {
  height:3rem;
}

.ombrelle {
  width: 976px;
  height: 90px;
  margin: 0 auto;
  padding: 0 12px;
  background: #fff;
}
.ombrelle.export_interne {
   text-align:left;
}
.ombrelle.partenariats .tt_rubrique_ombrelle, .ombrelle.partenariats .tt_rubrique_ombrelle a {
   padding:0 4px 0 0;
   background-image:none;
   font-family:FetteEngschrift;
   text-transform:uppercase;
  font-size: 55px;
  line-height: 55px;
}
.ombrelle.partenariats .tt_rubrique_ombrelle a, .ombrelle.export_interne .tt_rubrique_ombrelle a {
   color:#2e3942;
}
.ombrelle.partenariats span {
  display:inline-block;
  padding:0 8px 0 0;
}

.ombrelle .tt_rubrique_ombrelle, .ombrelle.style .tt_rubrique_ombrelle  {
  display: inline-block;
  padding: 0 0 0 67px;
  margin: 25px 0 0;
  background: url('/medias/web/img/elements_lm/m54x44.png') no-repeat 0 20%;
  font-family: 'TheSerifOffice', georgia, serif;
  font-size: 55px;
  line-height: 55px;
  color: #2E3942;
   font-weight: normal;
   letter-spacing: -0.01em
}
* + html .ombrelle .tt_rubrique_ombrelle, * + html .ombrelle.style .tt_rubrique_ombrelle  { display:inline; }

.ombrelle .tt_rubrique_ombrelle a, .ombrelle .tt_rubrique_ombrelle h2 a:hover, .ombrelle .tt_rubrique_ombrelle .obf, .ombrelle .tt_rubrique_ombrelle .obf:hover {
   color: #2E3942;
   text-decoration:none;
}

.ombrelle.style .tt_rubrique_ombrelle {
   background: url('/medias/web/img/elements_lm/m59x44.png') no-repeat 0 20%;
}

.ombrelle .tt_rubrique_ombrelle.max24, .ombrelle .tt_rubrique_ombrelle.max32, .ombrelle .tt_rubrique_ombrelle.max38 {
   background-position: 0 0;
   font-size: 43px;
   line-height: 57px;
}

.ombrelle .tt_rubrique_ombrelle.max32, .ombrelle .tt_rubrique_ombrelle.max38  {
   font-size: 36px;
   line-height: 61px;
}

.ombrelle .tt_rubrique_ombrelle.max38 {
   font-size: 32px;
}

.ombrelle.style .accroche {
   color: #8b9299;
   font-size: 12px;
   line-height: 12px;
   vertical-align: text-bottom;
}

.ombrelle .widget {
   display: inline-block;
   float: right;
   margin: 13px 0 0;
   line-height: 120%;
}

.ombrelle.style .widget {
   width: 424px;
   height: 64px;
   background: url('/medias/web/img/textes/widget_style.png');
   text-indent: -9999px;
}

.ombrelle.style .widget:hover, .ombrelle.politique .widget:hover {
   opacity: 0.7;
   -ms-filter:"progid:DXImageTransform.Microsoft.Alpha(Opacity=70)";
}

.ombrelle .autopromo_edito {
   overflow:hidden;
   width: 314px;
   height: 64px;
}

.autopromo_edito  img {
   border: 1px solid #eef1f5;
}

.autopromo_edito .nature_edito {
   display: inline;
}

/*** nav ***/
#nav {
   clear: both;
  height: 32px;
  margin:0 auto;
  width:1000px;
  background: #fafbfc;
  border-top: 3px solid transparent;
  border-bottom: 1px solid #dddee0;
}

#nav .conteneur_bordure {
  width: 998px;
  margin:-3px auto 0pt;
  border-top: 3px solid #ffd500;
  border-left: 1px solid #d2d6db;
  border-right: 1px solid #d2d6db;
}


#nav.accueil {
  width:auto;
  border-top:solid 3px #2E3942;
  background:#fff;
}

#nav ul {
  margin-top: -3px;
  overflow: hidden;
  width:1000px;
  margin:-3px auto 0;
}

#nav.acceuil ul  {
  width: 998px;
}

#nav li {
  display: block;
  float:left;
  border-top-width : 3px;
  border-top-style :solid;
}

#nav a, #nav span {
  display: inline-block;
  height: 25px;
  padding: 7px 10px 0 9px;
  border-left: 1px solid #d2d6db;
  border-bottom: 1px solid #d2d6db;
  font-size: 12px;
  font-weight: bold;
  text-transform: uppercase;
  color: #000;
}

#nav li:hover a, #nav a:hover, #nav li:hover .obf, #nav .obf:hover {
  color: #fff;
}

#nav .actif {
  background: #fff;
}

#nav .actif a {
  border-bottom: 1px solid #ffffff;
  -webkit-box-shadow: 0 3px 2px 2px rgba(0,0,0, 0.1);
     -moz-box-shadow: 0 3px 2px 2px rgba(0,0,0, 0.1);
          box-shadow: 0 3px 2px 2px rgba(0,0,0, 0.1);/* x,y,blur,spread*/
}

#nav .abonnes.actif a {
   -webkit-box-shadow: none;
     -moz-box-shadow: none;
          box-shadow: none;
}

#nav li:first-child a, #nav li:first-child span {
  border-left: none;
}

#nav .accueil {
  border-top-color: #a2a9ae;
}


#nav .accueil:hover {
  border-top-color: #16212c;
  background: #2e3942;
}


#nav .accueil a, #nav .accueil span {
  width: 12px;
   height: 23px;
   padding: 9px 10px 0 9px;
}

#nav .accueil .maison {
   display: inline-block;
  width: 11px;
   height: 10px;
   vertical-align: text-top;
   background: url('/medias/web/img/sprites/icos_petites.png') no-repeat -29px -108px;
   text-indent: -9999px;
}

#nav .accueil:hover .maison {
  background-position: -29px -120px;
}


/**********************************************/
/*** sous nav ***/
/**********************************************/
#ariane_az {
   width:1000px;
   margin: 0 auto;
}

#ariane_az .obf, #ariane_az a {
   padding: 0 9px;
   color: #000;
   white-space:nowrap;
}

#ariane_az .suite_entrees {
   background: #f8f9fb;
   position: absolute;
   left:-9999px;
}

#ariane_az .suite_entrees p {
   border-bottom: 1px solid #eef1f5;
   line-height: 33px;
   font-size: 12px;
   font-weight: bold;
}

#nav_ariane {
  height: 35px;
  overflow: hidden;
  background: url('/medias/web/img/sprites/sous_nav.png') repeat left -630px;
}

#nav_ariane ul {
  float: left;
  width: 950px;
  overflow: hidden;
}

#nav_ariane li {
  display: block;
  float:left;
}

#nav_ariane a, #nav_ariane h1 span.obf {
  display: inline-block;
  height: 23px;
  padding: 12px 8px 0;
  font-size: 1.2rem;
  line-height: 100%;
  font-weight: bold;
        white-space:nowrap;
}

#nav_ariane a:hover {
   text-decoration: none !important;
}

#nav_ariane .ariane a, #nav_ariane .ariane h1 {
  text-transform: uppercase;
}

.ie #nav_ariane a, #nav_ariane h1  {
  font-size: 12px;
}

#nav_ariane .sous_rub {
  border-right: 1px solid #e4e6e9;
}

#nav_ariane .az {
   position: absolute;
   left:-9999px;
}


#nav_ariane .ariane{
  background: url('/medias/web/img/sprites/sous_nav.png') no-repeat right -175px;
}

#nav_ariane .ariane {
  position: relative;
  padding: 0 13px 0 0;
  margin: 0 0 0 -13px;
  border: none;
}

#nav_ariane .ariane.z1 {
  z-index: 1;
}

#nav_ariane .ariane.z2 {
  z-index: 2;
}

#nav_ariane .ariane.z3 {
  z-index: 3;
}
#nav_ariane .ariane.z4 {
  z-index: 4;
}

#nav_ariane .ariane.z5 {
  z-index: 5;
}

#nav_ariane .ariane.z6 {
  z-index: 6;
}

#nav_ariane .ariane a, #nav_ariane .ariane .obf {
  padding: 12px 5px 0 20px;
        color:#fff;
}

#nav_ariane .ariane>a {
  color: #6a718b;
}

#nav_ariane .ariane a:hover, #nav_ariane .ariane .obf:hover {
   color:#fff;
}

#nav_ariane   .ariane:first-child a {
  padding: 12px 8px 0 25px;
}

.ie #nav_ariane .ariane a, .ie #nav_ariane .ariane span.obf {
  font-size: 12px;
}

.tt_rubrique  {
   margin: 7px 0 17px;
   padding-bottom: 7px;
   border-bottom: 3px solid #e9ecf0;
}


#nav_ariane .actif+li  a {
  padding-left: 3px;
}

#nav_ariane .sous_rub a:hover {
   color:#464f57;
}


/**********************************************/
/*** sous nav sport, dont reset anciens styles fournis par Newsweb ***/
/**********************************************/
#ariane_az #sn, #ariane_az #sn .navlist {
   border:0;
}
#ariane_az #sn {
   margin:0;
   background:#fff;
   border:solid #e4e6e9;
   border-width:0 0 1px;
}
#ariane_az #sn .navlist li {
   border-style:solid;
   border-color:#fff;
   border-width:0 0 0 1px;
}
#ariane_az #sn .navlist li:first-child {
   display:none;
}
#ariane_az #sn .navlist li:hover {
   border-color:#eef1f5;
}
#ariane_az #sn .navlist li:hover + li {
   border-color:#eef1f5;
}
#ariane_az #sn .navlist li a {
   height:28px;
   line-height:28px;
   padding:0 8px;
   font-size:12px;
   border:0;
}
#ariane_az #sn .navlist li a:hover, #ariane_az #sn .navlist li a:focus, #ariane_az #sn .navlist li a:hover span, #ariane_az #sn .navlist li a:focus span, #ariane_az #sn .navlist .cur a span{
   background:none;
   color: #6faa12;
}
#ariane_az #sn .navlist li a span {
   padding:0;
}

/**********************************************/
/*** debrief ***/
/**********************************************/
.conteneur_debrief {
  background: #16212c;
  border-bottom: 3px solid #ffd500;
}

.conteneur_debrief .debrief {
   margin: 0 auto;
   width: 1000px;
}

.debrief {
   overflow: hidden;
   padding: 10px 0;
   min-height: 168px;
   color: #f8f9fb;
   font-weight: bold;
}

.debrief ul {
   overflow: hidden;
   margin: 6px 0;
}

.debrief a, .debrief .obf {
   color: #f8f9fb;
}

.debrief a:hover, .debrief .obf:hover {
   text-decoration: underline;
}

.debrief.politique a:hover, .debrief.politique .obf:hover {
   color: #796ea4;
   text-decoration: none;
}

.debrief .texte_gauche {
   float: left;
   width: 102px;
}

.debrief .texte_debrief {
   display: block;
   width: 94px;
   height: 169px;
   text-indent: -9999px;
   background: url(/medias/web/img/textes/le_debrief.png)
}

.debrief li {
   float: left;
}

.debrief li img{
   border: 1px solid #2e3942;
}

.temps_fort {
   margin-top: -20px;
   margin-bottom: 20px;
   background: #2E3942;
}

.temps_fort.politique {
   background: #110b28;
}

.temps_fort .texte_gauche {
   float: left;
   width: 94px;
}

.temps_fort .titre_gauche{
   display: block;
   width: 94px;
   height: 102px;
   text-indent: -9999px;
   background: url(/medias/web/img/textes/temps_forts_debrief.png)
}

.pub {
   overflow: hidden;
}

.pub_oreille {
  width:200px;
  height:80px;
  float:right;
}

.pub_oreille:first-child {
  float:left;
}

.pub.banniere_top1 {
   width:1000px;
   min-height: 90px;
   margin:10px auto;
   text-align:center;
}


/* ----- start file /article.css ----- */
/**********************************************/
/*** article ***/
/**********************************************/
.article_normal{
   margin-bottom: 13px;
}

.article .tt32+p {
   color: #a2a9ae;
   margin: 6px 0 8px;
}

.article .tt32+p+.auteur {
   margin: 6px 0 8px;
}


.article p {
  margin: 15px 0;
}

.article blockquote {
  display: block;
   clear: both;
  width: 424px;
  padding-left: 16px;
  margin: 20px 0;
  border-left: 4px solid #b9c0c5;
  color: #5d666d;

}

.article h2   {
  font-size: 2rem;
  line-height: 105%;
  font-family: 'TheSerifOffice';
  font-weight: normal;
  margin: 3rem 0 0.5rem;
}

.ie .article h2  {
  font-size: 20px;
}

.article ol {
  list-style-type: decimal;
  margin: 10px 0 10px 20px;
}

.article ul{
  list-style-type: square;
  margin: 10px 0 10px 25px;
}


.article_normal .illustration_haut{
  position: relative;
}

.article_normal .illustration_haut figcaption {
  position: absolute;
  bottom: 0;
  left: 0;
  padding: 5px 10px;
  background: rgba(0, 0, 0, 0.65);
  color: #fff;

}

.article_normal .illustration_haut figcaption .lien_interne {
  color: #fff;
}

.article_normal .illustration_haut img {
  border: none;
}

.article .auteur {
   color: #747b83;
}

/**********************************************/
/*** rÃ©actions  ***/
/**********************************************/
.liste_reactions{
  padding-top: 10px;
  border-top: 3px solid #ffd500;
}

.liste_reactions .intitule{
  float: left;
  font-weight: bold;
}

.liste_reactions .entete {
  height: 38px;
  padding: 0 0 10px;
}

.liste_reactions .intitule span, .liste_reactions .btn span {
  color: #747b83;
}

.liste_reactions .entete .btn_abo {
  float: right;
}

.liste_reactions .reaction {
  padding: 10px 0;
  border-top: 1px solid #eef1f5;
  clear:both;
}

.liste_reactions .reponse {
   padding-left:55px;
}


.liste_reactions .grid_9 {
   width:424px;
}

.liste_reactions .reaction:hover  {
  background: #f5f8f9;
}

.liste_reactions .premier {
  color: #a2a9ae;
   font-weight: bold;
}

.liste_reactions .premier:hover {
   background:transparent;
}

.liste_reactions .reaction .btn {
  visibility: hidden;
  margin: 5px 0 0;
}

.liste_reactions .reaction:hover .btn  {
  visibility: visible;
}

.infobulle {
   position: relative;
}

.liste_reactions  .bulle {
  position:absolute;
   top: 60%;
   left: -93%;
  z-index:10;
  width: 170px;
  padding: 11px 0 0;
  background: url('/medias/web/img/habillage/lightbox_sociaux_coche.png') no-repeat center top;
  display: none;
}

.infobulle:hover .bulle {
   display: inline-block;
}

.liste_reactions  .bulle span {
  display: block;
  -webkit-box-shadow: 0px 3px 2px 1px rgba(0,11,21, 0.2);
     -moz-box-shadow: 0px 3px 2px 1px rgba(0,11,21, 0.2);
          box-shadow: 0px 3px 2px 1px rgba(0,11,21, 0.2);
  border-radius: 4px;
  padding: 10px;
  background: #fff;
}


.liste_reactions .references {
  font-weight: bold;
}


.liste_reactions .references .date {
  color: #8b9299;
}


/*** formulaires reactions ***/
.liste_reactions input[class="btn"], .liste_reactions input[class="btn_abo"] {
  margin:5px 0 10px;
}

.reaction_identifier, .reaction_redaction {
  margin: 20px 0;
  background: #f5f8f9;
  border-top: 3px solid #e9ecf0;
}

.reaction_redaction {
  padding: 0 0 10px;
}

.reaction_identifier .deja_abo {
   float: left;
   width: 275px;
   border-left:1px solid #ebeff0;
}

.reaction_identifier .deja_abo .erreur {
   display:none;
   padding: 7px 28px 7px 15px;
}

.reaction_identifier .form {
  padding: 10px 10px 10px 14px;
}

.reaction_identifier .form p {
   clear: both;
}

.reaction_identifier .non_abo, .conteneur_barre_outils .non_abo.classer   {
  position: relative;
  float: left;
  width: 233px;
  height: 230px;
  padding: 10px 10px 10px 14px;
  background: url('/medias/web/img/textes/daccord_pas_daccord.png') no-repeat 16px 40px;
  border-right: 1px solid #fff;
}

.reaction_identifier .texte{
  margin: 80px 0 15px;
}

.reaction_identifier .mini-login {
  position: relative;
  float: right;
  width: 275px;
  margin: 0;
   padding: 10px 0;
  height: 230px;
  border-left: 1px solid #e4e6e9;
}

.reaction_identifier .mini-login .deja_abo {
   padding: 0 10px 10px 14px;
}

.reaction_identifier .mini-login p {/** sur la barre d'outils seulement */
   overflow: hidden;
   clear: both;
}


.liste_reactions label, .reaction_identifier label {
  position: relative;
  margin: 10px 0 3px;
  color: #747b83;
  line-height: 20px;
}

.reaction_identifier .deja_abo .txt18 {
  display: inline-block;
  margin: 0 0 15px 0;
}

.reaction_identifier .deja_abo label+input {
  width: 210px;
}

.reaction_identifier .deja_abo p>label {
  float: left;
}

.reaction_identifier .deja_abo p>label+a {
   float: left;
   margin: 14px 0 0 20px;
}

.reaction_redaction {
  overflow: hidden;
}

.reaction_redaction >div {
  margin: 0 16px;
   padding-top:10px;
}

.reaction_redaction label+.annotation{
  float: right;
}

.reaction_redaction  textarea {
  width: 495px;
  max-width: 495px;
  height: 144px;
  margin: 10px 0;
}

.reaction_redaction  textarea+p {
  margin: 10px 0 20px;
}

.reaction_redaction .signature input {
   width: 236px;
  margin: 0 10px;
}

.reaction_redaction .signature .modifier, .reaction_redaction .signature .annuler {
   cursor:pointer;
}

.reaction_redaction .signature .annuler {
   display:none;
}

.reaction_redaction .signature .alerte {
   display:none;
  float: right;
  width: 170px;
  margin: 5px 0 0;
  color: #464f57;
}

.liste_reactions .regles_conduite {
  margin: 20px 0 0;
}

.liste_reactions  .bloc_readaction ul {
  list-style-type: disc;
  margin: 10px 15px;
  font-size: 13px;
}

/*.liste_reactions .regles_conduite .ouvert, .liste_reactions .regles_conduite .ferme {
  background: url('/medias/web/img/pictos/fle_ouvert_ferme.png') no-repeat left 4px;
  color:#000;
  padding: 0 0 0 15px;
}

.liste_reactions .regles_conduite .ouvert {
  background-position: 0 -18px
}*/
/**********************************************/
/*** bloc par defaut ***/
/**********************************************/
.grid_12 .bloc_base {
   margin: 0 0 25px;
   border: solid #eef1f5;
  border-width: 0 1px 1px;

}

.grid_12  .bloc_base .entete {
   border-top: 3px solid #16212c;
   display: block;
   padding: 8px 16px 6px;
   font-weight: bold;
}

.grid_12  .bloc_base .contenu {
   padding: 0 16px;
}

/**********************************************/
/*** mÃªme sujet ***/
/**********************************************/
.bloc_base.meme_sujet, .bloc_base.appel_temoignage {
   margin-top: 16px;
}

.bloc_base.meme_sujet{
   padding: 0 0 16px;
   margin-bottom: 0;
   font-weight: bold;
}

.meme_sujet .liste_chevron li {
   padding: 8px 0;
}

.meme_sujet .entete_exclu_abonnes {
   margin: 8px 0;
}

.meme_sujet  .bt {
   margin: 8px 0 0;
   text-align: center;
}
/**********************************************/
/*** voir aussi ***/
/**********************************************/
.voir_aussi {
   overflow: hidden;
   clear: both;
   margin: 0 0 25px;
   border: solid #eef1f5;
  border-width: 0 1px 1px;
   color: #a2a9ae;
   font-weight: bold;
   font-size: 12px;
}

.voir_aussi .entrees_visible {
   overflow: hidden;
}

.voir_aussi .intitule {
   float: left;
   padding: 7px 9px 0;
}

.voir_aussi .entrees {
   float: left;
   width: 400px;
   height: 33px;
   line-height: 33px;
   padding: 2px 0 0;
   overflow: hidden;
}

.voir_aussi .obf, .voir_aussi a, .voir_aussi span {
   padding: 0 9px;
   color: #a2a9ae;
}

.voir_aussi .obf:hover, .voir_aussi a:hover {
   color: #464f57;
}

.voir_aussi   .az {
  float: right;
  padding: 10px 3px 10px 10px;
  height: 15px;
  font-size: 12px;
  line-height: 12px;
  font-weight: bold;
}

.voir_aussi   .az span {
   padding: 0;
}

.voir_aussi   .suite_entrees p {
   border-top: 1px solid #eef1f5;
   width: 100%;
}

/**********************************************/
/*** en savoir plus ***/
/**********************************************/
.fenetre {
   padding: 10px 16px;
   background: #f8f9fb;
   border: 1px solid #eef1f5;
   color: #16212c;
   margin: 0 0 25px;
}

/**********************************************/
/*** barre outils ***/
/**********************************************/
.article .toolbar {
   display:block;
   min-height: 30px;
   vertical-align:bottom;
   margin:0 0 13px;
   overflow:hidden;
}

.barre_outils {
   postion: relative;
   height: 28px;
   border: solid #eef1f5;
   border-width: 1px 0;
   line-height: 27px;
   font-size: 11px;
   font-weight: bold;
}

.barre_outils .bt_abo {
   float: left;
   height: 22px;
   margin: -1px 4px 0 0;
   border: solid #ccaa00;
   border-width: 1px 0;
   font-size: 10px;
   line-height: 11px;
   color: #665500;
}

.barre_outils span {
   display: inline-block;
   color: #747b83;
}

.barre_outils .outil:hover {
   cursor: pointer;
   background: #f1f5f8;
}


.barre_outils .outil {
   float: left;
   padding: 2px 6px 0;
   height: 25px;
   color: #747B83;
}

.barre_outils .partage {
   float: right;
   height: 26px;
   margin: 0;
   padding-left: 10px;
   border-left: 1px solid #eef1f5;
   color: #747b83;
}

.barre_outils .partage+span {
   height: 26px;
   vertical-align: middle
}

.barre_outils .reagir span{
  width: 12px;
  height: 11px;
  background: url('/medias/web/img/sprites/icos_petites.png') no-repeat 0 0;
  vertical-align: middle;
}

.barre_outils .classer  span{
  width: 11px;
  height: 11px;
  background: url('/medias/web/img/sprites/icos_petites.png') no-repeat 0 -12px;
  vertical-align: baseline;
}


.barre_outils .classer.actif span {
   background-position: -13px -12px;
}

.barre_outils .imprimer span{
  width: 12px;
  height: 12px;
  background: url('/medias/web/img/sprites/icos_petites.png') no-repeat 0 -25px;
  vertical-align: baseline;
}

.barre_outils .envoyer span{
  width: 12px;
  height: 10px;
  background: url('/medias/web/img/sprites/icos_petites.png') no-repeat -13px -25px;
  vertical-align: baseline;
}

.conteneur_barre_outils .reaction_identifier {
   margin: 0 0 20px 0;
  border-bottom: 3px solid #e9ecf0;
   border-top: none;
}

.conteneur_barre_outils  .non_abo.classer {
  background: url('/medias/web/img/textes/pas_le_temps_lire.png') no-repeat 16px 40px;
}

.conteneur_barre_outils p {
   margin: 0;
}

/* Facebook like */

.article .fb-like{
   height:25px;
   overflow:hidden;
   opacity:0;
}
/* ----- start file /partenaires.css ----- */
.bloc_part .saisie {/* styles pour input text et autres champs de saisie - duplication de base.css */
  background-color: #f8f9fb;
  /*-webkit-box-shadow: inset 3px 3px 3px 5px rgba(250, 250, 250, 0.2), 0 -1px 1px rgba(0, 0, 0, 0.2);
    -moz-box-shadow: inset 3px 3px 3px 5px rgba(250, 250, 250, 0.2), 0 -1px 1px rgba(0, 0, 0, 0.2);
        box-shadow: inset 3px 3px 3px 5px rgba(250, 250, 250, 0.2), 0 -1px 1px rgba(0, 0, 0, 0.2);*/
  border: 1px solid #b9c0c5;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  padding: 2px 3px;

   /*font-size: 1.2em;*/
}

.bloc_part {
   border: 1px solid #eef1f5;
   overflow:hidden;
   line-height: 120%;
   position:relative;
}

.services .bloc_part.grid_6, .services .bloc_part.grid_12 {
   margin-left: 16px;
   margin-right: 0;
}

.services .bloc_part.grid_6:first-child {
   margin-left: 0;
}

.col_droite .bloc_part {
   margin: 0 0 25px;
}

.global.services .bloc_part:first-child {
   margin-left: 0;
}

.bloc_part .contenu {
   overflow: hidden;
}

.bloc_part .entete {
   background: #2e3942;
   height: 23px;
   line-height: 23px;
   padding: 0 15px;
   text-align:right;
}

.bloc_part .entete .intitule {
   font-family: 'FetteEngschrift','Arial Narrow',sans-serif;
   text-transform: uppercase;
   color: #fff;
   font-size: 15px;
   float:left;
}

.bloc_part .entete .nom {
   float: right;
   color: #eef1f5;
}

.bloc_part .accroche  {
   display: block;
   margin: 0 0 8px 0;
}

.bloc_part .promo {
   color: #fe2f2f;
}

.bloc_part .texte, .bloc_part.petit .texte {
   position: relative;
   padding-top: 12px;
   height: 182px;
   float: left;
   color: #16212c;
}

.bloc_part.petit .texte {
   height: 118px;
}

.bloc_part .texte.large {
   padding-top: 25px;
   padding-right: 23px;
}

.col_droite .bloc_part .img {
   float: left;
   width: 156px;
}

.col_droite .bloc_part .texte {
   float: left;
   width: 141px;
}


.bloc_part .btn_fonce, .bloc_part .btn {
   position: absolute;
   bottom: 15px;
}


.bloc_part  .agauche {
   left: 0;
}

.bloc_part .texte .btn_fonce {
   color:#fff;
}

.bloc_part .texte .btn{
   color:#000b15;
}

.bloc_part  .footer {
   clear: both;
   height: 21px;
   padding: 4px 15px 0;
   text-align: right;
   background: #eef1f5;
   color: #5d666d;
   font-size: 11px;
   font-weight: bold;
}


.bloc_part  .logo_header {
   height: 21px;
   color: #b9c0c5;
   font-size: 11px;
   font-weight: normal;
   float: right;

}

.bloc_part  .footer span, .bloc_part  .footer img {
   vertical-align: middle;
}

.bloc_part  .footer img {
   margin: 0 0 0 5px;
}

/*** attractive ***/
.bloc_part  .contenu.attractive {
   background: #e4e6e9;
}

.global .bloc_part .bandeau {
   height: 24px;
   padding: 0 15px;
   background: #d2d6db !important;
   color: #16212c;
   line-height: 22px;
   white-space:nowrap;
   overflow:hidden;
}

.bloc_part .attractive.carrousel_petit .texte {
   width: 125px;
   height: 150px;
}

/*.bloc_part .attractive.carrousel_grand .texte {

}*/


/**  Ajout pour le format texte attractive */


.bloc_part.attractive .texte{
   height: 52px;
}


.bloc_part.attractive.format-text .texte{
   padding: 0 15px 12px;
}


.bloc_part.attractive.format-text.chiffre .texte{
   width: 284px;
}

.bloc_part.attractive.format-text.exigeant .texte{
   padding: 0 15px 9px;
   width: 190px;
}

.bloc_part.attractive.format-text.exigeant .btn_fonce {
   margin: 0 0 26px 57px;
}

.bloc_part.attractive.format-text.exigeant.grid_6 .btn_fonce{
   margin: 0 ;
   right : 15px;
}

.bloc_part.attractive.text{
   height: 208px;
}

.bloc_part.attractive.temoignage .img, .bloc_part.attractive.escapade .img{
   margin-right: 0 ;
   padding: 15px 0 15px 15px;
}

.bloc_part.attractive.temoignage.petit .img{
    margin-right: 0 ;
    padding: 15px 0 15px 15px;
}


.bloc_part.attractive.temoignage .texte, .bloc_part.attractive.escapade .texte{

   height: 166px;
   margin : 0;
   width : 142px;
}

.bloc_part.attractive.temoignage.petit .texte{

    height: 108px;
}

.bloc_part.attractive.temoignage.petit .texte{

    height: 108px;
}

.bloc_part.attractive.text{
   height: 208px;

}

.bloc_part.attractive.format-text .img img{
   padding: 15px 15px 9px;
}


/***********************************************/


/*** gymglish ***/
.services .bloc_part.gymglish.grid_12, .services .bloc_part.darqroom.grid_12.promo {
   background-color: #e9ecf0;
   background-image: -moz-linear-gradient(top, #fff, #e9ecf0);
   background-image: -ms-linear-gradient(top, #fafbfc #e9ecf0);
   background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#fafbfc), to(#e9ecf0));
   background-image: -webkit-linear-gradient(top, #fafbfc, #e9ecf0);
   background-image: -o-linear-gradient(top, #fafbfc, #e9ecf0);
   background-image: linear-gradient(top, #fff, #e9ecf0);
   background-repeat: repeat-x;
   filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fafbfc', endColorstr='#e9ecf0', GradientType=0);
}


/**
*   CM:  le bloc ci-dessous permet de ne pas mettre les options background ci dessus sur les blocs simples
*/

.services .bloc_part.gymglish.grid_6 {
   background: none;
}

.bloc_part.gymglish .contenu {
   padding: 12px 15px 0;
   height: 182px;
   box-sizing: border-box;
   -moz-box-sizing: border-box;
   -webkit-box-sizing: border-box;
   overflow: hidden;
   clear: both;
}


.bloc_part.gymglish .exercice .texte, .bloc_part.gymglish .mot_mois .texte {
   width: 166px;
   height: 126px;
   padding: 0;
}

.bloc_part.gymglish .mot_mois .texte {
   width: 155px;
   padding: 4px 15px 0 0;
}


.bloc_part.gymglish .cours .texte {
   width: 145px;
   height: 170px;
   padding: 0 15px 0 0;
}


.bloc_part.gymglish .cours .img{
   width: 120px;
}

.bloc_part.gymglish .mot_mois .enonce {
   display: block;
   overflow: hidden;
   height: 45px;
   clear: both;
}

.bloc_part.gymglish .exercice.contenu {
   position: relative;
   background: #FFFFFF;
}

.bloc_part.gymglish .exercice.contenu .btn_fonce{
   left: 16px;
}

.bloc_part.gymglish .exercice .enonce {
   display: block;
   overflow: hidden;
   min-height: 25px;
   clear: both;
}


.bloc_part.gymglish .exercice .img, .bloc_part.gymglish .cours .img  {
   width: 110px;
   float: right;
}

.bloc_part.gymglish label {
   display: block;
   margin: 5px 0;
}


/**
*   CM les 4 declarations suivantes permettent d'aligner le bouton gymglish en zone service et en col droite
*/



.services .bloc_part.gymglish .contenu.citation .btn_fonce{
   bottom: 13px;
   margin: 0px 0 0px 13px;
}

.col_droite .bloc_part.gymglish .contenu.citation .btn_fonce{
   margin: 0 0 0px 13px;
   bottom: 48px;

}

.bloc_part.gymglish .contenu.citation .btn_fonce{
   margin: 0 0 0px 13px;
   bottom: 43px;
}

.bloc_part.gymglish .contenu.mot_mois .btn_fonce{
   bottom: 45px;
   left: 15px;
}

.services .bloc_part.gymglish .contenu.mot_mois .btn_fonce{
   bottom: 16px;
   left: 15px;
}

.bloc_part.gymglish .contenu.mot_mois {
   bottom: 42px;
   left: 15px;
   height: 143px;
}

.bloc_part.gymglish .contenu.mot_mois .img{
   width: 110px;
   float: right;
   margin: 4px 0px;

}
/*************************************************************/


/*** empruntis ***/

.bloc_part.empruntis  .contenu {

   padding: 0 15px 0;
   background: url('/medias/web/img/partenaires/empruntis/stylo.jpg') no-repeat;
}

.bloc_part.empruntis .contenu .texte {
   box-sizing: border-box;
   -moz-box-sizing: border-box;
   -webkit-box-sizing: border-box;
   width: 190px;
   color: #16212c;
}

.bloc_part.empruntis .contenu .texte strong {
   display: block;
   color: #16212c;
}

.bloc_part.empruntis .contenu .texte .lien_chevron {
   display: block;
   color: #a2a9ae;
   font-weight: bold;
   color: #16212c;
}

.bloc_part.empruntis .footer img{
   margin-top: -10px
}

/*** darqroom ***/
.bloc_part.darqroom, .bloc_part.darqroom .texte {
   background: #000;
   color: #fff;
}

.bloc_part.darqroom .footer {
   background: #16212c;
}

.bloc_part.darqroom .footer img{
   margin-top: -3px
}

.bloc_part.darqroom.grid_12.promo .texte {
   background: none;
   color: #16212c;
}



/*** homelidays***/
.bloc_part .homelidays  {
   padding: 0px 0px 0px;
}

.footer .homelidays  {
   margin-top: -3px ;
}

/*** immostreet - la centrale  ***/
.bloc_part.immostreet .annonce, .bloc_part.la_centrale .annonce {
   display: table-cell;
   width: 85px;
   font-size: 10px;
   line-height: 13px;
   color: #5d666d;
}

.bloc_part.la_centrale .annonce .modele, .bloc_part.la_centrale .annonce .prix {
   display: block;
}

.bloc_part.la_centrale .annonce .modele {
   color: #003366;
   text-transform: uppercase;
   font-size: 10px;
   line-height: 11px;
   font-weight: bold;
}

.bloc_part.la_centrale .annonce .prix {
   color: #5d666d;
}

.bloc_part.immostreet .annonce:hover, .bloc_part.la_centrale .annonce:hover {
   color: #129AF0;
}

.bloc_part.immostreet .annonces .annonce, .bloc_part.la_centrale .annonces .annonce  {
   padding-left: 13px;
}

.bloc_part.immostreet .annonces .annonce:first-child, .bloc_part.la_centrale .annonces .annonce:first-child {
   padding-left: 0;
}

.bloc_part.immostreet .recherche, .bloc_part.la_centrale .recherche {
   border-top: 1px solid #eef1f5;
}

.bloc_part.immostreet .recherche .contenu, .bloc_part.la_centrale .recherche .contenu{
   padding-top: 10px;
}

.bloc_part.immostreet .recherche label {
   width: 75px;
   margin: 0 20px 0 0;
   font-size: 11px;
   font-weight: bold;
}

.bloc_part.immostreet .recherche .saisie.cp {
   padding: 0 7px;
   width: 60px;
   height: 19px;
   font-size: 11px;
   line-height: 15px;
}


.bloc_part .criteres {
   margin-top: 7px;
   postion: relative;
}

.bloc_part.immostreet .recherche .criteres .saisie {
   padding: 0 7px;
   width: 100px;
   height: 19px;
   font-size: 11px;
   line-height: 15px;
}

.bloc_part.immostreet .recherche .criteres .btn, .bloc_part.la_centrale .recherche .criteres .btn  {
   height: 15px;
   font-size: 10px;
}

.bloc_part.la_centrale .contenu, .bloc_part.immostreet .contenu  {
   padding: 12px 15px 10px;

}

.bloc_part.la_centrale .recherche select{
   width: 130px;
   font-size: 10px;
}

.bloc_part.la_centrale .recherche .saisie {
   width: 65px;
   font-size: 10px;
}

.bloc_part.la_centrale .recherche .saisie:first-child {
   width: 122px;
}


.bloc_part.la_centrale .recherche select:first-child, .bloc_part.la_centrale .recherche .saisie {
   margin-right: 14px;
}

.bloc_part.la_centrale.petit img{
    margin-right: 0;
}

.bloc_part.la_centrale.petit{
    margin: 21px 0 13px;
}

/*le guide /shopping*/

.bloc_part .le_guide .footer img{
   margin-top: -3px
}

.bloc_part.leguide{
   border: 0;
}


/*** talents ***/
.bloc_part.talents .contenu {
   padding: 12px 15px 5px;
}

.bloc_part.talents a+span {
   display: block;
   margin: 3px 0 8px;
}

.bloc_part.talents .saisie {
   width: 240px;
}


/*** quotatis ***/
.bloc_part.quotatis .contenu  {
   padding: 12px 15px 5px;
}

.bloc_part.quotatis .contenu  .bg {
   width: 282px;
   height: 91px;
   background: url(/medias/web/img/partenaires/quotatis/travaux.jpg);
   text-align: center;
}

.bloc_part.quotatis .contenu  .btn_fonce {
   position: relative;
   top: 50px;
}

.bloc_part.quotatis .saisie {
   width: 240px;
}

.bloc_part.quotatis .footer img {
   margin-top: -3px;
}


.quotatis .contenu.bord_top1_gris{
   border: 0;

}


.bloc_part.wineandco .footer img{
   vertical-align: text-top;
}

.bloc_part.wineandco .img.grid_3.alpha{

   margin-right: 0px;
}
/*** carroussel ***/

.bloc_part  .contenu.carrousel_petit, .bloc_part .contenu.carrousel_grand  {
   position: relative;
   width: 644px;
   height: 182px;
   overflow: hidden;
   padding: 0;
}

.bloc_part  .contenu.carrousel_petit {
   width: 312px;
}

.bloc_part  .contenu.carrousel ul {
   width: 10000px;
}

.bloc_part  .contenu.carrousel li {
   overflow: hidden;
   float: left;
}

.bloc_part .contenu.carrousel_petit li {
   height: 182px;
   width: 312px;
}

.bloc_part .contenu.carrousel_grand li {
   height: 182px;
   width: 642px;
}


.bloc_part  .contenu.carrousel  .prev, .bloc_part  .contenu.carrousel .next {
   display: block;
   width: 13px;
   height: 21px;
   text-shadow: 0 1px 1px rgba(255, 255, 255, 0.75);
   background-color: #fafafa;
   background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#fefefe), color-stop(25%, #fefefe), to(#e4e6e9));
   background-image: -webkit-linear-gradient(#fefefe, #fefefe 25%, #e4e6e9);
   background-image: -moz-linear-gradient(top, #fefefe, #fefefe 25%, #e4e6e9);
   background-image: -ms-linear-gradient(#fefefe, #fefefe 25%, #e4e6e9);
   background-image: -o-linear-gradient(#fefefe, #fefefe 25%, #e4e6e9);
   background-image: linear-gradient(#fefefe, #fefefe 25%, #e4e6e9);
   background-repeat: no-repeat;
   filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fefefe', endColorstr='#e4e6e9', GradientType=0);
   font-size: 21px;
   line-height: 15px;
   color: #2e3942;
}

.bloc_part  .contenu.carrousel  .prev:hover, .bloc_part  .contenu.carrousel  .next:hover {
   color: #2e3942;
   text-decoration: none;
   background-color: #e4e6e9;
   background-position: 0 -15px;
   -webkit-transition: background-position 0.1s linear;
   -moz-transition: background-position 0.1s linear;
   -ms-transition: background-position 0.1s linear;
   -o-transition: background-position 0.1s linear;
   transition: background-position 0.1s linear;
   cursor: pointer;
}

.bloc_part  .contenu.carrousel .prev {
   position: absolute;
   left: 0;
   top: 46%;
   border: solid #d2d6db;
   border-width: 1px 1px 1px 0;
   text-align: left;
   padding-left: 7px;
}

.bloc_part  .contenu.carrousel .next {
   border: solid #d2d6db;
   border-width: 1px 0 1px 1px;
   position: absolute;
   right: 0;
   top: 46%;
   text-align: right;
   padding-right: 7px;
}
/* ----- start file /col_droite.css ----- */
.col_droite .bloc_base {
   margin: 0 0 25px;
   border: solid #eef1f5;
  border-width: 0 1px 1px;
   background: #fafbfc;
   overflow:hidden;
}

.col_droite .bloc_base .entete {
   display: block;
   padding: 8px 16px 6px;
   border-top: 3px solid #16212c;
   border-bottom: 1px solid #eef1f5;
   font-weight: bold;
}
.col_droite .twtr-widget h3 {
   font-family:arial, sans-serif !important;
   line-height: 120% !important;
   font-size:1.5rem !important;
   display: block !important;
   padding: 8px 16px 6px !important;
   border-top: 3px solid #16212C !important;
   border-bottom: 1px solid #eef1f5 !important;
   font-weight: bold !important;
}
.col_droite .twtr-widget .twtr-doc {
   -moz-border-radius:0 !important;
   -webkit-border-radius:0 !important;
   border-radius:0 !important;
}
.col_droite .twtr-widget .twtr-hd {
   padding:0 !important;
}
.col_droite .twtr-widget .twtr-join-conv {
   color:#036 !important;
   text-decoration: none !important;
   font-weight:bold !important;
}
.col_droite .twtr-widget .twtr-join-conv:hover, .col_droite .twtr-widget .twtr-join-conv:focus, .col_droite.twtr-widget .twtr-join-conv:active {
   color:#129AF0 !important;
}
.col_droite .twtr-widget .twtr-join-conv::before {
   color:#16212C;
   content: '\203A';
   font-family: arial;
   display: inline-block;
   font-size: 13px;
   margin-right:3px;
   left: 0;
   position: relative;
   width: 7px;
   font-weight: normal;
}

.col_droite .bloc_base .footer {
   height: 21px;
   padding: 4px 15px 0;
   text-align: right;
   background: #eef1f5;
   color: #5d666d;
   font-size: 11px;
   font-weight: bold;
}

.col_droite .bloc_base  .footer span, .col_droite .bloc_base  .footer img {
   vertical-align: middle;
}

.bloc_part  .footer img {
   margin: 0 0 0 5px;
}

.col_droite .bloc_element  {
   overflow: hidden;
   margin: 0 0 25px;
}

.col_droite .bloc_element  img {
   display: block;
}

.col_droite .bloc_element .ligne_titre {
   display: block;
   overflow: hidden;
   position: relative;
   border-top: 3px solid #16212c;
   border-bottom: 1px solid #eef1f5;
   border-left: 1px solid #eef1f5;
   background: #e9ecf0;
}

.col_droite .bloc_element .titre {
   float: left;
   width: 238px;
   padding: 8px 16px 6px;
   border-right: 1px solid #fff;
   background: #fafbfc;
}

.col_droite .bloc_element .element:hover .titre {
   background: #e9ecf0;
}

.col_droite .bloc_element .fleche {
   display: block;
   float: right;
   width: 42px;
   border-left: 1px solid #e4e6e9;
}

.col_droite .bloc_element .fleche  {
   position: absolute;
   right: 13px;
   top: 33%;
   background: url('/medias/web/img/sprites/icos_petites.png') no-repeat -1px -108px;
  width: 13px;
  height: 22px;
}


.col_droite .bloc_element .element:hover .fleche  {
   background-position: -15px -108px;
}


.contenu_bloc_droit {
  padding: 7px 16px 10px;
  overflow: hidden;
}

.contenu_bloc_droit .liste_chevron li {
   padding: 8px 0 6px;
}

.col_droite .liste_img_lien  figure, .col_droite .liste_img_lien  figcaption {
  height: auto;
}

.col_droite .bt_abo  {
  width: 280px;
}

.col_droite .bloc_abonnes .bt_abo {
   margin:10px 0 0;
   text-align:center;
}

.col_droite .bulle_nombre {
  float: right;
  display: block;
}

.col_droite .plus_partages, .col_droite .sociaux {
  margin: 0 0 20px;
  background: #fafbfc;
  border: solid #eef1f5;
  border-width: 0 1px 1px;
  overflow: hidden;
}

.col_droite .plus_partages .entete, .col_droite .sociaux .entete  {
   padding: 0 15px;
   line-height: 25px;
   color: #fff;
   background: #3b5998;
   font-weight: bold;
}


.col_droite .sociaux .entete  {
   background: #5d666d;
}

.col_droite .plus_partages ul{
   overflow:hidden;
}

.col_droite .plus_partages li{
  overflow: hidden;
  padding: 10px 15px;
  border-top: 1px solid #eef1f5;
   line-height: 120%;
}

.col_droite .plus_partages li:first-child {
  border-top: 0;
}

.col_droite .plus_partages .bulle_nombre, .col_droite .plus_partages .numero {
  margin: 2px 0 0 0;
  text-align: center;
}

.col_droite .plus_partages .numero {
  float: left;
  width: 15px;
  height: 14px;
  background: #e9ecf0;
  color: #a2a9ae;
  font-size: 11px;
  line-height: 15px;
}

.col_droite .plus_partages .texte{
  float: left;
  width: 190px;
  padding: 0 10px 0 8px;
}

.col_droite .sociaux .pictos {
  overflow: hidden;
  margin: 10px 15px;
}

.col_droite .sociaux .pictos span.text {
  float: left;
  width: 130px;
  padding: 0 15px 0 0;
  color: #464f57;
   line-height: 120%;
}



/**********************************************/
/*** bloc recherche / elections***/
/**********************************************/
.col_droite .recherche_resultat_pres.bloc_base {
   background: #0b0423 url('/medias/web/img/evenementiel/presidentielle_2012/bg_recherche_elections_col_droite.png') center 0 no-repeat;
   color: #fff;
}

.col_droite .boite_recherche {
   background: none;
   padding: 8px 16px 10px;
}

.col_droite .recherche_resultat_pres.bloc_base .entete {
   border-top: 0!important;
   border-bottom: 0!important;
   padding-top: 16px;

}

.col_droite .recherche_resultat_pres .entete span {
   display:inline-block;
   height: 30px;
   background: url('/medias/web/img/textes/elections/bulle_2012_39x27_bg_fonce.png') no-repeat;
   padding-left: 50px;
}

.col_droite .recherche_resultat_pres .moteur_commune {
   width: 274px;
}


 .col_droite .boite_recherche p {
   margin: 8px 0;
   clear: both;
}

.col_droite .boite_recherche .saisie {
   width: 239px;
   float: right;
}

.col_droite .boite_recherche .saisie:first-child {
   width: 274px;
   float: none;
}

.col_droite .boite_recherche .bord_double_gris_blanc {
   margin: 0;
}

/**********************************************/
/*** bloc abonnes / JE ***/
/**********************************************/

.col_droite .bloc_abonnes {
  margin-bottom: 25px;
  border: solid #eef1f5;
  border-width: 0 1px 1px;
  background: #fafbfc;
}

.col_droite .plus {
  font-weight: bold;
}

.col_droite .bloc_abonnes .bt {
  text-align: center;
  margin: 10px 0;
}

.col_droite .plus span {
  color: #747b83;
  font-size: 110%;
  line-height: 1;
}

.col_droite .entete_abonnes {
  padding-left: 16px;
  padding-right: 16px;
  font-size: 1.5rem;
  line-height: 100%;
}

.ie .col_droite .entete_abonnes {
  font-size: 15px;
}

.col_droite .avatar {
  display: block;
  float: left;
  width: 39px;
  margin: 0 11px 0 0;
}

.col_droite .avatar img {
  border: 1px solid #eef1f5;
}

.col_droite .avatar+p {
  float: left;
  width: 220px;
}

.col_droite .abonne-activite {
  overflow-y: scroll;
  height: 200px;
  padding: 10px 5px 10px 16px;
  border-bottom: 1px solid #eef1f5
}
.col_droite .abonne-activite li {
  margin: 0 0 16px;
  overflow: hidden;
  color: #5d666d;
}

.col_droite>div:last-child {
   margin-bottom:0 !important;
}


/*** previsuel de couv type bloc EA JE, bloc EA Education */
.previsu {
  padding:10px;
  text-align:center;
  zoom:1;
}

.previsu .date_couv {
  display: block;
  font-size:13px;
  color:#646464;
}

.previsu_contenu {
  text-align: left;
  margin: 10px 0 0;
  color: #222
}

/**********************************************/
/*** blocs abonne ***/
/**********************************************/
/*** presentation couvertures ***/
.previsu_contenu li {
  margin: 0 0 3px
}
.previsu_contenu  .date {
  text-transform: uppercase;
  font-size: 10px;
  color: #666
}

.previsu .lire {
  font-size: 16px;
  font-weight: bold;
  margin: 0 0 5px;
  display: inline-block
}
.previsu +.contenu {
  border-top: 1px solid #e6e7e8
}

/*** blocs promo journal une ***/
.bloc_je {
  margin-bottom:20px
}

.bloc_je .bt_push_abo {
  margin-top:15px;
}
.bloc_je .liste_ensembles  {
  font-size: 15px
}

.bloc_je .annonce {
  display: block;
  padding: 8px 9px;
  background: #2e3942;
  color: #fff;
}

.bloc_je .annonce .intro {
  display: block;
  text-transform: uppercase;
  font-weight: bold;
}

.bloc_je .previsu .bt_blanc_gris_32 {
  margin: 20px 0 0
}

.bloc_je .tt_dossier_meilleur_monde {
  background:url('/medias/www/img/tit/tt_dossiers_meilleur_monde.png') left center no-repeat;
  display: block;
  width: 250px;
  margin: 0 9px;
  font-size: 13px;
  color: #222;
  text-indent: -9999px
}

.bloc_je .centrer {
   color: #747b83;
}

.bloc_couvs {
  position:relative;
  margin:10px auto 3px;
}

.bloc_couvs a {
   cursor:pointer;
  display:block;
  width:208px;
  left:35px;
  height:145px;
  overflow:hidden;
  border:solid 1px #e7e7e7;
  box-shadow:0 0 3px #e7e7e7;
  position:absolute;
}

/* default / une page / pas de sup */

.bloc_couvs.bloc_1_couv {
  height:145px;
}
.bloc_couvs .couv_petite {
  width:146px;
  height:74px;
}
.bloc_couvs b {
  top:146px;
  display:block;
  width:280px;
  height:44px;
  background:url('/medias/www/img/plus_une_lemonde.png') left center no-repeat;
  position:relative;
}

/* deux pages / un sup */
.bloc_couvs.bloc_2_couv {
  width:247px;
  height:185px;
}

.bloc_couvs.bloc_2_couv a {
  left:0;
}

.bloc_couvs.bloc_2_couv .couv_petite {
  left:auto;
  top:auto;
  right:0;
  bottom:0;
}

.bloc_couvs.bloc_2_couv b {
  right:153px;
  top:153px;
  width:15px;
  height:15px;
  background:url('/medias/www/img/plus_une_lemonde.png') right center no-repeat;
  position:absolute;
}

/* trois pages / deux sups */
.bloc_couvs.bloc_3_couv {
  width:280px;
  height:278px;
}

.bloc_couvs.bloc_3_couv .couv_petite {
  width:125px;
  height:86px;
  right:auto;
  top:auto;
  left:0;
  bottom:0;
}
.bloc_couvs.bloc_3_couv .couv_petite.petite_1 {
  left:auto;
  right:0;
}
/* cinq pages / quatre sups */
.bloc_couvs.bloc_pls_couv {
  width:280px;
  height:317px;
}
.bloc_couvs.bloc_pls_couv .couv_focus {
  width:105px;
  height:126px;
  top:auto;
  right:auto;
  left:0;
  bottom:2px;
}
.bloc_couvs.bloc_pls_couv .couv_petite {
  width:125px;
  height:86px;
  top:auto;
  left:auto;
  right:36px;
  bottom:42px;
}
.bloc_couvs.bloc_pls_couv .couv_petite.petite_2 {
  right:18px;
  bottom:21px;
}
.bloc_couvs.bloc_pls_couv .couv_petite.petite_3 {
  right:0;
  bottom:0;
}
.nouveau_weekend {
   font-weight:bold;
   border-bottom:solid 1px #E6E7E8;
}
.nouveau_weekend strong {
  display:block;
  margin:0 0 3px;
  text-transform:lowercase;
  font-variant:small-caps;
  font-family:georgia, serif;
  font-size:1.1em;
}

.nouveau_weekend span {
  display:inline-block;
  margin:0 1px 0 0;
  padding:0 4px 1px;
  background:#bb0102;
  color:#fff;
  font-family:arial, sans-serif;
  font-size:0.85em;
}

.titres_journal {
  padding:10px;
  border-top:solid 1px #e6e7e8;
  text-align:left;
  background:#fff;
}

.titres_journal .bull_gris_petit li {
  margin-bottom:2px;
}

.titres_journal .fle_abo {
    font-size: 15px;
    margin-bottom: 3px;
    font-weight: bold;
    padding-left: 14px;
}
/* ----- start file /ticker.css ----- */
/*
** Live
*/
#bandeau_bas{/*** conteneur general live + ticker ***/
   z-index: 2147483647;
   position:fixed;
   bottom:0;
   width:100%;
   height: 25px;
  border-bottom: 1px solid #000;
  background: #000b15;
  color: #fff;
}

#bandeau_bas .conteneur_en_continu{/*** conteneur ticker ***/
   position:relative;
   margin:auto;
   width:1000px;
   height:25px;
   font-size:12px;
   line-height:25px;
   color:#fff;
   z-index:1;
}

#bandeau_bas .conteneur_en_continu .tetiere {
   display: inline-block;
   width: 71px;
   height: 25px;
   margin-right: 13px;
   background: url('/medias/web/img/textes/ticker_en_continu.png');
   text-indent: -9999px;
}

#bandeau_bas .conteneur_en_continu .heure {
  margin: 0 10px 0 0;
  font-weight: bold;
}

#bandeau_bas > span {
   vertical-align: middle;
}


/*** live ***/
#bandeau_bas a {
   color:white;
}

#bandeau_bas .conteneur_lives {
   position:relative;
   z-index:2;
}

.conteneur_lives .lives {
   position:absolute;
   bottom:0px;
   right:0px;
   color: #fff;
}

#bandeau_bas .conteneur_lives .lives {
   -webkit-box-shadow: -3px 4px 15px -0 rgba(0, 11, 21, 0.5);
      -moz-box-shadow: -3px 4px 15px -0 rgba(0, 11, 21, 0.5);
           box-shadow: -3px 4px 15px -0 rgba(0, 11, 21, 0.5);
}

.conteneur_lives.popuped .lives {
   position:relative;
}

.conteneur_lives .live {
   width:328px;
   right:0px;
   background-color:#F6F6F6;
}

.conteneur_lives .live .bandeau {
   height: 25px;
   width: 320px;
   padding-right: 8px;
   overflow: hidden;
   line-height: 23px;
   cursor:pointer;
   background-color: #f5f5f5;
   background-image: -moz-linear-gradient(top, #d20303, #bf0202);
   background-image: -ms-linear-gradient(top, #d20303, #bf0202);
   background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#d20303), to(#bf0202));
   background-image: -webkit-linear-gradient(top, #d20303, #bf0202);
   background-image: -o-linear-gradient(top, #d20303, #bf0202);
   background-image: linear-gradient(top, #d20303, #bf0202);
   background-repeat: repeat-x;
   filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#d20303', endColorstr='#bf0202', GradientType=0);
}


.conteneur_lives .live.petit .bandeau:hover{
   background-color: #fe2f2f;
   background-position: 0 -25px;
  -webkit-transition: background-position 0.06s linear;
  -moz-transition: background-position 0.06s linear;
  -ms-transition: background-position 0.06s linear;
  -o-transition: background-position 0.06s linear;
  transition: background-position 0.06s linear;
  cursor: pointer;
}

.conteneur_lives .live .bandeau .titre  {
   float:left;
   padding: 0 7px;
   width: 220px;
   font-family: arial, sans-serif;
   font-size: 13px;
   font-weight: bold;
}

.conteneur_lives .lives .chrome .titre {
   float:left;
   width: 230px;
   height: 25px;
   overflow: hidden;
   color:white;
   text-align: left;
   font-weight: bold;
   font-family: arial, sans-serif;
   font-size: 13px;
   line-height: 25px;
}

.conteneur_lives .lives .chrome .titre  .tt_live {
   display: inline-block;
   width: 20px;
   height: 10px;
   margin: 0 5px 0 16px;
   text-indent: -9999px;
   background: url('/medias/web/img/sprites/icos_live.png') -162px 0;
}

/* devient visible quand il y a quelquechose
 * Ã  afficher */
.conteneur_lives .lives .chrome {
   background: #d50303 url('/medias/web/img/textes/tt_live_bas.png') no-repeat;
   height: 25px;
   line-height: 23px;
   padding: 0 5px 0 40px;
   display:none;
   width:283px;
   cursor:pointer;
}

.conteneur_lives .lives.grand .chrome {
   background-color: #000b15;
}

.conteneur_lives.popuped .lives .chrome {
   cursor:default;
}

.conteneur_lives .lives .chrome a, .conteneur_lives .live .bandeau .voir {
   display: inline-block;
   text-decoration:none;
   float:right;
   margin: 4px 0 0 5px;
   height: 15px;
   width: 14px;
}

/*** pictos bandeau live ***/
.conteneur_lives .live .bandeau .voir, .conteneur_lives .lives .chrome .live_replier,  .conteneur_lives .lives .chrome .popup,
.conteneur_lives .lives .chrome .live_deplier, .conteneur_lives .lives .chrome .live_fermer {
   background-image: url('/medias/web/img/sprites/icos_live.png');
}


.conteneur_lives .live .bandeau .voir {
   height: 13px;
   background-position: -113px 0;
}

.conteneur_lives .live.grand .bandeau .titre a {
   text-decoration:underline;
}

.conteneur_lives .lives .chrome .live_replier, .conteneur_lives .lives.grand .chrome .live_replier:hover  {
   background-position: -17px -5px;
}

.conteneur_lives .lives .chrome .live_replier:hover {
   background-position: -67px -5px;
}

.conteneur_lives .lives .chrome .popup, .conteneur_lives .lives.grand  .chrome .popup:hover  {
   background-position: -34px 0 ;
}

.conteneur_lives .lives .chrome .popup:hover {
   background-position: -83px 0;
}

.conteneur_lives .lives .chrome .live_deplier, .conteneur_lives .lives.grand  .chrome .live_deplier:hover {
   background-position: -17px 0;
}

.conteneur_lives .lives .chrome .live_deplier:hover {
   background-position: -67px 0;
}

.conteneur_lives .lives .chrome .live_fermer, .conteneur_lives .lives.grand   .chrome .live_fermer:hover {
   width: 10px;
   background-position: -131px 1px;
}

.conteneur_lives .lives .chrome .live_fermer:hover {
   background-position: -147px 1px;
}

.conteneur_lives .lives.grand .chrome .live_replier, .conteneur_lives .lives.grand  .chrome .popup,
.conteneur_lives .lives.grand  .chrome .live_deplier, .conteneur_lives .lives.grand   .chrome .live_fermer {
   opacity: 0.6;
}

.conteneur_lives .lives.grand .chrome .live_replier:hover, .conteneur_lives .lives.grand  .chrome .popup:hover ,
.conteneur_lives .lives.grand  .chrome .live_deplier:hover , .conteneur_lives .lives.grand   .chrome .live_fermer:hover  {
    opacity: 1;
}

.conteneur_lives .lives .chrome .aide {
   display:none;
}


.conteneur_lives .live .toast {/*** conteneur d'un live / iframe ***/
   padding: 10px 20px;
   background: #16212c;
   color: #fff;
   width:288px;
}

.conteneur_lives .live.petit .toast, .conteneur_lives .live.petit .cil {
   display:none;
}

.conteneur_lives .live.moyen .cil, .conteneur_lives .live.moyen .bandeau {
   display:none;
}

.conteneur_lives .live.grand .bandeau {
   cursor:default;
}

.conteneur_lives .live.grand .cil {
   padding: 0;line-height:0px;
   width:328px;
}
.conteneur_lives .live.grand .toast {
   display:none;
}

.conteneur_lives .live .toast .heure {
   float: left;
   font-size: 10px;
   color: #8b9299;
}

.conteneur_lives .live .toast .details {
   margin-left: 35px;
   height:75px;
   overflow:hidden;
   font-size: 12px;
   line-height: 120%;
   color: #fff;
}

.conteneur_lives .live .toast .details a {
   color: #fff;
}

.conteneur_lives .live .toast .details a:hover {
   text-decoration: underline;
}

#bandeau_bas .conteneur_lives .live .toast .btn {
   position:absolute;
   display:none;
   color: black;
   height: 18px;
   font-size: 10px;
   line-height: 18px;
   top:90px;
   left:200px;
   width:100px;
}

#bandeau_bas .conteneur_lives .live:hover .toast .btn {
   display:block;
}

/*** posisionnements du live ***/
.conteneur_lives .live.invisible {
   display: none;
}


/**
*** MEDIA
**/

/* grand ecran : live collÃ© Ã  l'extÃ©rieur droit de la page */
@media screen and (min-width: 1640px) {
   .conteneur_lives {
      width:0px;
      margin:auto;
   }
   .conteneur_lives .lives {
      left:500px;
   }
}
/**********************************************/
/*** ALERTE ***/
/**********************************************/

.conteneur_alerte {
   background: #2e3942;
   margin: 0 auto;
   position: relative;
   width: 1000px;
   height: 120px;/*hauteur totale */
   z-index: 3;
}

.conteneur_alerte.invisible {
   display: none;
   top: 0px;
}

.conteneur_alerte.visible {
   top: -120px;
}

.conteneur_alerte .bandeau {
   overflow: hidden;
   height: 15px;
   padding: 5px 12px;
   background: #CB2626;
   color: #fff;
}

.conteneur_alerte .bandeau span {
   float: right;
   margin-top:3px;
}

.conteneur_alerte .bandeau span:first-child {
   float: left;
   margin-top: 0;
}

.conteneur_alerte .conteneur_bas {
   padding: 0 12px;
}

.conteneur_alerte .alerte {
   width: 88%;
   display: table-cell;
   padding: 10px 0;
   vertical-align: top;
   height: 75px;/*hauteur totale - 25px (tetiere) - 20px (padding) */
}

.conteneur_alerte .alerte .heure_alerte {
   float: left;
   width: 55px;
}


.conteneur_alerte .alerte .texte_alerte {
   float: left;
   width: 540px;
   height:75px;
   overflow:hidden;
}

.conteneur_alerte .alerte .texte_alerte strong {
   display: block;
}

.conteneur_alerte .sociaux {
   width: 10.2%;
   display: table-cell;
   padding: 10px 10px 20px;
   vertical-align: bottom;
   border-left: 1px solid #464f57;
}

.conteneur_alerte .sociaux .txt11 {
   display: block;
   margin: 0 0 10px 0;
   color: #5d666d;
   font-weight: bold;
}

/**
*** MEDIA
**/
/* "petits" ecrans : nous allons sacrifier relativement l'alerte */
@media screen and (max-width: 1640px) {
   .conteneur_alerte  {
      width:72%;
      margin:0;
   }
}

@media screen and (max-width: 1200px) {
   .conteneur_alerte  {
      width:640px;
      margin:0;
   }
}
/* ----- start file /couleurs.css ----- */
/**********************************************/
/*** couleurs ***/
/**********************************************/
.txt_ea {
  color: #998000;
}

.txt_abo {
  color: #ffd500;
}


.txt_twit {
  color: #41c8f5;

}

.txt_gris747 {
   color: #747b83;
}

.gris_moyen {
   color: #464f57
}

.gris_clair {
   color: #a2a9ae
}

.global.generique{
   border-top:3px solid #a2a9ae;
}

.global.generique .entete_deroule{
   color: #a2a9ae;
}

.global.generique .bandeau {
   background: #a2a9ae;
}

#nav.generique{
  border-top-color: #a2a9ae;
}

#nav.generique  li{
  border-top: 3px solid  #a2a9ae;
}


#nav.accueil {
  border-top: 3px solid #d2d6db;
}

/* blocs fonces / videos */


.global.fonce {
   background: #000b15;
   border-top: 3px solid #464f57;
}

.global.fonce .entete_deroule, .global.fonce .lien_chaine{
   border-color: #2e3942;
}

.global.fonce .entete_deroule:hover {
   background: #000b15;
   color: #a2a9ae;
}

.global.fonce a, .global.fonce span, .global.fonce .obf {
   color: #eef1f5;
}

.global.fonce a:hover , .global.fonce span:hover , .global.fonce .obf:hover, .global.fonce a:hover .tt17  {
   color: #a2a9ae;
}

.global.videos figure img {
    border: 1px solid #2e3942;
}

/* international */
.global.international {
  border-top: 3px solid #0386c3;/*couleur foncee*/
}
.global.international .entete_deroule {
  color: #0386c3;/*couleur foncee*/
}
.global.international .bandeau {
  background: #0386c3;/*couleur foncee*/
}

#nav.accueil .international {
  border-top-color: #0386c3;/*couleur foncee*/
}

#nav .international:hover {
  background: #0386c3;/*couleur foncee*/
  border-top-color: #026b9C; /*hover sur fond gris couleur moyenne*/
}

#nav .international:hover a {
  border-color: #0386c3;/*couleur foncee*/
}

#nav.international, #nav.international li {
  border-top: 3px solid #0386c3;/*couleur foncee*/
}

#nav_ariane.international .ariane {
  background: url('/medias/web/img/sprites/sous_nav.png') no-repeat right 0;
}

#nav_ariane.international .ariane>a {/*texte onglet couleur la plus claire */
  color: #68b6db;
}

.international #ariane_az  a:hover,.international  #ariane_az .obf:hover, .ombrelle.international .tt_rubrique_ombrelle, .ombrelle.international h2 .obf, .ombrelle.international h2 .obf:hover, .international .tt_rubrique, .international .jour_parution, .international .couleur_rubrique{
  color: #0386c3;/*couleur foncee*/
}

 /* politique */
.global.politique {
  border-top: 3px solid #1f0d67;
}
.global.politique .entete_deroule {
  color: #1f0d67;
}
.global.politique .bandeau {
  background: #1f0d67;
}
#nav .politique:hover {
  background: #1f0d67;
  border-top-color: #190A52;
}

#nav.accueil .politique {
  border-top-color: #1f0d67;
}

#nav .politique:hover  a {
  border-color: #1f0d67;
}

#nav.politique, #nav.politique li {
  border-top: 3px solid #1f0d67;
}

#nav_ariane.politique .ariane {
  background: url('/medias/web/img/sprites/sous_nav.png') no-repeat right -35px;
}

#nav_ariane.politique .ariane>a {
  color: #796ea4;
}


.politique #ariane_az  a:hover,.politique  #ariane_az .obf:hover, .ombrelle.politique .tt_rubrique_ombrelle, .ombrelle.politique h2 .obf, .ombrelle.politique h2 .obf:hover, .politique .tt_rubrique, .politique .couleur_rubrique {
  color: #1f0d67;
}
 /* societe */
.global.societe {
  border-top: 3px solid #d50303;
}
.global.societe .entete_deroule {
  color: #d50303;
}
.global.societe .bandeau {
  background: #d50303;
}
#nav .societe:hover {
  background: #d50303;
  border-top-color: #AA0202;
}
#nav .societe:hover a, #nav.accueil .societe  {
  border-color: #d50303;
}

#nav.societe, #nav.societe li {
  border-top: 3px solid #d50303;
}

#nav_ariane.societe .ariane {
  background: url('/medias/web/img/sprites/sous_nav.png') no-repeat right -70px;
}

#nav_ariane.societe .ariane>a {
  color: #fe9b9b;
}

.societe  #ariane_az  a:hover,.societe   #ariane_az .obf:hover , .ombrelle.societe .tt_rubrique_ombrelle, .ombrelle.societe h2 .obf, .ombrelle.societe h2 .obf:hover, .societe .tt_rubrique, .societe .jour_parution, .societe .couleur_rubrique {
  color: #d50303;
}

 /* economie*/
.global.economie {
  border-top: 3px solid #fe2f2f;
}
.global.economie .entete_deroule {
  color: #fe2f2f;
}
.global.economie .bandeau {
  background: #fe2f2f;
}
#nav .economie:hover {
  background: #fe2f2f;
  border-top-color: #CB2626;
}
#nav .economie:hover a, #nav.accueil .economie {
  border-color: #fe2f2f;
}

#nav.economie , #nav.economie li {
  border-top: 3px solid #fe2f2f;
}

#nav_ariane.economie .ariane {
  background: url('/medias/web/img/sprites/sous_nav.png') no-repeat right -105px;
}

#nav_ariane.economie .ariane>a {
  color: #ffacac;
}

#nav_ariane.economie .ariane a:hover, #nav_ariane.economie .ariane .obf:hover {
   color:#fff;
}

.economie  #ariane_az  a:hover,.economie   #ariane_az .obf:hover , .ombrelle.economie .tt_rubrique_ombrelle, .ombrelle.economie h2 .obf, .ombrelle.economie h2 .obf:hover, .economie .tt_rubrique, .economie .jour_parution, .economie .couleur_rubrique {
  color: #fe2f2f;
}

 /* culture*/
.global.culture {
  border-top: 3px solid #f20559;
}
.global.culture .entete_deroule {
  color: #f20559;
}
.global.culture .bandeau {
  background: #f20559;
}
#nav .culture:hover {
  background: #f20559;
  border-top-color: #C20447;
}

#nav.culture, #nav.culture li {
  border-top: 3px solid #C20447;
}

#nav .culture:hover a {
  border-color: #f20559;
}
#nav.accueil .culture{
  border-top-color: #f20559;
}

#nav_ariane.culture .ariane {
  background: url('/medias/web/img/sprites/sous_nav.png') no-repeat right -140px;
}

#nav_ariane.culture .ariane>a {
  color: #fa9bbd;
}

.culture  #ariane_az  a:hover,.culture  #ariane_az .obf:hover , .ombrelle.culture .tt_rubrique_ombrelle, .ombrelle.culture h2 .obf, .ombrelle.culture h2 .obf:hover, .culture .tt_rubrique, .culture .jour_parution, .culture .couleur_rubrique {
  color: #f20559;
}

/* debats */
.global.debats{
   border-top: 3px solid #2e3942;
}

 /* defaut*/


.global .entete_deroule {
  color: #2e3942;
}

.global .debats.bandeau, .global .videos.bandeau {
  background: #2e3942 !important;
}

#nav .debats:hover {
  background: #2e3942;
  border-top-color: #16212C;
}

#nav, #nav li {
  border-top: 3px solid #2e3942;
}

#nav li:hover a{
  border-color: #2e3942;
}

#nav_ariane .ariane {
  background: url('/medias/web/img/sprites/sous_nav.png') no-repeat right -175px;
}

#ariane_az  a:hover, #ariane_az .obf:hover , .ombrelle .tt_rubrique_ombrelle, .ombrelle h2 .obf, .ombrelle h2 .obf:hover, .tt_rubrique, .jour_parution, .couleur_rubrique {
  color: #2e3942;
}

 /* education*/
.global.education {
  border-top: 3px solid #ff6e17;
}

.global.education .entete_deroule {
  color: #ff6e17;
}

.global.education .bandeau {
  background: #ff6e17 !important;
}

#nav .education:hover {
  background: #ff6e17;
  border-top-color: #16212C;
}

#nav.education, #nav.education li {
  border-top: 3px solid #ff6e17;
}

#nav .education:hover a, #nav.accueil .education{
  border-color: #ff6e17;
}

#nav_ariane.education .ariane {
  background: url('/medias/web/img/sprites/sous_nav.png') no-repeat right -490px;
}

#nav_ariane.education .ariane>a {
  color: #f79b6e;
}

.education   #ariane_az  a:hover,.education  #ariane_az .obf:hover , .ombrelle.education .tt_rubrique_ombrelle, .ombrelle.education h2 .obf, .ombrelle.education h2 .obf:hover, .education .tt_rubrique, .education .jour_parution, .education .couleur_rubrique {
  color: #ff6e17;
}

.education .col_droite .bloc_base .entete.theme {
   background: #ff6e17;
   color: #fff;
   border-top: none;
}

.education .square:before {
  color: #ff6e17;
}

.education .nl_blanc_bg {
   background: #ff6e17;
}

 /* planete*/
.global.planete {
  border-top: 3px solid #30932e;
}

.global.planete .entete_deroule {
  color: #30932e;
}

.global.planete .bandeau {
  background: #30932e !important;
}

#nav .planete:hover {
  background: #30932e;
  border-top-color: #16212C;
}

#nav.planete, #nav.planete li {
  border-top: 3px solid #30932e;
}

#nav .planete:hover a, #nav.accueil .planete{
  border-color: #30932e;
}

#nav_ariane.planete .ariane {
  background: url('/medias/web/img/sprites/sous_nav.png') no-repeat right -420px;
}

#nav_ariane.planete .ariane>a {
  color: #a3c383;
}

.planete   #ariane_az  a:hover,.planete  #ariane_az .obf:hover , .ombrelle.planete .tt_rubrique_ombrelle, .ombrelle.planete h2 .obf, .ombrelle.planete h2 .obf:hover, .planete .tt_rubrique, .planete .jour_parution, .planete .couleur_rubrique {
  color: #30932e;
}


 /* sante*/
.global.sante {
  border-top: 3px solid #189494;
}

.global.sante .entete_deroule {
  color: #189494;
}

.global.sante.bandeau {
  background: #189494 !important;
}

#nav .sante:hover {
  background: #189494;
  border-top-color: #16212C;
}

#nav.sante, #nav.sante li {
  border-top: 3px solid #189494;
}

#nav .sante:hover a, #nav.accueil .sante{
  border-color: #189494;
}

#nav_ariane.sante .ariane {
  background: url('/medias/web/img/sprites/sous_nav.png') no-repeat right -455px;
}

#nav_ariane.sante .ariane>a {
  color: #83bbc3;
}

.sante   #ariane_az  a:hover,.sante  #ariane_az .obf:hover , .ombrelle.sante .tt_rubrique_ombrelle, .ombrelle.sante h2 .obf, .ombrelle.sante h2 .obf:hover, .sante .tt_rubrique, .sante .jour_parution, .sante .couleur_rubrique {
  color: #189494;
}

/* sport */
.global.sport {
  border-top: 3px solid #6faa12;
}
.global.sport .entete_deroule {
  color: #6faa12;
}
.global.sport .bandeau {
  background: #6faa12;
}
#nav.accueil .sport {
  border-top-color: #6faa12;
}

#nav .sport:hover {
  background: #6faa12;
  border-top-color: #59880E;
}

#nav .sport:hover a {
  border-color: #6faa12;
}

#nav.sport, #nav.sport li, body.sport nav#nav, body.sport nav#nav li {
  border-top: 3px solid #6faa12;
}

#nav_ariane.sport .ariane {
  background: url('/medias/web/img/sprites/sous_nav.png') no-repeat right -210px;
}

#nav_ariane.sport .ariane>a {
  color: #b1e264;
}

.sport  #ariane_az  a:hover,.sport  #ariane_az .obf:hover , .ombrelle.sport .tt_rubrique_ombrelle, .ombrelle.sport h2 .obf, .ombrelle.sport h2 .obf:hover, .sport .tt_rubrique, .sport .jour_parution, .sport .couleur_rubrique  {
  color: #6faa12;
}

/* sciences */
.global.sciences {
  border-top: 3px solid #0cb4ae;
}
.global.sciences .entete_deroule {
  color: #0cb4ae;
}
.global.sciences .bandeau {
  background: #0cb4ae;
}
#nav.accueil .sciences {
  border-top-color: #0cb4ae;
}

#nav .sciences:hover {
  background: #0cb4ae;
  border-top-color: #0A908B;
}

#nav .sciences:hover a {
  border-color: #0cb4ae;
}

#nav.sciences, #nav.sciences li {
  border-top: 3px solid #0cb4ae;
}

#nav_ariane.sciences .ariane {
  background: url('/medias/web/img/sprites/sous_nav.png') no-repeat right -245px;
}

#nav_ariane.sciences .ariane>a {
  color: #9ee1df;
}

.sciences  #ariane_az  a:hover,.sciences   #ariane_az .obf:hover,.ombrelle.sciences .tt_rubrique_ombrelle, .ombrelle.sciences h2 .obf, .ombrelle.sciences h2 .obf:hover, .sciences .tt_rubrique, .sciences .jour_parution, .sicences .couleur_rubrique {
  color: #0cb4ae;
}

/* techno */
.global.techno {
  border-top: 3px solid #006169;
}

.global.techno .entete_deroule {
  color: #006169;
}

.global.techno .bandeau {
  background: #006169;
}
#nav.accueil .techno {
  border-top-color: #006169;
}

#nav .techno:hover {
  background: #006169;
  border-top-color: #004E54;
}

#nav .techno:hover a {
  border-color: #006169;
}

#nav.techno, #nav.techno li {
  border-top: 3px solid #006169;
}

#nav_ariane.techno .ariane {
  background: url('/medias/web/img/sprites/sous_nav.png') no-repeat right -280px;
}

#nav_ariane.techno .ariane>a {
  color: #89c1c6;
}

.techno  #ariane_az  a:hover,.techno  #ariane_az .obf:hover, .ombrelle.techno .tt_rubrique_ombrelle, .ombrelle.techno h2 .obf, .ombrelle.techno h2 .obf:hover, .techno .tt_rubrique, .techno .jour_parution, .techno .couleur_rubrique {
  color: #006169;
}

/* style */
.global.style {
  border-top: 3px solid #020818;
}

.global.style .entete_deroule {
  color: #020818;
}

.global.style .bandeau {
  background: #020818;
}
#nav.accueil .style, #nav .style:hover  a{
  border-top-color: #020818;
}

#nav .style:hover {
  background: #020818;
  border-top-color: #050F31;
}

#nav .style:hover a {
  border-color: #020818;
}

#nav.style, #nav.style li {
  border-top: 3px solid #020818;
}

#nav_ariane.style .ariane {
  background: url('/medias/web/img/sprites/sous_nav.png') no-repeat right -315px;
}

#nav_ariane.style .ariane>a {
  color: #6a718b;
}

.ombrelle.style .tt_rubrique_ombrelle, .ombrelle.style h2 .obf, .ombrelle.style h2 .obf:hover, .style .tt_rubrique, .style .jour_parution, .style .couleur_rubrique {
  color: #020818;
}

.style   #ariane_az  a:hover,.style   #ariane_az .obf:hover {
   color: #3a4971;
}

/* vous */
.global.vous {
  border-top: 3px solid #820250;
}
.global.vous .entete_deroule {
  color: #820250;
}
.global.vous .bandeau {
  background: #820250;
}
#nav.accueil .vous{
  border-top-color: #820250;
}

#nav .vous:hover {
  background: #820250;
  border-top-color: #680240;
}

#nav .vous:hover a {
  border-color: #820250;
}

#nav.vous, #nav.vous li {
  border-top: 3px solid #820250;
}

#nav_ariane.vous .ariane {
  background: url('/medias/web/img/sprites/sous_nav.png') no-repeat right -350px;
}

#nav_ariane.vous .ariane>a {
  color: #fa9bbd;
}

.vous  #ariane_az  a:hover,.vous  #ariane_az .obf:hover, .ombrelle.vous .tt_rubrique_ombrelle, .ombrelle.vous h2 .obf, .ombrelle.vous h2 .obf:hover, .vous .tt_rubrique, .vous .jour_parution, .vous .couleur_rubrique {
  color: #820250;
}

/* abonnes */
.bg_abo {
   background: #ffd500;
}

.global.abonnes {
  border-top: 3px solid #ffd500;
}

.global.abonnes .entete_deroule {
  color: #ffd500;
}
.global.abonnes .bandeau {
  background: #ffd500;
}
#nav.accueil .abonnes{
  border-top-color: #ffd500;
}

#nav .abonnes:hover {
  background: #ffd500;
  border-top-color: #ccaa00;
}

#nav .abonnes:hover a {
  border-color: #ffd500;
}

#nav.abonnes, #nav.abonnes li {
  border-top: 3px solid #ffd500;
}

#nav .abonnes {
   float:none;
   overflow:hidden;
}

#nav_ariane.abonnes .ariane {
  background: url('/medias/web/img/sprites/sous_nav.png') no-repeat right -525px;
}

#nav_ariane.abonnes .ariane>a {
  color: #ccaa00;
}

.vous  #ariane_az  a:hover,.vous  #ariane_az .obf:hover, .ombrelle.vous .tt_rubrique_ombrelle, .ombrelle.vous h2 .obf, .ombrelle.vous h2 .obf:hover, .vous .tt_rubrique, .vous .jour_parution {
  color: #820250;
}


.abonnes  #ariane_az  a:hover,.abonnes  #ariane_az .obf:hover, .ombrelle.abonnes .tt_rubrique_ombrelle, .ombrelle.abonnes h2 .obf, .ombrelle.abonnes h2 .obf:hover, .abonnes .tt_rubrique, .abonnes .jour_parution, .abonnes .couleur_rubrique {
  color: #ffd500;
}


/* surcharge de la couleur du bouton actif du fil d'ariane */
#ariane_az .ariane a:hover, #ariane_az .ariane .obf:hover, #nav_ariane .ariane.actif a, #nav_ariane .ariane.actif span  {
   color:#fff;
}


/*** bloc deroule une avec bordure et entete image de fond  */

/* presidentielle */
.global.presidentielle{
   border-top: 0;
}

.global.presidentielle .entete_deroule, .global.presidentielle .entete_deroule:hover {
   background: url('/medias/web/img/textes/elections/bandeau_deroule_presidentielles2012.png') no-repeat;
   text-indent: -9999px;
}

.global.presidentielle .entete_deroule:hover {
   background-position: 0 -33px;
}
/* ----- start file /elections.css ----- */
/**
 * Fichier des elements supposement communs a toutes les elections
 */

.titre_bulle_2012 {
   color: #d50303
}

.bulle_2012_39x27 {
   display: inline-block;
   width: 39px;
   height: 27px;
   background: url('/medias/web/img/textes/elections/bulle_2012_39x27.png');
}


.bulle_2012_73x51 {
   display: inline-block;
   width: 73px;
   height: 51px;
   margin-left: 4px;
   text-indent: -9999px;
   vertical-align: bottom;
   background: url('/medias/web/img/textes/elections/bulle_2012_73x51.png');
}


.deroule_fleuve .logo_annee_france {
   height: 76px;
   padding: 10px 0 0 115px;
   background: url('/medias/web/img/habillage/logo_annee_france.png') no-repeat left top;
}

.deroule_fleuve .carte_annee_france {
   padding-right: 204px;
   height: 226px;
   margin-bottom: 15px;
   background: url('/medias/web/img/habillage/carte_annee_france.jpg') no-repeat right top;
}

.deroule_fleuve .carte_annee_france a {
   display: block;
   font-size: 11px;
   font-weight: bold;
   line-height: 0.96rem;
   margin-bottom: 1.7rem;
   margin-left: 4px;
}

.col_droite .alerte_election {
   display: block;
   width: 312px;
   height: 48px;
   background: url('/medias/web/img/textes/elections/tetiere-bloc-formulaire-alerte.png');
   text-indent: -9999px;
}

.col_droite .erreur {
   display:block;
   width:292px;
}

.col_droite .inscription_alerte_election  .saisie   {
   width: 272px;
}

#alerte_election_coldroite .conteneur_autocompletion {
   width:272px;
}
#alerte_election_coldroite .contenu_bloc_droit {
   overflow:visible;
}

/**
*recherche
*/
.boite_recherche {
   background: #f8f9fb url('/medias/web/img/evenementiel/presidentielle_2012/bg_recherche_elections.png') center 0 no-repeat;
   overflow: visible;
   padding: 16px 16px 10px;
   color: #fff;
}

.boite_recherche .bord_double_gris_blanc {
   margin: 0 4px;
   display: inline-block;
   line-height: 20px;
   font-weight: bold;
}

.bord_top3_politique .boite_recherche input:first-child {
   width: 265px;
}

.boite_recherche .bord_double_gris_blanc span {
   padding: 0 3px;
}

.bord_top3_politique select {
   width: 175px;
}

.boite_recherche .conteneur_autocompletion .ui-state-hover {
   font-weight: bold;
}

.boite_recherche .txt15_120 {
   background: url('/medias/web/img/textes/elections/bulle_2012_39x27_bg_fonce.png') no-repeat;
   padding-left: 50px;
   height: 30px;
   line-height: 26px;
}

.boite_recherche strong {
   display:inline-block;
}

.une_edito .boite_recherche > p, .boite_inline .boite_recherche > p {
   display:inline;
}

.une_edito .grid_12 .boite_recherche > p {
   display: block;
   margin: 5px 0 0;
}

.une_edito .btn.adroite, .boite_inline .btn.adroite {
   margin-top:5px;
}

/**
 * Pages d'inscripton aux alertes resultats
 */
.reception_alertes_resultats {
  border:solid 1px #eef1f5;
}
.reception_alertes_resultats h1 {
  border-top:solid 3px #1f0d67;
}
.reception_alertes_resultats .conteneur_hors_grille {
  margin:16px 54px 54px;
}
.reception_alertes_resultats .saisie {
  display:block;
  width:282px;
}
.reception_alertes_resultats .saisie.iblock {
   display:inline-block;
   vertical-align:middle;
}
.reception_alertes_resultats .saisie[type="date"] {
  display:inline-block;
  width:172px;
}

.reception_alertes_resultats .confirmation a {
   font-weight:bold;
}
#alertes_confirmation_newsletter form * {
   vertical-align:top;
}
#alertes_confirmation_newsletter form input {
   margin-top:3px;
}

/**
 * Gestion des alertes resultats
 */
.reception_alertes_resultats .rnd4 {
   overflow:hidden;
}
.reception_alertes_resultats table th, .reception_alertes_resultats table td {
   padding:8px;
   border:solid 1px #b9c0c5;
}
.reception_alertes_resultats table th {
   text-align:left;
   background:#f1f5f8;
}
.reception_alertes_resultats td span {
   display:block;
   cursor:pointer;
}
.reception_alertes_resultats .conteneur_autocompletion {
   width:282px;
}

/*** comparer ***/
label.comparer {
   clear: both;
   display: inline-block;
   padding: 3px 16px;
   background: #f1f5f8;
   font-weight: bold;
}

label.comparer input {
   margin-right: 8px;
}

/** images du bloc deroule presidentielle */
.lien_img314x64.comparer_sondages {
   background: url('/medias/web/img/textes/elections/widget_comparer_sondages.png');
   text-indent: -9999px;
}
.lien_img314x64.comparer_programmes {
   background: url('/medias/web/img/textes/elections/widget_comparateur2nd_tour.png');
   text-indent: -9999px;
}
.lien_img314x64.inscription_alerte {
   background: url('/medias/web/img/textes/elections/widget_inscription_alerte.jpg');
   text-indent: -9999px;
}
.lien_img314x64.explorer_discours_2012 {
   background: url('/medias/web/img/textes/elections/widget_explorer_discours_2012.png');
   text-indent: -9999px;
}

* {
    margin: 0;
    padding: 0;
}
img,
form { border: 0 }
ul {
    list-style-image: none;
    list-style-position: inside;
    list-style-type: none;
}
table { border-collapse: collapse }
#mainContent {
    background: #fff;
    font-family: Verdana,Arial,Helvetica,sans-serif;
    font-size: 12px;
    color: #222;
}
body>img { position: absolute }
.megaban {
    margin-right: auto;
    margin-left: auto;
    text-align: center;
}
.ad-top .megaban { width: 1000px }
.ligatus iframe {
    display: block;
    margin: auto;
}
body.access-pre .offers-hide-pre { display: none!important }
body.access-ess .offers-hide-ess { display: none!important }
body.access-bas .offers-hide-quo { display: none!important }
body.access-pre .block-ad,
body.access-ess .block-ad { display: none!important }
.clear { clear: both }
.display-none { display: none }
.float-right { float: right }
.float-left { float: left }
.rounded,
.rounded3 {
    border-radius: 3px;
    -moz-border-radius: 3px;
    -webkit-border-radius: 3px;
}
.rounded5 {
    border-radius: 5px;
    -moz-border-radius: 5px;
    -webkit-border-radius: 5px;
}
.hand-cursor {
    cursor: pointer;
    cursor: hand;
}
.m-auto { margin: auto }
.m-bot-2 { margin-bottom: 2px }
.m-bot-3 { margin-bottom: 3px }
.m-bot-4 { margin-bottom: 4px }
.m-bot-5 { margin-bottom: 5px }
.m-bot-10 { margin-bottom: 10px }
.m-bot-15 { margin-bottom: 15px }
.m-bot-20 { margin-bottom: 20px }
.m-bot-30 { margin-bottom: 30px }
.m-bot-45 { margin-bottom: 45px }
.m-right-0 { margin-right: 0 }
.m-right-5 { margin-right: 5px }
.m-right-10 { margin-right: 10px }
.m-right-20 { margin-right: 20px }
.m-right-100 { margin-right: 100px }
img.spacer {
    width: 1px;
    height: 1px;
}
.visual-square-90 {
    width: 90px;
    height: 90px;
}
.visual-rect-0302-460 {
    width: 460px;
    height: 307px;
}
.visual-rect-0302-460 {
    width: 460px;
    height: 307px;
}
.visual-rect-0302-150 {
    width: 150px;
    height: 100px;
}
.visual-rect-2305-460 {
    width: 460px;
    height: 100px;
}
.txt-up-c { text-transform: uppercase }
.txt-low-c { text-transform: none }
.txt-center { text-align: center }
.txt-right { text-align: right }
.txt-justify { text-align: justify }
.txt-u { text-decoration: underline }
#header-liberation hr {
    border: 0;
    border-top: 3px solid #e0e0e0;
}
#header-liberation .header-base {
    border-top: 1px solid #e0e0e0;
    margin: 0 10px;
}
#header-liberation .header-base .home,
#header-liberation .header-base .sites-info-search,
#header-liberation .header-base .links,
#header-liberation .header-base .digitalpaper {
    display: block;
    float: left;
}
#header-liberation .header-base .home { width: 196px }
#header-liberation .header-base .home .logo { display: block }
#header-liberation .header-base .sites-info-search {
    width: 280px;
    overflow: hidden;
    margin-right: 28px;
}
#header-liberation .header-base .sites-info-search ul.sites {
    display: block;
    height: 40px;
}
#header-liberation .header-base .sites-info-search ul.sites li {
    position: relative;
    display: block;
    float: left;
    height: 40px;
    box-shadow: 9px 0 10px -11px #6c6c6c;
    -moz-box-shadow: 9px 0 10px -11px #6c6c6c;
    -webkit-box-shadow: 9px 0 10px -11px #6c6c6c;
}
#header-liberation .header-base .sites-info-search ul.sites li a {
    display: block;
    width: 100%;
    height: 100%;
}
#header-liberation .header-base .sites-info-search ul.sites li span.logo {
    display: block;
    position: absolute;
    background-image: url('http://s0.libe.com/libe/img/common/_sprites_header/header.png?df8de01457fa');
    background-repeat: no-repeat;
}
#header-liberation .header-base .sites-info-search ul.sites li.libe { width: 75px }
#header-liberation .header-base .sites-info-search ul.sites li.libe span.logo {
    top: 9px;
    left: 9px;
    width: 56px;
    height: 21px;
    background-position: -190px 0;
}
#header-liberation .header-base .sites-info-search ul.sites li.next { width: 75px }
#header-liberation .header-base .sites-info-search ul.sites li.next span.logo {
    top: 11px;
    left: 13px;
    width: 49px;
    height: 18px;
    background-position: -96px 0;
}
#header-liberation .header-base .sites-info-search ul.sites li.ecrans { width: 65px }
#header-liberation .header-base .sites-info-search ul.sites li.ecrans span.logo {
    top: 9px;
    left: 12px;
    width: 41px;
    height: 23px;
    background-position: -147px 0;
}
#header-liberation .header-base .sites-info-search ul.sites li.labo { width: 56px }
#header-liberation .header-base .sites-info-search ul.sites li.labo span.logo {
    top: 13px;
    left: 12px;
    width: 34px;
    height: 14px;
    background-position: 0 0;
}
#header-liberation .header-base .sites-info-search ul.sites li.boutique { width: 84px }
#header-liberation .header-base .sites-info-search ul.sites li.boutique span.logo {
    top: 7px;
    left: 14px;
    width: 58px;
    height: 27px;
    background-position: -36px 0;
}
#header-liberation .header-base .sites-info-search .info {
    display: block;
    height: 32px;
}
#header-liberation .header-base .sites-info-search .info span {
    display: block;
    color: #808080;
    font-size: 11.2px;
    font-family: Arial,Verdana,sans-serif;
    padding-top: 9px;
}
#header-liberation .header-base .sites-info-search .search {
    display: block;
    width: 278px;
    height: 22px;
    border: 1px solid #808080;
}
#header-liberation .header-base .sites-info-search .search input[type=text] {
    border: 0;
    color: #808080;
    height: 22px;
    width: 220px;
    padding: 0 5px;
}
#header-liberation .header-base .sites-info-search .search input[type=submit] {
    background: url('http://s0.libe.com/libe/img/common/_sprites_header/header.png?df8de01457fa') no-repeat 0 -32px;
    display: block;
    float: right;
    width: 29px;
    height: 22px;
    border: 0;
}
#header-liberation .header-base .links h2 {
    font-weight: normal;
    text-transform: uppercase;
    font-size: 11px;
    height: 16px;
}
#header-liberation .header-base .links ul li {
    font-family: Arial,Verdana,sans-serif;
    font-size: 11.5px;
}
#header-liberation .header-base .links ul li a { color: #808080 }
#header-liberation .header-base .nav {
    display: block;
    clear: both;
    position: relative;
}
#header-liberation .header-base .nav li {
    display: block;
    float: left;
}
#header-liberation .header-base .nav .nav1 {
    font-weight: normal;
    text-transform: uppercase;
    font-size: 11px;
}
#header-liberation .header-base .nav .nav1 a { display: block }
#header-liberation .header-base .nav .nav1 a:hover { text-decoration: none }
#header-liberation .header-base .nav .nav2 {
    position: absolute;
    display: block;
    z-index: 5000;
    bottom: 0;
    left: 0;
    width: 100%;
}
#header-liberation .header-base .nav .nav2 li {
    display: block;
    float: left;
}
#header-liberation .header-base .nav .nav2 li a {
    position: relative;
    display: block;
}
#core-liberation form h2 { margin-bottom: 10px }
#core-liberation form p {
    padding-top: 10px;
    padding-bottom: 10px;
}
#core-liberation form .hidden { display: none }
ul.errorlist {
    background: #fafafa;
    border: 1px solid #e20000;
    color: #2e2e2e;
    margin: 0 0 5px 0;
    padding: 5px;
}
ul.errorlist li {
    font-size: 11px;
    font-weight: normal;
    color: #e20000;
}
ul.list li { margin-bottom: 20px }
.block .block-content { padding: 5px 14px }
.block.rounded,
.block .block-content.rounded {
    border-radius: 5px;
    -moz-border-radius: 5px;
    -webkit-border-radius: 5px;
}
#core-liberation .block .right { float: right }
#core-liberation .block .block-top img.icon {
    width: 30px;
    float: left;
    margin: 0 5px 5px 14px;
}
#core-liberation .block .block-top h5 { font-size: 12px }
#core-liberation .block .block-bottom span.right {
    float: right;
    display: block;
}
#core-liberation .block-basic-rounded .block-top h5 {
    text-tranform: uppercase;
    font-weight: normal;
}
#core-liberation .block-basic-rounded .block-content {
    border: 1px solid #D8D8D8;
    border-radius: 5px;
    -moz-border-radius: 5px;
    -webkit-border-radius: 5px;
}
#core-liberation .block-basic-curled { position: relative }
#core-liberation .block-basic-curled .shadow-left,
#core-liberation .block-basic-curled .shadow-right,
#core-liberation .block-basic-curled .shadow-top-left,
#core-liberation .block-basic-curled .shadow-top-right {
    display: block;
    position: absolute;
    z-index: 0;
    width: 35%;
    max-width: 100%;
    max-height: 100%;
}
#core-liberation .block-basic-curled .shadow-left,
#core-liberation .block-basic-curled .shadow-right { bottom: -4px }
#core-liberation .block-basic-curled .shadow-top-left,
#core-liberation .block-basic-curled .shadow-top-right { top: -4px }
#core-liberation .block-basic-curled .shadow-left,
#core-liberation .block-basic-curled .shadow-top-left { left: -4px }
#core-liberation .block-basic-curled .shadow-right,
#core-liberation .block-basic-curled .shadow-top-right { right: -4px }
#core-liberation .block-basic-curled .block-top,
#core-liberation .block-basic-curled .block-content {
    position: relative;
    z-index: 1000;
    background: #fff;
}
#core-liberation .headrest { clear: both }
#core-liberation .headrest h5 { font-size: 12px }
#core-liberation .headrest h4 { font-size: 18px }
#core-liberation .headrest span.right { float: right }
#core-liberation .headrest-basic-rounded {
    border: 1px solid #D8D8D8;
    border-radius: 3px;
    -moz-border-radius: 3px;
    -webkit-border-radius: 3px;
}
#core-liberation .cartridge { display: block }
#core-liberation .cartridge .segment {
    display: block;
    float: right;
    height: 100%;
}
#core-liberation .cartridge span.br { display: block }
#core-liberation .cartridge-basic-rounded {
    border: 1px solid #222;
    border-radius: 5px;
    -moz-border-radius: 5px;
    -webkit-border-radius: 5px;
}
#core-liberation .cartridge-basic-bubble .plain,
#core-liberation .cartridge-basic-bubble .segment {
    display: block;
    float: left;
    border: 1px solid #222;
    border-radius: 5px;
    -moz-border-radius: 5px;
    -webkit-border-radius: 5px;
}
#core-liberation .pagination {
    float: right;
    height: 21px;
    margin-bottom: 25px;
}
#core-liberation .pagination a {
    display: block;
    float: left;
    background: #e6e6e6;
    height: 19px;
    margin-right: 5px;
    padding: 1px 6px;
}
#core-liberation .pagination span {
    display: inline;
    height: 19px;
    margin-right: 5px;
    padding: 1px 6px;
}
#core-liberation .pagination .disabled,
#core-liberation .pagination .current {
    background: #7d7d7d;
    color: #fff;
}
#core-liberation .js-loader {
    width: 0;
    height: 0;
}
img#hit-count {
    position: absolute;
    bottom: 0;
    right: 0;
    margin: 0;
    padding: 0;
    height: 0;
}
#DOMWindow iframe { height: 96%!important }
#mainContent {
    display: block;
    margin: 0 auto;
    width: 1000px;
    padding: 1px 0;
}
#core-liberation,
#header-liberation,
#footer-liberation {
    display: block;
    clear: both;
    margin: 0 0 14px 0;
}
#core-liberation { padding: 0 10px }
#header-liberation { padding: 0 }
#footer {
    margin-bottom: 0;
    padding: 0 0 28px 0;
}
.m-bot-s1 { margin-bottom: 42px }
.m-bot-s2 { margin-bottom: 28px }
.m-bot-s3 { margin-bottom: 21px }
.m-bot-s4 { margin-bottom: 14px }
.m-bot-s5 { margin-bottom: 7px }
.col {
    display: block;
    float: left;
}
.gutter { margin-right: 28px }
.gutter-double { margin-right: 56px }
.gutter-half { margin-right: 14px }
.w35unit,
.w35unit .visual100 { width: 980px }
.w34unit,
.w34unit .visual100 { width: 952px }
.w33unit,
.w33unit .visual100 { width: 924px }
.w32unit,
.w32unit .visual100 { width: 896px }
.w31unit,
.w31unit .visual100 { width: 868px }
.w30unit,
.w30unit .visual100 { width: 840px }
.w29unit,
.w29unit .visual100 { width: 812px }
.w28unit,
.w28unit .visual100 { width: 784px }
.w27unit,
.w27unit .visual100 { width: 756px }
.w26unit,
.w26unit .visual100 { width: 728px }
.w25unit,
.w25unit .visual100 { width: 700px }
.w24unit,
.w24unit .visual100 { width: 672px }
.w23unit,
.w23unit .visual100 { width: 644px }
.w22unit,
.w22unit .visual100 { width: 616px }
.w21unit,
.w21unit .visual100 { width: 588px }
.w20unit,
.w20unit .visual100 { width: 560px }
.w19unit,
.w19unit .visual100 { width: 532px }
.w18unit,
.w18unit .visual100 { width: 504px }
.w17unit,
.w17unit .visual100 { width: 476px }
.w16unit,
.w16unit .visual100 { width: 448px }
.w15unit,
.w15unit .visual100 { width: 420px }
.w14unit,
.w14unit .visual100 { width: 392px }
.w13unit,
.w13unit .visual100 { width: 364px }
.w12unit,
.w12unit .visual100 { width: 336px }
.w11unit,
.w11unit .visual100 { width: 308px }
.w10unit,
.w10unit .visual100 { width: 280px }
.w9unit,
.w9unit .visual100 { width: 252px }
.w8unit,
.w8unit .visual100 { width: 224px }
.w7unit,
.w7unit .visual100 { width: 196px }
.w6unit,
.w6unit .visual100 { width: 168px }
.w5unit,
.w5unit .visual100 { width: 140px }
.w4unit,
.w4unit .visual100 { width: 112px }
.w3unit,
.w3unit .visual100 { width: 84px }
.w2unit,
.w2unit .visual100 { width: 56px }
.w1unit,
.w1unit .visual100 { width: 28px }
ul.list li {
    display: block;
    float: left;
    margin-bottom: 28px;
    margin-left: 28px;
}
.w35unit .list-4-items li { width: 224px }
.w29unit .list-4-items li { width: 182px }
.w23unit .list-4-items li { width: 140px }
.w35unit .list-3-items li { width: 308px }
.w23unit .list-3-items li { width: 196px }
.w23unit .list-2-items li { width: 308px }
ul.list li:first-child,
ul.list li.new-line {
    clear: both;
    margin-left: 0;
}
body.barry-white { padding-top: 41px }
body.init-bar-is-closed { padding-top: 15px }
body.slideshow { padding-top: 41px }
body.iframe { padding-top: 0 }
.ad-top { padding: 1px 0 }
.ad-top .megaban { margin: 7px auto }
.ad-bottom .megaban { padding: 7px 0 }
.ad-google .googleBanner .annonce {
    margin: 0 0 7px 0;
    padding: 7px;
    font-size: 12px;
    border: 1px solid;
}
.ad-google .googleBanner .annonce:last-of-type { margin-bottom: 0 }
.lnk-libeplus {
    background-image: url('http://s0.libe.com/libe/img/common/ico-lnk-libeplus.png?2967b1507eee');
    background-repeat: no-repeat;
    background-position: right 4px;
    padding-right: 20px;
}
.lnk-libeplus-big {
    background-image: url('http://s0.libe.com/libe/img/common/ico-lnk-libeplus-big.png?401394d0f866');
    background-repeat: no-repeat;
    background-position: right 4px;
    padding-right: 30px;
}
.site-liberation #header-liberation h2,
.site-liberation #header-liberation h1 { font-family: Verdana,Arial,Helvetica,sans-serif }
.site-liberation .hot-topics {
    display: block;
    clear: both;
    margin: 14px 10px 0;
    padding: 14px 0;
    font-size: 11px;
}
.site-liberation .hot-topics h1 {
    border-right: 1px dotted;
    float: left;
    margin: 0 0 0 21px;
    padding: 0 21px 0 0;
    text-transform: uppercase;
    font-size: 20px;
}
.site-liberation .hot-topics h5 {
    float: left;
    margin: 0 0 0 21px;
    padding: 5px 21px 5px 0;
    background: url('http://s0.libe.com/libe/img/common/bg-puce-losange.png?099dfb8021ab') no-repeat center right;
    text-transform: uppercase;
    font-size: 12px;
}
.site-liberation .hot-topics ul {
    float: left;
    margin: -1px 0 0 7px;
}
.site-liberation .hot-topics li {
    display: block;
    float: left;
    padding: 3px 7px 5px;
    margin: 3px 10px 3px 0;
}
#header-liberation .header-base { border-top: 1px solid #e0e0e0 }
#header-liberation .header-base .home,
#header-liberation .header-base .sites-info-search,
#header-liberation .header-base .links,
#header-liberation .header-base .digitalpaper { height: 120px }
#header-liberation .header-base .home .logo {
    background: url('http://s0.libe.com/libe/img/common/logo-liberation-150.png?f613aa3caae2') no-repeat 0 0;
    width: 150px;
    height: 55px;
    margin-top: 33px;
}
#header-liberation .header-base .links {
    display: block;
    width: 280px;
    height: 110px;
    padding-top: 10px;
}
#header-liberation .header-base .links .lnk1,
#header-liberation .header-base .links .lnk2 { float: left }
#header-liberation .header-base .links .lnk1 {
    position: relative;
    width: 123px;
}
#header-liberation .header-base .links .lnk2 {
    width: 136px;
    padding-left: 21px;
}
#header-liberation .header-base .links h2 { margin-bottom: 3px }
#header-liberation .header-base .links ul li {
    margin-bottom: 1px;
    height: 13px;
}
#header-liberation .header-base .digitalpaper {
    position: relative;
    float: right;
    width: 196px;
}
#header-liberation .header-base .digitalpaper a.dl,
#header-liberation .header-base .digitalpaper a.abo {
    display: block;
    position: absolute;
    top: 15px;
    right: 0;
    width: 79px;
    height: 34px;
    padding-left: 10px;
    padding-top: 7px;
    font-size: 11px;
    font-family: Arial,Verdana,sans-serif;
}
#header-liberation .header-base .digitalpaper a.abo {
    top: 56px;
    padding-top: 5px;
}
#header-liberation .header-base .digitalpaper a.une {
    position: absolute;
    right: 88px;
    width: 79px;
    height: 102px;
    bottom: 8px;
}
#header-liberation .header-base .digitalpaper a.une img {
    width: 79px;
    height: 102px;
}
#header-liberation .header-base .digitalpaper .mask {
    display: block;
    position: absolute;
    bottom: 0;
    right: 0;
    width: 180px;
    height: 23px;
}
#header-liberation .header-base .nav { height: 59px }
#header-liberation .header-base .nav .nav1 a {
    position: relative;
    height: 22px;
    padding: 7px 7px 0 19px;
}
#header-liberation .header-base .nav .nav1 a span {
    position: absolute;
    display: block;
    width: 10px;
    height: 10px;
    top: 10px;
    left: 5px;
}
#header-liberation .header-base .nav .nav1 .on a span,
#header-liberation .header-base .nav-no-js>li:hover .nav1 a span,
#header-liberation .header-base .nav .nav1 a:hover span {
    width: 9px;
    height: 9px;
}
#header-liberation .header-base .nav .nav2 {
    display: none;
    height: 28px;
}
#header-liberation .header-base .nav .on .nav2 { display: block }
#header-liberation .header-base .nav .nav2 li a {
    display: block;
    height: 26px;
    padding: 6px 24px 0 0;
    font-size: 12px;
    font-family: Arial,Verdana,sans-serif;
    text-transform: none;
}
#header-liberation .header-base .nav .nav2 li a:hover { text-decoration: none }
#header-liberation .header-base .nav .nav2 li.on { font-weight: bold }
#header-liberation .header-base .nav .nav2 li a span {
    display: block;
    position: absolute;
    top: 6px;
    right: 11px;
    width: 1px;
    height: 13px;
    left: auto;
}
#header-liberation .header-base .nav .nav2 li:last-of-type a span { display: none }
#header-liberation .header-base .nav-no-js>li:hover .nav2 { display: block!important }
#header-liberation .header-base .nav-no-js:hover .on .nav2 { display: none }
#header-liberation .header-simple { margin: 0 41px }
#header-liberation .header-simple .header {
    height: 39px;
    padding-top: 20px;
}
#header-liberation .header-simple .back {
    display: block;
    float: left;
    height: 39px;
    width: 130px;
}
#header-liberation .header-simple .back a {
    display: block;
    padding-top: 11px;
    padding-left: 17px;
}
#header-liberation .header-simple .logo {
    display: block;
    float: left;
    height: 39px;
    width: 120px;
}
#header-liberation .header-simple .logo img {
    display: block;
    width: 106px;
    height: 39px;
}
#header-liberation .header-annex {
    position: relative;
    margin: 0 42px;
    padding: 20px 0 0 0;
}
#header-liberation .header-annex .logo {
    position: absolute;
    display: block;
    width: 205px;
    height: 80px;
}
#header-liberation .header-annex a.logo:hover:after {
    content: "< retour sur l'accueil";
    position: absolute;
    top: 17px;
    left: 230px;
    width: 200px;
    display: inline-block;
    padding-right: 20px;
    text-transform: none;
    font-size: 13px;
}
#header-liberation .header-annex h1,
#header-liberation .header-annex ul {
    display: block;
    margin-left: 230px;
}
#header-liberation .header-annex h1 {
    border-bottom: 1px solid;
    height: 25px;
    margin-top: 10px;
    padding: 0 0 5px 0;
    text-align: right;
    font-size: 18px;
    text-transform: uppercase;
    font-weight: normal;
}
#header-liberation .header-annex h1 a:hover:before {
    content: "< retour sur";
    display: inline-block;
    padding-right: 20px;
    text-transform: none;
    font-size: 13px;
}
#header-liberation .header-annex ul {
    display: table;
    width: 750px;
    margin-top: 10px;
    margin-bottom: 10px;
}
#header-liberation .header-annex ul li {
    display: table-cell;
    text-align: center;
}
* html #header-liberation .header-annex ul li {
    display: block;
    float: left;
}
*:first-child+html #header-liberation .header-annex ul li {
    display: block;
    float: left;
}
#header-liberation .header-annex ul li a {
    margin: 0 10px;
    display: inline-block;
    font-size: 15px;
}
.site-liberation #footer-liberation h2,
.site-liberation #footer-liberation h3 { font-family: Verdana,Arial,Helvetica,sans-serif }
#footer-liberation .footer-base { margin: 0 10px }
#footer-liberation .links {
    clear: both;
    display: block;
    padding: 28px 0;
}
#footer-liberation .abo,
#footer-liberation .monlibe,
#footer-liberation .news,
#footer-liberation .services {
    display: block;
    float: left;
}
#footer-liberation .abo {
    position: relative;
    width: 448px;
    height: 180px;
}
#footer-liberation a.visual {
    display: block;
    position: absolute;
    width: 252px;
    height: 135px;
    right: 28px;
    top: 33px;
}
#footer-liberation .abo ul li { padding: 0 0 3px 0 }
#footer-liberation .monlibe,
#footer-liberation .news,
#footer-liberation .services { min-height: 200px }
#footer-liberation .monlibe {
    width: 112px;
    margin-right: 14px;
    padding-left: 14px;
}
#footer-liberation .news {
    width: 168px;
    padding: 0 14px;
}
#footer-liberation .services {
    width: 168px;
    padding: 0 14px;
}
#footer-liberation .monlibe h5,
#footer-liberation .news h5,
#footer-liberation .services h5 {
    text-transform: uppercase;
    padding: 0 0 4px 0;
    font-size: 10px;
}
#footer-liberation .abo h2 {
    text-transform: uppercase;
    font-size: 12px;
}
#footer-liberation .abo h3 {
    text-transform: uppercase;
    font-weight: normal;
    font-size: 12px;
    margin-bottom: 20px;
}
#footer-liberation .news h5,
#footer-liberation .services h5 { margin-bottom: 10px }
#footer-liberation .news ul,
#footer-liberation .services ul {
    border-right: 1px dotted;
    font-size: 10px;
    width: 83px;
    float: left;
    min-height: 150px;
}
#footer-liberation .news ul:last-of-type,
#footer-liberation .services ul:last-of-type {
    border-right: none;
    width: 84px;
}
#footer-liberation .news ul li,
#footer-liberation .services ul li {
    padding: 0 14px 0 0;
    margin-bottom: 7px;
    line-height: 10px;
}
#footer-liberation .news ul:last-of-type li,
#footer-liberation .services ul:last-of-type li { padding: 0 0 0 14px }
#footer-liberation .references { clear: both }
#footer-liberation .references ul {
    border-top: 1px solid;
    padding: 14px 0;
}
#footer-liberation .references ul:last-child { padding-bottom: 0 }
#footer-liberation .references ul li {
    display: inline;
    padding: 0 14px 0 8px;
    font-size: 11px;
    border-right: 1px solid;
}
#footer-liberation .references ul li.first { padding-left: 0 }
#core-liberation .text h2,
#core-liberation .text h3 { margin-bottom: 14px }
#core-liberation .text sub,
#core-liberation .text sup { line-height: 10px }
#core-liberation .text-static h2,
#core-liberation .text-static h3,
#core-liberation .text-static h4 { font-family: Verdana,sans-serif }
#core-liberation .text-static h4 {
    font-size: 16px;
    font-weight: bold;
    margin-bottom: 15px;
}
#core-liberation .text-static ul li {
    margin-bottom: 10px;
    list-style: disc inside none;
}
#core-liberation .text-https h2,
#core-liberation .text-https h3,
#core-liberation .text-https h4 {
    font-family: Verdana,sans-serif;
    font-weight: normal;
}
#core-liberation .text-https h4 {
    font-size: 16px;
    font-weight: bold;
    margin-bottom: 15px;
}
#core-liberation .text-https p { padding: 0 }
#core-liberation .text-https ul li {
    margin-bottom: 10px;
    list-style: disc inside none;
}
#core-liberation .text-benefits h3 {
    font-weight: normal;
    font-size: 17px;
}
#core-liberation .text-404 h3 {
    font-style: italic;
    font-size: 16px;
}
#core-liberation .text-404 p {
    font-family: Georgia,"Times New Roman",Times,serif;
    font-style: italic;
    font-size: 13px;
}
form input[type=text],
form input[type=password] {
    border: 1px solid;
    padding: 3px;
    height: 14px;
}
form select {
    padding: 1px;
    height: 20px;
}
#core-liberation form textarea { resize: vertical }
#core-liberation form input[type=text]:focus,
#core-liberation form input[type=password]:focus,
#core-liberation form input[type=file]:focus,
#core-liberation form textarea:focus,
#core-liberation form select,
#core-liberation form checkbox { outline: 1px solid }
#core-liberation .error_ajax,
#core-liberation .error_ajax_form {
    background: #ddd;
    border: 1px solid #9d9d9d;
    padding: 10px 10px 12px;
}
#core-liberation .error_ajax_form {
    position: absolute;
    top: 130px;
    left: 105px;
    width: 230px;
}
#core-liberation .new_comment_form_wrapper { position: relative }
#core-liberation .form-monlibe {
    border-top: 1px dotted;
    border-bottom: 1px dotted;
    padding: 14px;
}
#core-liberation .form-monlibe label {
    display: block;
    margin-bottom: 4px;
}
#core-liberation .form-monlibe input[type=text],
#core-liberation .form-monlibe input[type=password],
#core-liberation .form-monlibe textarea {
    border: 1px solid;
    font-size: 12px;
    margin-bottom: 20px;
    padding: 3px;
}
#core-liberation .form-monlibe textarea { font-family: Verdana,sans-serif }
#core-liberation .form-monlibe input[type=checkbox] { float: right }
#core-liberation .w26unit .form-monlibe input[type=text],
#core-liberation .w26unit .form-monlibe input[type=password],
#core-liberation .w26unit .form-monlibe textarea { width: 652px }
#core-liberation .w17unit .form-monlibe input[type=text],
#core-liberation .w17unit .form-monlibe input[type=password],
#core-liberation .w17unit .form-monlibe textarea { width: 412px }
body.auth-unlogged #core-liberation .form-monlibe-unlogged form {
    opacity: .3;
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=30)";
    filter: alpha(opacity=30);
}
#core-liberation .form-monlibe-unlogged { position: relative }
#core-liberation .form-monlibe .note-unlogged {
    position: absolute;
    border: 1px solid;
    top: 130px;
    left: 10px;
    width: 420px;
    padding: 10px 10px 12px;
}
#core-liberation .form-monlibe .note-unlogged p {
    font-family: Georgia,"Times New Roman",Times,serif;
    font-size: 21px;
    font-weight: normal;
    line-height: 25px;
}
#core-liberation .form-monlibe .note-unlogged p.small {
    font-family: Verdana,Arial,sans-serif;
    font-size: 12px;
}
#core-liberation .form-monlibe .monlibe-edit-profile label {
    float: left;
    width: 70%;
}
#core-liberation .form-monlibe .monlibe-edit-profile p { clear: both }
#core-liberation .form-monlibe .monlibe-edit-profile .btn-monlibe { margin-top: 30px }
#core-liberation .block-comments .form-monlibe { border-top: none }
#core-liberation .block-comments .form-monlibe input[type=text],
#core-liberation .block-comments .form-monlibe textarea { width: 98% }
#core-liberation .form-contacts { width: 380px }
#core-liberation .form-contacts p { margin-bottom: 10px }
#core-liberation .form-contacts p a { font-weight: bold }
#core-liberation .form-contacts p label {
    display: block;
    padding-bottom: 5px;
    font-weight: bold;
}
#core-liberation .form-contacts p input[type=text] { width: 372px }
#core-liberation .form-contacts p textarea {
    resize: vertical;
    width: 378px;
    height: 200px;
}
#core-liberation .form-contacts p select { width: 300px }
#core-liberation .form-https {
    width: 388px;
    margin: 28px auto;
    padding: 14px;
    border-radius: 5px;
    -moz-border-radius: 5px;
    -webkit-border-radius: 5px;
    -o-border-radius: 5px;
    border: 1px solid;
}
#core-liberation .form-https p:last-child { margin-bottom: 0 }
#core-liberation .form-https p label {
    display: inline-block;
    font-weight: normal;
    margin-bottom: 7px;
}
#core-liberation .form-https p input[type=text],
#core-liberation .form-https p input[type=password] {
    display: block;
    width: 372px;
    border-radius: 2px;
    -moz-border-radius: 2px;
    -webkit-border-radius: 2px;
    -o-border-radius: 2px;
    margin-bottom: 14px;
    padding: 7px;
}
#core-liberation .form-https .btn-rounded-degraded,
#core-liberation .form-https .btn-laune {
    margin-top: 7px;
    float: right;
}
#core-liberation .col-contextual ul li { margin-bottom: 5px }
#core-liberation ul.list-links li {
    margin-bottom: 7px;
    line-height: 14px;
}
#core-liberation ul.list-links li:last-child { margin-bottom: 0 }
#core-liberation ul.list-latest-news span {
    display: block;
    text-transform: uppercase;
    font-size: 10px;
    padding-bottom: 4px;
}
#core-liberation ul.list-forums li h4 {
    padding-bottom: 4px;
    font-weight: bold;
    font-size: 12px;
}
#core-liberation ul.list-forums li h4 span { padding-left: 5px }
#core-liberation ul.list-forums span { font-weight: normal }
#core-liberation ul.list-items li {
    margin-bottom: 10px;
    clear: both;
}
#core-liberation ul.list-items li h5,
#core-liberation ul.list-items li h4,
#core-liberation ul.list-items li p { margin-left: 98px }
#core-liberation ul.list-items li h4 {
    font-family: Georgia,"Times New Roman",Times,serif;
    font-weight: bold;
    font-size: 13px;
}
#core-liberation ul.list-items li p { font-size: 11px }
#core-liberation ul.list-items span { padding: 0 5px 0 0 }
#core-liberation ul.list-items li img.visual {
    float: left;
    width: 84px;
    height: 84px;
    margin: 3px 10px 10px 0;
}
#core-liberation ul.list-items li img.square,
#core-liberation ul.list-items li img.signature {
    width: 84px;
    height: 84px;
}
#core-liberation ul.list-items li.full h5,
#core-liberation ul.list-items li.full h4,
#core-liberation ul.list-items li.full p { margin-left: 0 }
#core-liberation ul.list-items li.half img.visual { width: 130px }
#core-liberation ul.list-items li.full h5,
#core-liberation ul.list-items li.half h4,
#core-liberation ul.list-items li.half p { margin-left: 140px }
#core-liberation ul.list-items li.arround .visual {
    margin-right: 10px;
    margin-bottom: 10px;
}
#core-liberation ul.list-items li.arround h5,
#core-liberation ul.list-items li.arround h4,
#core-liberation ul.list-items li.arround p { margin-left: 0 }
#core-liberation ul.list-items li.chat p {
    display: block;
    clear: both;
    margin-left: 0;
}
#core-liberation ul.list-items li.chat h5 { margin-bottom: 5px }
#core-liberation ul.list-items-mosts li { margin-bottom: 5px }
#core-liberation ul.list-items-mosts li { font-family: Georgia,"Times New Roman",Times,serif }
#core-liberation ul.list-rss-stream { list-style: none }
#core-liberation ul.list-rss-stream li {
    list-style: none;
    margin-bottom: 20px;
}
#core-liberation ul.list-rss-stream li h5 {
    margin-bottom: 7px;
    font-weight: normal;
    text-decoration: underline;
}
#core-liberation ul.list-rss-stream li img {
    display: block;
    float: left;
    margin: 0 10px;
}
#core-liberation ul.list-rss-stream li img.xml { margin-top: 1px }
#core-liberation ul.list-rss-stream li img.google { margin-top: 0 }
#core-liberation ul.list-rss-stream li img.netvibes { margin-top: 0 }
#core-liberation ul.list-call-items li img.visual {
    display: block;
    margin-bottom: 5px;
}
#core-liberation ul.list-call-items li img.big {
    width: 280px;
    height: 187px;
}
#core-liberation ul.list-call-items li { margin-bottom: 15px }
#core-liberation ul.list-call-items li h2 { margin-bottom: 5px }
#core-liberation ul.list-call-items.sheet li h2 { font-size: 13px }
#core-liberation ul.list-call-items.folder li h2 {
    font-weight: normal;
    font-size: 19px;
}
#core-liberation ul.list-labo-meetings li {
    clear: both;
    margin-bottom: 7px;
    border-bottom: 1px solid;
}
#core-liberation ul.list-labo-meetings li .visual {
    float: left;
    margin: 3px 14px 7px 0;
    width: 56px;
    height: 56px;
}
#core-liberation ul.list-labo-meetings li h4 {
    margin-left: 70px;
    font-family: Verdana,sans-serif;
    text-transform: uppercase;
    font-size: 10px;
}
#core-liberation ul.list-labo-meetings li p {
    padding-bottom: 7px;
    margin-left: 70px;
    font-family: Georgia,"Times New Roman",Times,serif;
    font-size: 13px;
    font-weight: bold;
}
#core-liberation ul.list-labo-meetings li:last-child { border-bottom: 0 }
#core-liberation ul.list-labo-meetings li:last-child img,
#core-liberation ul.list-labo-meetings li:last-child p {
    margin-bottom: 0;
    padding-bottom: 0;
}
#core-liberation .list-man-of-day a {
    display: block;
    min-height: 100px;
    border-left: 7px solid;
    padding-left: 14px;
}
#core-liberation .list-man-of-day h2 {
    font-weight: normal;
    font-size: 20px;
}
#core-liberation .list-man-of-day h2 span { font-size: 39px }
#core-liberation .block .block-top h2 {
    margin-bottom: 10px;
    font-family: Verdana,sans-serif;
    font-weight: normal;
    font-size: 20px;
}
#core-liberation .block .block-top h5 { text-transform: uppercase }
.block .block-content { padding: 0 }
#core-liberation .block .block-bottom .pager { padding: 6px 0 0 }
.block-solid-c1 { padding: 10px }
.block-solid-c1 .block-bottom { border-top: 1px solid }
.block-solid-c1 .block-bottom a.lnk-readmore { font-size: 11px }
.block-solid-c2 { padding: 10px }
.block-solid-c2 hr {
    border-left: 0;
    border-right: 0;
    border-top: 1px solid;
    border-bottom: 2px solid;
    margin: 10px 0;
}
.block-solid-c2 h5 { font-weight: normal }
.col-contextual .block {
    margin: 14px 0;
    padding: 10px 14px 14px;
}
.col-contextual .block.block-ad { width: auto }
.col-contextual .block-ad iframe {
    display: block;
    margin-left: auto;
    margin-right: auto;
}
.w11unit .col-contextual .block-ad iframe { max-width: 308px }
.col-contextual>div:first-child,
.col-contextual>.first {
    margin-top: 0;
    margin-bottom: 0;
}
.col-contextual>.div:last-child,
.col-contextual>.block:last-child { margin-bottom: 28px }
.col-contextual .block .block-top {
    text-transform: uppercase;
    font-weight: bold;
    border-bottom: 1px solid;
    padding-bottom: 4px;
    margin-bottom: 14px;
}
.col-contextual .block .block-bottom {
    border-top: 1px solid;
    margin-top: 14px;
    padding-top: 4px;
}
.col-contextual .block .block-bottom a.lnk-readmore { font-size: 11px }
#core-liberation .col-contextual .block .block-content .visual100 {
    width: 280px;
    height: auto;
}
.col-contextual .block-iframe { padding: 0 }
.col-contextual .block-iframe .block-top {
    padding: 10px 0 4px;
    margin: 0 14px 14px;
    border-bottom: 1px solid;
}
.col-contextual .block-iframe .block-top>div {
    border-bottom: 1px solid;
    padding-bottom: 5px;
}
.col-contextual .block-iframe .block-top .right {
    padding-top: 2px;
    text-transform: none;
    font-size: 10px;
}
.col-contextual .ad-square,
.col-contextual .block-ad {
    display: block;
    margin: 14px auto;
    width: 300px;
}
.col-contextual .headrest { margin-bottom: 3px }
.col-contextual .block .headrest { margin-bottom: 0 }
.col-contextual .block-nobg { padding: 10px 0 }
.col-contextual .block-solid-c2 .block-top { border-bottom: 3px solid }
.col-part .block {
    margin-bottom: 7px;
    border-radius: 10px;
    -moz-border-radius: 10px;
    -webkit-border-radius: 10px;
}
.col-part .block .block-top {
    text-transform: uppercase;
    font-weight: bold;
    padding: 7px 0 7px;
    text-align: center;
}
.col-part .block .block-content { padding: 0 0 1px 0 }
.col-part .block hr {
    border: 0;
    border-top: 1px solid;
}
.col-part .block img.visual {
    display: block;
    margin: 0 auto 7px;
}
.col-part .block img.left {
    float: left;
    margin-right: 5px;
    margin-bottom: 5px;
}
.col-part .block p {
    margin-bottom: 7px;
    padding: 0 10px;
}
.col-part .block p.center { text-align: center }
.col-part .block .follow-libe .fb,
.col-part .block .follow-libe .twitter,
.col-part .block .follow-libe .nv-rss { padding-top: 7px }
.col-part .block .follow-libe .fb p,
.col-part .block .follow-libe .twitter p,
.col-part .block .follow-libe .nv-rss p { font-size: 10px }
.col-part .block .follow-libe .twitter p { padding: 0 5px 0 10px }
.col-part .block .follow-libe .nv-rss a.nv,
.col-part .block .follow-libe .nv-rss a.rss {
    display: inline-block;
    height: 18px;
    padding: 2px 0 0 23px;
}
.col-part .block .follow-libe .nv-rss a.rss { background: url('http://s0.libe.com/libe/img/common/ico-rss.jpg?e5d7b4c9c034') no-repeat 0 1px }
.col-part .block .follow-libe .nv-rss a.nv {
    background: url('http://s0.libe.com/libe/img/common/ico-netvibes.jpg?f74e57884286') no-repeat 0 1px;
    padding-right: 3px;
}
.col-part .block .follow-libe img.clear {
    display: block;
    margin-top: 5px;
}
.col-part .block .follow-libe img.visual { margin-top: 7px }
.block-basic-rounded { margin-bottom: 20px }
.block-basic-rounded .block-content { padding: 14px }
#core-liberation .block-item { margin-bottom: 28px }
#core-liberation .block-item .toolbox {
    margin: 21px 0;
    clear: both;
}
#core-liberation .block-item .object-header h1 { margin-bottom: 14px }
#core-liberation .block-item .object-header h5 { margin-bottom: 14px }
#core-liberation .block-item .object-picture .visual100 { margin-bottom: 4px }
#core-liberation .block-item .object-picture .legende {
    margin-bottom: 21px;
    line-height: 15px;
    font-size: 11px;
}
#core-liberation .block-item .object-media { margin-bottom: 14px }
#core-liberation .block-item .object-content div.author { margin-bottom: 15px }
#core-liberation .block-item .object-content div.author p {
    display: inline;
    font-size: 10px;
}
#core-liberation .block-item .object-content div.author strong small {
    text-transform: none;
    font-size: 10px;
    font-weight: normal;
}
#core-liberation .block-item .object-content h2 {
    margin-bottom: 17px;
    line-height: 1.39em;
}
.site-liberation .block-item .object-content a { text-decoration: underline }
#core-liberation .w17unit .block-item .object-content img { max-width: 476px }
#core-liberation .block-item .object-workinfos {
    margin: 21px 0;
    font-size: 13px;
    color: #999;
}
#core-liberation .block-item .object-workinfos .author {
    font-size: 13px;
    font-weight: bold;
}
#core-liberation .block-item .object-workinfos .work {
    color: #222;
    font-weight: bold;
}
#core-liberation .block-item h2 {
    font-weight: bold;
    font-family: Verdana,sans-serif;
    font-size: 13px;
}
#core-liberation .selected-comments .comment_reply_links { display: none }
#core-liberation .block-item-locked {
    margin-bottom: 20px;
    padding: 20px 0;
    border-top: 1px solid;
    border-bottom: 1px solid;
}
#core-liberation .block-item-locked .block-top {
    height: 17px;
    text-transform: uppercase;
    font-weight: normal;
    font-size: 14px;
}
#core-liberation .block-item-locked .block-top span {
    margin-left: 20px;
    padding: 0 7px 0 10px;
}
#core-liberation .block-item-locked .block-content { padding: 20px 0 10px }
#core-liberation .block-item-locked h6 {
    font-family: Georgia,"Times New Roman",Times,serif;
    font-size: 16.5px;
    font-weight: normal;
}
#core-liberation .block-item-locked a { text-decoration: none }
#core-liberation .block-item-locked .visual {
    margin: 18px 0 0 20px;
    display: block;
    float: left;
    width: 216px;
    height: 149px;
}
#core-liberation .block-item-locked h2,
#core-liberation .block-item-locked h3,
#core-liberation .block-item-locked p { margin-left: 270px }
#core-liberation .block-item-locked h3 {
    font-style: italic;
    font-size: 15px;
    margin-bottom: 10px;
}
#core-liberation .block-item-locked h3 .chiffre {
    font-size: 29px;
    padding: 0 3px;
}
#core-liberation .block-item-locked h3 .euro { font-size: 19px }
#core-liberation .block-item-locked .btn-zoneabo {
    margin: 0 0 15px 270px;
    width: 158px;
}
#core-liberation .block-item-locked .btn-zoneabo a {
    text-decoration: none;
    text-align: center;
}
#core-liberation .block-item-locked .btn-zoneabo a:hover { text-decoration: underline }
#core-liberation .block-item-locked p.already {
    font-size: 10px;
    margin-bottom: 0;
}
#core-liberation .block-item-locked .offre-1-euro .offer {
    display: block;
    height: 110px;
    margin-left: 270px;
    padding-top: 17px;
}
#core-liberation .block-item-locked .offre-1-euro .offer h6 {
    margin-bottom: 10px;
    text-transform: uppercase;
}
#core-liberation .block-item-locked .offre-1-euro .offer .price {
    display: inline-block;
    margin-right: 10px;
    float: left;
    font-family: Georgia,"Times New Roman",Times,serif;
    font-size: 50px;
    line-height: 30px;
}
#core-liberation .block-item-locked .offre-1-euro .offer .price:first-letter {
    font-size: 80px;
    line-height: 40px;
}
#core-liberation .block-item-locked .offre-1-euro .offer .price span {
    display: block;
    font-size: 14px;
}
#core-liberation .block-item-locked .offre-1-euro .offer p {
    margin-left: 0;
    font-family: Georgia,"Times New Roman",Times,serif;
    font-size: 14px;
    line-height: 14px;
}
#core-liberation .block-item-locked .offre-1-euro .btn-zoneabo {
    width: 159px;
    margin-left: 278px;
}
#core-liberation .block-item-read-more {
    margin-bottom: 28px;
    border: 1px solid;
}
#core-liberation .block-item-read-more .block-top {
    float: left;
    margin-top: -10px;
    margin-left: -1px;
    text-transform: uppercase;
    font-weight: bold;
    font-size: 14px;
    padding: 0 12px 5px 0;
    margin-bottom: 5px;
}
#core-liberation .block-item-read-more .block-content { clear: both }
#core-liberation .block-item-read-more .block-content .mini-tpl {
    margin-bottom: 21px;
    padding: 0 14px;
}
#core-liberation .block-item-read-more .block-content .mini-tpl h5 { margin-bottom: 7px }
#core-liberation .block-item-read-more .block-content .mini-tpl .visual { margin-right: 14px }
#core-liberation .block-item-read-more .block-content .mini-tpl hr {
    clear: both;
    border: none;
    border-top: 1px dotted;
    width: 140px;
    margin: 14px auto;
}
#core-liberation .block-comments .block-content .block-comments-tree { overflow: hidden }
#core-liberation .block-comments .block-content .comment { border-left: 1px solid }
#core-liberation .block-comments .block-content .comment_level_0 .comment { margin-left: 14px }
#core-liberation .block-comments .block-content .comment_outer {
    overflow: hidden;
    border-right: 1px solid;
    border-bottom: 1px solid;
    padding: 14px;
}
#core-liberation .flat-comments .comment,
#core-liberation .block-comments .comment_level_0 {
    margin-top: 20px;
    border-top: 1px solid;
}
#core-liberation .flat-comments .comment:first-of-type,
#core-liberation .block-comments .comment_level_0:first-of-type { margin-top: 0 }
#core-liberation .flat-comments .comment>.comment_outer,
#core-liberation .block-comments .comment_level_0>.comment_outer {
    margin-left: -1px;
    border: 1px solid;
    border-top: none;
}
#core-liberation .block-comments .block-content .detail_comment {
    border-top: 1px solid;
    margin-top: -1px;
}
#core-liberation .block-comments .block-content .detail_comment>.comment_outer {
    margin-left: -1px;
    border: 1px solid;
    border-top: none;
}
#core-liberation .block-comments .block-content .comment_selected>.comment_outer .icon {
    position: absolute;
    right: 0;
    top: 0;
    display: block;
    width: 28px;
    height: 25px;
    background: url('http://s0.libe.com/libe/img/common/_sprites_icons/icons.png?9914d0d70a49') no-repeat -59px -36px;
}
#core-liberation .block-comments .block-content .comment_selected>.comment_outer .meta .who,
#core-liberation .block-comments .block-content .comment_selected>.comment_outer .meta .details,
#core-liberation .block-comments .block-content .comment_selected>.comment_outer .meta .note { padding-right: 35px }
#core-liberation .block-comments .block-content .comment_draft>.comment_outer { background-image: url('http://s0.libe.com/libe/img/common/bg-comment-draft.png?4158f727c626') }
#core-liberation .block-comments .block-content .comment_collapsed>.comment_content>*,
#core-liberation .block-comments .block-content .comment_collapsed>.visual { display: none }
#core-liberation .block-comments .block-content .comment_expanded>.comment_content>*,
#core-liberation .block-comments .block-content .comment_expanded>.visual { display: block }
#core-liberation .block-comments .block-content .meta {
    min-height: 75px;
    margin-bottom: 5px;
    position: relative;
    line-height: 15px;
}
#core-liberation .block-comments .block-content .meta img.visual {
    display: block;
    float: left;
    width: 56px;
    height: 56px;
    margin-right: 14px;
    margin-top: 3px;
}
#core-liberation .block-comments .block-content .meta .who,
#core-liberation .block-comments .block-content .meta .details,
#core-liberation .block-comments .block-content .meta .note,
#core-liberation .block-comments .block-content .meta .when { display: block }
#core-liberation .block-comments .block-content .meta .details,
#core-liberation .block-comments .block-content .meta .note { font-size: 10px }
#core-liberation .block-comments .block-content .meta .details a.profile { display: none }
#core-liberation .block-comments .block-content .comment_hover .meta .details a.profile { display: block }
#core-liberation .block-comments .block-content .meta .when {
    position: absolute;
    right: 0;
    bottom: 16px;
    font-size: 11px;
}
#core-liberation .block-comments .block-content .comment_title {
    display: block;
    clear: both;
    font-weight: bold;
    font-size: 12px;
    font-family: Verdana,sans-serif;
    margin-bottom: 10px;
}
#core-liberation .block-comments .block-content .comment_reply_links {
    padding: 14px 0 0 0;
    height: 30px;
}
#core-liberation .block-comments .block-content .comment_reply_links .comment_flag,
#core-liberation .block-comments .block-content .comment_reply_links .comment_post_new {
    display: none;
    float: right;
    margin-right: 10px;
    padding-top: 5px;
}
#core-liberation .block-comments .block-content .comment_reply_links .comment_flag .icon {
    position: static;
    display: block;
    width: 13px;
    height: 12px;
    float: left;
    background-image: url('http://s0.libe.com/libe/img/common/_sprites_icons/icons.png?9914d0d70a49');
    background-repeat: no-repeat;
    background-position: -33px -2px;
    margin: 3px 6px 0 0;
}
#core-liberation .block-comments .block-content .comment_reply_links .comment_flag:hover .icon { background-position: -33px -18px }
#core-liberation .block-comments .block-content .comment_reply_links .comment_flag:hover { text-decoration: none }
#core-liberation .block-comments .block-content .comment_reply_links .comment_reply {
    display: none;
    float: right;
    padding: 5px 10px 7px;
    border-radius: 5px 5px 5px 5px;
    -moz-border-radius: 5px 5px 5px 5px;
    -webkit-border-radius: 5px 5px 5px 5px;
}
#core-liberation .block-comments .block-content .comment_reply_links .comment_reply:hover { text-decoration: none }
#core-liberation .block-comments .block-content .comment_libe>.comment_outer .meta .icon {
    position: absolute;
    right: 0;
    top: 0;
    display: block;
    width: 36px;
    height: 13px;
    background: url('http://s0.libe.com/libe/img/common/_sprites_icons/icons.png?9914d0d70a49') no-repeat 0 -84px;
}
#core-liberation .block-comments .block-content .comment_libe>.comment_outer .meta .who,
#core-liberation .block-comments .block-content .comment_libe>.comment_outer .meta .details,
#core-liberation .block-comments .block-content .comment_libe>.comment_outer .meta .note { padding-right: 41px }
#core-liberation .block-comments .block-content .is_removed>.comment_outer { padding: 3px 8px 5px }
#core-liberation .block-comments .block-content .is_removed>.comment_outer .icon {
    float: left;
    display: block;
    width: 12px;
    height: 11px;
    margin: 3px 8px 0 0;
    background: url('http://s0.libe.com/libe/img/common/_sprites_icons/icons.png?9914d0d70a49') no-repeat 0 0;
}
#core-liberation .block-comments .comment_replies {
    padding: 10px;
    display: none;
    border-bottom: 1px solid;
}
#core-liberation .block-comments .comment_cutoff { display: block }
#core-liberation .block-usercomments .comment_replies { display: block }
#core-liberation .block-usercomments .noreplies { display: none }
#core-liberation .block-comments .headrest-community h3 a:hover { text-decoration: none }
#core-liberation .block-comments .headrest-community a.folded:after,
#core-liberation .block-comments .headrest-community a.unfolded:after {
    display: inline-block;
    content: '';
    background-image: url('http://s0.libe.com/libe/img/common/_sprites_icons/icons.png?9914d0d70a49');
    background-repeat: no-repeat;
}
#core-liberation .block-comments .headrest-community a.folded:after {
    background-position: -85px -69px;
    margin: 0 0 2px 7px;
    width: 6px;
    height: 8px;
}
#core-liberation .block-comments .headrest-community a.unfolded:after {
    background-position: -76px -69px;
    margin: 0 0 2px 7px;
    width: 8px;
    height: 7px;
}
lnk-back .comment_god_actions {
    float: left;
    display: none;
    padding: 10px 10px 0 0;
}
.comment_hover .comment_god_actions { display: block }
.comment_god_actions ul,
.comment_god_actions li,
.comment_god_actions form { display: inline-block }
.profile_god_actions { margin-top: 10px }
.god input[type=text] { width: 1em }
.god {
    color: #333;
    background-color: #f1f1f1;
    border: 1px solid #FE9900;
}
a.god:hover {
    background: #3c3c3c;
    color: #fff;
    text-decoration: none;
}
.god .symbol { font-size: 18px }
.suspend input { width: 30px }
#bar-liberation .god {
    font-weight: bold;
    text-align: center;
    height: 94%;
    border: 1px solid #000;
    background-color: #fff;
}
#bar-liberation .god ul {
    display: block;
    text-align: left;
}
#bar-liberation .god li {
    display: inline-block;
    text-align: center;
    width: 86px;
    vertical-align: top;
    height: 38px;
}
#bar-liberation .other .god a {
    padding: 5px;
    -moz-box-sizing: border-box;
    -webkit-box-sizing: border-box;
}
#bar-liberation .other .god a:hover {
    background-color: yellow;
    color: #000;
}
#bar-liberation .god .godenabled a {
    background: #3c3c3c;
    color: #fff;
}
#bar-liberation .god a.godenter { background: url('http://s0.libe.com/libe/img/common/icon_godenter.png?9ffa63824b5c') no-repeat center center #fff }
#bar-liberation .god a.godquit { background: url('http://s0.libe.com/libe/img/common/icon_godquit.png?a59104f30cfb') no-repeat center center #000 }
#bar-liberation .god a.godquit:hover { background: url('http://s0.libe.com/libe/img/common/icon_godenter.png?9ffa63824b5c') no-repeat center center yellow }
#bar-liberation .god a.jumptoadmin { background: url('http://s0.libe.com/back/img/icon_home.png?c1de55b52ccc') no-repeat center center #fff }
#bar-liberation .god a.jumptoedit { background: url('http://s0.libe.com/back/img/icon_changelink.png?4a31d309d5db') no-repeat center center #fff }
#mainContent .god {
    font-size: 10px;
    padding: 6px;
    border-radius: 2px;
    -moz-border-radius: 4px;
    -webkit-border-radius: 4px;
}
#core-liberation .block-partnership .block-content img.visual {
    display: block;
    float: left;
    width: 140px;
    margin-top: 4px;
    margin-bottom: 10px;
}
#core-liberation .block-partnership .block-content h4 {
    font-family: Verdana,sans-serif;
    font-size: 12px;
    font-weight: bold;
    margin: 0 0 11px 150px;
}
#core-liberation .block-partnership .block-content p { margin: 0 0 10px 154px }
#core-liberation .block-partnership .block-content ul {
    clear: both;
    margin: 10px 0 0;
}
#core-liberation .block-partnership .block-content ul li a,
#core-liberation .block-partnership .block-content a.arrow {
    background: url('http://s0.libe.com/libe/img/common/ico-lnk-arrow-red.gif?feba6ff926a7') no-repeat 0 4px;
    padding-left: 15px;
}
#core-liberation .block-pager-labo { padding: 14px }
#core-liberation .block-pager-labo .block-top,
#core-liberation .block-pager-labo .block-content { margin-bottom: 14px }
#core-liberation .block-pager-labo .list li { margin-bottom: 0 }
#core-liberation .block-pager-labo .list img.visual {
    display: block;
    margin-bottom: 7px;
}
#core-liberation .block-pager-labo .list h5 { margin-bottom: 7px }
#core-liberation .block-pager-labo .block-bottom { border-top: 1px solid }
#core-liberation .block-pager-labo .block-bottom .pager { padding-top: 13px }
#core-liberation .block-pager-labo .block-bottom .right { padding-top: 7px }
#core-liberation .w35unit .block-pager-labo .list li {
    width: 308px;
    margin-left: 14px;
}
#core-liberation .w29unit .block-pager-labo .list li {
    width: 252px;
    margin-left: 14px;
}
#core-liberation .w35unit .block-pager-labo .list img.visual {
    width: 308px;
    height: 173px;
}
#core-liberation .w29unit .block-pager-labo .list img.visual {
    width: 252px;
    height: 142px;
}
#core-liberation .col .block-pager-labo .list li:first-child,
#core-liberation .col .block-pager-labo .list li.new-line { margin-left: 0 }
#core-liberation .block-podcast .block-content p.note { font-size: 10px }
#core-liberation .block-podcast .block-content p.logo-pc {
    background: url('http://s0.libe.com/libe/img/common/bg-podcast.png?bc9501afa40e') no-repeat left center;
    padding: 0 0 0 85px;
}
#core-liberation .block-podcast .block-content p { margin-bottom: 10px }
#core-liberation .block-podcast .block-content .lnk-podcast p {
    font-size: 12px;
    margin-bottom: 5px;
    text-align: right;
    text-decoration: underline;
    font-weight: bold;
}
#core-liberation .block-podcast .block-content .lnk-podcast ul {
    display: block;
    height: 20px;
}
#core-liberation .block-podcast .block-content .lnk-podcast ul li {
    display: block;
    float: right;
    padding-left: 10px;
}
#core-liberation .block-benefits .block-content img.visual {
    display: block;
    float: left;
    width: 112px;
    height: 210px;
    margin: 4px 14px 0 0;
}
#core-liberation .block-benefits .block-content .icon {
    float: left;
    margin: 3px 5px 0 0;
}
#core-liberation .block-benefits .block-content ul li { margin-bottom: 0 }
#core-liberation .block-benefits .block-content ul li.b-top {
    border-top: 1px solid;
    padding-top: 21px;
    margin-top: 21px;
}
#core-liberation .block-benefits .block-content .btn-monlibe {
    width: 100px;
    margin-left: 126px;
    text-align: center;
}
#core-liberation .block-benefits .block-content .text-benefits li h5,
#core-liberation .block-benefits .block-content .text-benefits li h3,
#core-liberation .block-benefits .block-content .text-benefits li p { margin-left: 126px }
#core-liberation .col-contextual .block-label { padding: 0 }
#core-liberation .col-contextual .block-label .block-content { padding: 0 }
#core-liberation .block-label img.visual {
    display: block;
    float: left;
    width: 84px;
    height: 84px;
}
#core-liberation .block-label a {
    display: block;
    float: left;
    width: 203px;
    height: 60px;
    padding: 7px 7px 7px 14px;
    overflow: hidden;
}
#core-liberation .block-section .block-content img.visual {
    display: block;
    margin-bottom: 14px;
    width: 280px;
    height: 187px;
}
#core-liberation .block-section .block-content h3 {
    margin-bottom: 4px;
    font-size: 19px;
    font-weight: normal;
}
#core-liberation .block-section .block-content h4 {
    margin-bottom: 4px;
    font-size: 13px;
    font-weight: bold;
}
#core-liberation .block-section .block-content a {
    clear: both;
    display: block;
    margin-top: 7px;
}
#core-liberation .block-np .block-top h5 {
    font-size: 12px;
    letter-spacing: -1px;
}
#core-liberation .block-np .block-top h5 .right {
    display: block;
    text-transform: none;
    font-size: 10px;
    padding-top: 2px;
}
#core-liberation .block-np p {
    text-align: center;
    font-size: 11px;
}
#core-liberation .block-np .today img.visual {
    display: block;
    height: 250px;
    width: 194px;
    margin: 0 auto 14px;
}
#core-liberation .block-np .tomorrow .progress-nb {
    display: block;
    margin-bottom: 3px;
}
#core-liberation .block-np .tomorrow .progress-bar {
    display: block;
    margin-bottom: 14px;
    height: 7px;
}
#core-liberation .block-np .tomorrow .progress-bar .done {
    display: block;
    float: left;
    height: 7px;
}
#core-liberation .block-np .railway {
    position: relative;
    margin-bottom: 15px;
    height: 191px;
    overflow: hidden;
}
#core-liberation .block-np .railway .box {
    position: absolute;
    top: 0;
    left: 0;
    padding-left: 1px;
}
#core-liberation .block-np .railway .box h5 { display: none }
#core-liberation .block-np .railway ul {
    width: 280px;
    clear: both;
}
#core-liberation .block-np .block-content .railway ul li {
    float: left;
    width: 42px;
    height: 57px;
    margin-bottom: 10px;
}
#core-liberation .block-np .block-content .railway ul li.p-l {
    margin-right: 2px;
    margin-left: 3px;
}
#core-liberation .block-np .block-content .railway ul li.p-r { margin-right: 4px }
#core-liberation .block-np .block-content .railway ul li img {
    display: block;
    width: 39px;
    height: 50px;
    border: 1px solid;
}
#core-liberation .block-np .pager { margin-bottom: 7px }
#core-liberation .block-np .pager span {
    float: right;
    padding-right: 5px;
    font-size: 11px;
    margin-top: 1px;
}
#core-liberation .block-np .pager ul {
    margin-left: 2px;
    margin-top: 6px;
}
#core-liberation .block-np .from p {
    margin-bottom: 14px;
    font-size: 12px;
}
#core-liberation .block-np .from ul {
    height: 150px;
    margin-bottom: 7px;
}
#core-liberation .block-np .from ul li { margin-bottom: 14px }
#core-liberation .block-np .from ul li.l {
    width: 133px;
    float: left;
}
#core-liberation .block-np .from ul li.l img.visual { float: right }
#core-liberation .block-np .from ul li.r {
    width: 133px;
    float: right;
    text-align: left;
}
#core-liberation .block-np .from ul li img.visual {
    display: block;
    height: 148px;
    border: 1px solid;
}
.w11unit .block-np .from .btn-read-digitalpaper a,
.w11unit .block-np .from .btn-read-digitalpaper span {
    display: table-cell;
    vertical-align: middle;
    width: 214px;
    height: 32px;
}
.col-contextual .block-subscribe-newsletter .visual {
    display: block;
    float: left;
    margin: 3px 14px 14px 0;
    background: url('http://s0.libe.com/libe/img/common/_sprites_icons/icons.png?9914d0d70a49') no-repeat -144px -36px;
    width: 56px;
    height: 37px;
}
.col-contextual .block-subscribe-newsletter p { margin: 0 0 14px 74px }
.col-contextual .block-subscribe-newsletter p strong {
    display: inline-block;
    margin-bottom: 7px;
}
.col-contextual .block-subscribe-newsletter input[type=submit] { float: right }
.col-contextual .block-subscribe-newsletter input[type=text] {
    float: left;
    width: 169px;
    height: 18px;
}
#core-liberation .col-contextual .block-promo .block-content img.visual {
    display: block;
    float: left;
    width: 140px;
    margin-top: 4px;
    margin-bottom: 10px;
}
#core-liberation .col-contextual .block-promo .block-content h4 {
    font-family: Verdana,sans-serif;
    font-size: 12px;
    font-weight: bold;
    margin: 0 0 11px 154px;
}
#core-liberation .col-contextual .block-promo .block-content p { margin: 0 0 10px 154px }
#core-liberation .col-contextual .block-promo .block-content ul {
    clear: both;
    margin: 10px 0 0;
}
#core-liberation .col-contextual .block-promo .block-content ul li a,
#core-liberation .col-contextual .block-promo .block-content a.arrow {
    background: url('http://s0.libe.com/libe/img/common/ico-lnk-arrow-red.gif?feba6ff926a7') no-repeat 0 4px;
    padding-left: 15px;
}
#core-liberation .block-all-forums .headrest {
    margin: 0 0 7px;
    border-bottom: 1px solid;
}
#core-liberation .block-all-forums .headrest h5 {
    border-bottom: 0;
    text-transform: none;
    padding: 0 0 7px;
}
#core-liberation .block-all-forums .headrest .community-bubble {
    float: left;
    margin: 4px 10px 0 0;
}
#core-liberation .block-all-forums .block-top,
#core-liberation .block-all-forums .block-content .forums-most { margin-bottom: 28px }
#core-liberation .block-all-forums .block-top .filters .on { font-weight: bold }
#core-liberation .block-all-forums .forums-most .comment_reply_links {
    display: none;
    visibility: hidden;
}
#core-liberation .block-all-forums .forum {
    clear: both;
    border-bottom: 1px solid;
    padding: 14px 0;
}
#core-liberation .block-all-forums .forum:first-child { padding-top: 0 }
#core-liberation .block-all-forums .forum h5.title {
    margin-bottom: 7px;
    margin-left: 0;
}
#core-liberation .block-all-forums .forum h5.title .right { font-weight: normal }
#core-liberation .block-all-forums .forum h5.title .community-bubble {
    float: left;
    margin: 1px 10px 0 0;
}
#core-liberation .block-all-forums .forum img.visual {
    display: block;
    float: left;
    margin: 4px 0 0 0;
    width: 56px;
    height: 56px;
}
#core-liberation .block-all-forums .forum h5 {
    margin-left: 70px;
    margin-bottom: 7px;
}
#core-liberation .block-all-forums .forum p.subtitle { margin-left: 70px }
#core-liberation .block-all-forums .forum span.infos {
    margin-left: 70px;
    display: block;
}
#core-liberation .block-all-forums .forum span.infos a { font-weight: bold }
#core-liberation .block-all-forums table {
    width: 100%;
    margin-bottom: 28px;
}
#core-liberation .block-all-forums table th { width: 20% }
#core-liberation .block-all-forums table th.subject { width: 60% }
#core-liberation .block-all-forums table .subject { text-align: left }
#core-liberation .block-all-forums table .date {
    text-align: right;
    white-space: nowrap;
}
#core-liberation .block-all-forums table .ft-c { text-align: center }
#core-liberation .block-all-forums table th,
#core-liberation .block-all-forums table td { padding: 4px 0 6px }
#core-liberation .block-all-blogs { margin-bottom: 28px }
#core-liberation .block-all-blogs .block-content .headrest { border-bottom: 1px dotted #ddd }
#core-liberation .block-all-blogs .headrest h4 { text-transform: uppercase }
#core-liberation .block-all-blogs .headrest h5 {
    text-transform: uppercase;
    padding: 5px 9px 6px;
    float: left;
}
#core-liberation .block-all-blogs .block-content .list .mini-tpl { border-bottom: 0 }
#core-liberation .block-all-blogs .block-content .list li { clear: none }
#core-liberation .block-all-blogs .block-content .list li.new-line { clear: both }
#core-liberation .block-all-blogs .block-content .list .blog h5 .icon { display: none }
#core-liberation .block-all-blogs .block-content .list .blog-libe h5 .icon {
    display: block;
    position: absolute;
    background: url('http://s0.libe.com/libe/img/common/_sprites_icons/icons.png?9914d0d70a49') no-repeat -38px -84px;
    width: 20px;
    height: 7px;
    margin-top: 4px;
    top: 7px;
    right: 7px;
}
#core-liberation .block-all-blogs .block-content .list .blog-libe { padding-top: 3px }
#core-liberation .block-all-blogs .block-content .list .blog-libe h5 {
    position: relative;
    display: block;
    padding: 7px 40px 7px 7px;
}
#core-liberation .block-all-blogs .block-content .list .blog-libe img.visual { margin-top: 0 }
#core-liberation .block-search-head form input[type=submit],
#core-liberation .block-search-results form input[type=submit] {
    background-image: url('http://s0.libe.com/libe/img/common/bg-search-formsubmit.png?96b143873213');
    background-repeat: repeat-x;
    background-position: 0 0;
    border-style: solid;
    border-width: 1px;
    padding: 1px 3px 3px;
    height: 22px;
}
#core-liberation .block-search-head form input[type=submit]:hover { background-image: url('http://s0.libe.com/libe/img/common/bg-search-formsubmit-on.png?21388ca68b89') }
#core-liberation .block-search-results form input[type=submit]:active { background-image: url('http://s0.libe.com/libe/img/common/bg-search-formsubmit-active.png?16bd2d8fbc96') }
#core-liberation .block-search-head .pagination { border-top: 0 }
#core-liberation .block-search-results .pagination { border-bottom: 0 }
#core-liberation .block-search-head .pagination a,
#core-liberation .block-search-results .pagination a { background-color: #fff }
#core-liberation .block-search-head .pagination .prev,
#core-liberation .block-search-results .pagination .prev {
    margin-left: 0;
    padding-left: 17px;
}
#core-liberation .block-search-head .pagination .next,
#core-liberation .block-search-results .pagination .next {
    margin-right: 0;
    padding-right: 17px;
}
#core-liberation .block-search-head { margin-bottom: 20px }
#core-liberation .block-search-head h1 {
    font-family: Verdana,sans-serif;
    font-size: 18px;
    margin-bottom: 14px;
}
#core-liberation .block-search-head .basic { padding-bottom: 7px }
#core-liberation .block-search-head .basic label { display: none }
#core-liberation .block-search-head .basic input[type=text] { width: 521px }
#core-liberation .block-search-head .basic input[type=submit] {
    width: 80px;
    float: right;
}
#core-liberation .block-search-head .basic p {
    float: left;
    padding: 0;
}
#core-liberation .block-search-head .advanced {
    clear: both;
    margin-bottom: 21px;
    border-top: 1px dotted;
}
#core-liberation .block-search-head .advanced .note {
    display: block;
    position: relative;
    border-radius: 0 0 10px 10px;
    -moz-border-radius: 0 0 10px 10px;
    -webkit-border-radius: 0 0 10px 10px;
}
#core-liberation .block-search-head .advanced .note a.displayer {
    display: block;
    padding: 5px 16px 7px 0;
    float: right;
    font-weight: bold;
    background-image: url('http://s0.libe.com/libe/img/common/bg-search-down.png?b74f495d5e6b');
    background-repeat: no-repeat;
    background-position: right 10px;
    margin-right: 14px;
}
#core-liberation .block-search-head .displayed .note a.displayer { background-image: url('http://s0.libe.com/libe/img/common/bg-search-up.png?6f25843d1bc2') }
#core-liberation .block-search-head .advanced .note .links {
    display: block;
    padding: 5px 0 0 14px;
}
#core-liberation .block-search-head .advanced .searchform {
    height: 0;
    overflow: hidden;
}
#core-liberation .block-search-head .advanced .searchform select { font-size: 10px }
#core-liberation .block-search-head .advanced .searchform .period,
#core-liberation .block-search-head .advanced .searchform .between,
#core-liberation .block-search-head .advanced .searchform .source,
#core-liberation .block-search-head .advanced .searchform .category {
    padding: 7px 14px 7px;
    border-bottom: 1px dotted;
    font-size: 11px;
}
#core-liberation .block-search-head .advanced .searchform .period label { padding-right: 4px }
#core-liberation .block-search-head .advanced .searchform .period ul li { display: inline }
#core-liberation .block-search-head .advanced .searchform .between .from,
#core-liberation .block-search-head .advanced .searchform .between .to {
    display: inline;
    padding-left: 5px;
}
#core-liberation .block-search-head .advanced .searchform .between span { padding-right: 5px }
#core-liberation .block-search-head .advanced .searchform .source ul,
#core-liberation .block-search-head .advanced .searchform .source ul li { display: inline }
#core-liberation .block-search-head .advanced .searchform .source ul li { padding: 0 20px 0 12px }
#core-liberation .block-search-head .advanced .searchform .category select {
    margin-left: 20px;
    outline: none;
}
#core-liberation .block-search-head .advanced .searchform input[type=submit] { margin: 10px 0 0 165px }
#core-liberation .block-search-head .results { margin-bottom: 15px }
#core-liberation .block-search-head .results p { margin-bottom: 15px }
#core-liberation .block-search-head .results p.filters {
    text-align: right;
    margin-bottom: 0;
}
#core-liberation .block-search-results .block-top { margin-bottom: 0 }
#core-liberation .block-search-results .block-top h2 {
    margin-bottom: 0;
    border-bottom: 1px dotted;
    padding-bottom: 5px;
    font-family: Verdana,sans-serif;
    font-size: 18px;
    font-weight: bold;
}
#core-liberation .block-search-results .tpl-search-results { margin-bottom: 0 }
#core-liberation .block-search-results .tpl-search-results .object-content { padding-top: 14px }
#core-liberation .block-search-results .tpl-search-results .object-picture { top: 14px }
#core-liberation .block-search-results .tpl-search-results .folder .object-content,
#core-liberation .block-search-results .tpl-search-results .emission .object-content { min-height: 53px }
#core-liberation .block-search-results .tpl-search-results .article .object-content { min-height: 116px }
#core-liberation .block-search-results .tpl-search-results .category .object-content { margin-right: 0 }
#core-liberation .block-search-results .tpl-search-results .emission .object-picture,
#core-liberation .block-search-results .tpl-search-results .folder .object-picture,
#core-liberation .block-search-results .tpl-search-results .emission .object-picture img,
#core-liberation .block-search-results .tpl-search-results .folder .object-picture img {
    width: 84px;
    height: 84px;
}
#core-liberation .block-search-results .block-content { margin-bottom: 15px }
#core-liberation .block-search-results .block-content .object-content h3 {
    font-size: 16px;
    font-weight: bold;
}
#core-liberation .block-search-results .block-c ontent h4 {
    font-family: Verdana,sans-serif;
    font-size: 12px;
}
#core-liberation .block-search-results .block-content h4 span { text-transform: uppercase }
#core-liberation .block-search-results .block-content h4 strong {
    text-transform: uppercase;
    font-weight: normal;
}
#core-liberation .block-search-results .block-content h4 a:hover span { text-decoration: underline }
#core-liberation .block-search-results .block-content .category .object-content p {
    margin-top: 0;
    font-family: Georgia,"Times New Roman",Times,serif;
    font-size: 16px;
}
#core-liberation .block-search-results .block-content .object-picture {
    position: absolute;
    width: 87px;
}
#core-liberation .block-search-results .block-content .object-picture img {
    display: block;
    width: 87px;
}
#core-liberation .block-search-results .block-content .article .object-picture,
#core-liberation .block-search-results .block-content .article .object-picture img { height: 116px }
#core-liberation .block-search-results .block-content .object-picture .np { position: relative }
#core-liberation .block-search-results .block-content .object-picture .np .p1,
#core-liberation .block-search-results .block-content .object-picture .np .p2 {
    position: absolute;
    width: 79px;
    height: 102px;
    border-style: solid;
    border-top-width: 7px;
    border-bottom-width: 7px;
    border-left-width: 4px;
    border-right-width: 4px;
}
#core-liberation .block-search-results .block-content .object-picture .np a.date {
    position: absolute;
    display: block;
    width: 80px;
    top: 10px;
    padding: 2px 2px 3px 4px;
}
#core-liberation .block-search-results .block-content .object-picture .np .p1 { z-index: 2000 }
#core-liberation .block-search-results .block-content .object-picture .np .p2 { z-index: 1000 }
#core-liberation .block-search-results .block-content .object-picture .np a.date { z-index: 500 }
#core-liberation .block-https-inscription {
    width: 418px;
    margin: 0 auto 42px;
}
#core-liberation .block-https-inscription .block-content h2 {
    margin: 5px 0 10px;
    text-align: center;
    font-size: 16px;
    font-weight: bold;
    font-family: Verdana,sans-serif;
}
#core-liberation .block-https-inscription .block-content p {
    margin-bottom: 15px;
    text-align: center;
    font-size: 14px;
}
#core-liberation .block-https-inscription .block-content .btn-monlibe {
    margin: 0 auto 7px;
    width: 90px;
    text-align: center;
}
#core-liberation .headrest { margin-bottom: 14px }
#core-liberation .headrest h5,
#core-liberation .headrest h4,
#core-liberation .headrest h3 { font-family: Verdana,sans-serif }
#core-liberation .headrest h5 {
    border-bottom: 1px solid;
    text-transform: uppercase;
    padding: 7px 0;
}
#core-liberation .headrest h4 {
    margin-bottom: 7px;
    font-weight: bold;
}
#core-liberation .headrest .links-inline {
    padding-left: 30px;
    font-size: 10px;
    font-weight: normal;
    text-transform: none;
}
#core-liberation .headrest .folder { background: url('http://s0.libe.com/libe/img/common/bg-headrest-triangle.png?589ad9ce9011') no-repeat right center }
#core-liberation .headrest .folder img.visual {
    display: block;
    float: left;
    margin-right: 14px;
}
#core-liberation .headrest .folder h5 {
    border-bottom: none;
    padding: 5px 5px 7px;
}
#core-liberation .headrest .folder h2 {
    margin-left: 14px;
    padding-top: 3px;
    font-weight: normal;
}
#core-liberation .headrest .folder p { margin-left: 14px }
#core-liberation .headrest .bg-sprites-icons span.icon {
    float: left;
    margin-right: 10px;
}
#core-liberation .block .block-top .headrest-basic-striked h5,
#core-liberation .headrest-basic-striked h5 {
    border: 0;
    padding: 0 0 4px 0;
    font-weight: normal;
    font-size: 14px;
    height: 12px;
}
#core-liberation .headrest-basic-striked h5 span {
    margin-left: 20px;
    padding: 0 7px 0 10px;
}
#core-liberation .headrest-community { margin-bottom: 14px }
#core-liberation .headrest-community h3 {
    font-family: Verdana,sans-serif;
    font-size: 14px;
    text-transform: uppercase;
}
#core-liberation .headrest-community a.lnk-com {
    display: inline-block;
    padding-left: 50px;
}
#core-liberation .headrest-community a.lnk-back {
    display: inline-block;
    margin-bottom: 4px;
}
#core-liberation .headrest-basic-zoneabo h4 {
    margin-bottom: 28px;
    border-bottom: 1px solid;
    padding-bottom: 7px;
    text-align: center;
    text-transform: uppercase;
    font-weight: normal;
    font-size: 16px;
}
#core-liberation .cartridge { margin-bottom: 28px }
#core-liberation .cartridge .share { padding: 0 5px }
#core-liberation .cartridge .share li {
    float: left;
    margin: 0 5px;
}
#core-liberation .cartridge .share li a.twitter { margin-top: 7px }
#core-liberation .cartridge .share li a.facebook { margin-top: 6px }
#core-liberation .cartridge .share li a.mail { margin-top: 8px }
#core-liberation .cartridge .share li a.star { margin-top: 4px }
#core-liberation .cartridge .btn-comment,
#core-liberation .cartridge .btn-back { text-align: center }
#core-liberation .cartridge .btn-comment span,
#core-liberation .cartridge .btn-back span {
    display: block;
    padding: 6px 7px 0;
    font-weight: bold;
}
#core-liberation .cartridge a.btn-comment:hover,
#core-liberation .cartridge a.btn-back:hover { text-decoration: none }
#core-liberation .cartridge a.btn-comment-disabled { background: transparent url('http://s0.libe.com/libe/img/common/bg-btn-comment.png?593ec6d1f747') }
#core-liberation .cartridge a.btn-comment-disabled:hover { cursor: default }
#core-liberation .cartridge .options-tab { position: relative }
#core-liberation .cartridge .options-tab-content {
    display: none;
    position: absolute;
    padding: 5px 9px 8px;
    border: 1px solid;
    width: 180px;
    text-align: right;
    right: 8px;
    font-size: 11px;
    z-index: 100;
}
#core-liberation .cartridge .options-tab-content a { display: block }
#core-liberation .cartridge a.options-tab-label {
    display: block;
    position: relative;
    width: 100px;
    margin: 3px 8px 0 0;
    padding: 3px 7px 5px;
    border-radius: 8px 8px 0 0;
    -moz-border-radius: 8px 8px 0 0;
    -webkit-border-radius: 8px 8px 0 0;
}
#core-liberation .cartridge a.options-tab-label:hover { text-decoration: none }
#core-liberation .cartridge a.options-tab-label .arrow {
    position: absolute;
    right: 6px;
    top: 8px;
}
#core-liberation .cartridge-basic-rounded {
    border: 1px dotted;
    height: 30px;
}
#core-liberation .cartridge-basic-rounded p { padding: 6px 10px 0 }
#core-liberation .cartridge-basic-rounded .segment { border-left: 1px dotted }
#core-liberation .cartridge-basic-rounded .btn-comment {
    border-radius: 0 5px 5px 0;
    -moz-border-radius: 0 5px 5px 0;
    -webkit-border-radius: 0 5px 5px 0;
}
#core-liberation .cartridge-basic-rounded .options-tab { border-left: 0 }
#core-liberation .cartridge-basic-bubble { height: 30px }
#core-liberation .cartridge-basic-bubble .segment,
#core-liberation .cartridge-basic-bubble .plain {
    height: 28px;
    border: 1px solid;
    margin-right: 20px;
}
#core-liberation .cartridge-basic-bubble p { padding: 6px 10px 0 }
#core-liberation .cartridge-basic-bubble .share span {
    display: block;
    float: left;
    width: 60px;
    line-height: 10px;
    font-size: 10px;
    padding: 3px 0 0 10px;
}
#core-liberation .cartridge-basic-bubble .share li.spacer {
    width: 1px;
    height: 28px;
}
#core-liberation .w23unit .cartridge-basic-bubble .segment { margin-right: 29px }
#core-liberation .w17unit .cartridge-basic-bubble .segment { margin-right: 47px }
#core-liberation .w23unit .cartridge-basic-bubble .text,
#core-liberation .w17unit .cartridge-basic-bubble .text { margin-right: 0 }
#core-liberation .cartridge-basic-bubble .text p {
    font-size: 10px;
    padding: 3px 10px;
    line-height: 10px;
    text-align: center;
}
#core-liberation .cartridge-basic-bubble .share { width: 115px }
#core-liberation .cartridge-basic-bubble .btn-back { width: 150px }
#core-liberation .cartridge-basic-bubble .text { width: 150px }
#core-liberation .block-item .cartridge-basic-bubble .btn-comment { width: 100px }
.btn-basic span,
.btn-basic a {
    display: block;
    padding: 2px 1px 4px;
    text-decoration: none;
    text-align: center;
    font-size: 11px;
    border: 1px solid;
}
form .btn-basic input[type=button],
form .btn-basic input[type=submit],
form .btn-basic input[type=reset] {
    border: 1px solid;
    padding: 0 10px 4px;
    height: 26px;
    cursor: pointer;
    cursor: hand;
    font-size: 11px;
    font-family: Verdana,sans-serif;
}
.btn-laune span,
.btn-laune a,
.btn-monlibe span,
.btn-monlibe a,
.btn-zoneabo span,
.btn-zoneabo a {
    display: block;
    padding: 5px 5px 7px;
    border-radius: 5px 5px 5px 5px;
    -moz-border-radius: 5px 5px 5px 5px;
    -webkit-border-radius: 5px 5px 5px 5px;
    text-decoration: none;
}
.btn-laune a:hover,
.btn-monlibe a:hover,
.btn-zoneabo a:hover { text-decoration: underline }
form .btn-laune input[type=button],
form .btn-laune input[type=submit],
form .btn-laune input[type=reset],
form .btn-monlibe input[type=button],
form .btn-monlibe input[type=submit],
form .btn-monlibe input[type=reset],
form .btn-zoneabo input[type=button],
form .btn-zoneabo input[type=submit],
form .btn-zoneabo input[type=reset] {
    border-radius: 5px 5px 5px 5px;
    -moz-border-radius: 5px 5px 5px 5px;
    -webkit-border-radius: 5px 5px 5px 5px;
    padding: 0 10px 3px;
    height: 25px;
    cursor: pointer;
    cursor: hand;
    font-size: 12px;
    font-family: Verdana,sans-serif;
    border: 0;
}
form .btn-monlibe input[type=reset] { opacity: .9 }
.btn-rounded-degraded span,
.btn-rounded-degraded a {
    display: block;
    border-radius: 5px 5px 5px 5px;
    -moz-border-radius: 5px 5px 5px 5px;
    -webkit-border-radius: 5px 5px 5px 5px;
    padding: 7px 14px 11px;
    text-decoration: none;
    text-align: center;
    font-size: 13px;
    font-weight: bold;
}
.btn-rounded-degraded span:hover,
.btn-rounded-degraded a:hover { text-decoration: none!important }
form .btn-rounded-degraded input[type=button],
form .btn-rounded-degraded input[type=submit] {
    border-radius: 5px 5px 5px 5px;
    -moz-border-radius: 5px 5px 5px 5px;
    -webkit-border-radius: 5px 5px 5px 5px;
    border: 0;
    padding: 0 10px 6px;
    height: 35px;
    cursor: pointer;
    cursor: hand;
    font-size: 13px;
    font-family: Verdana,sans-serif;
    font-weight: bold;
}
form .btn-rounded-degraded input[type=button]:hover,
form .btn-rounded-degraded input[type=submit]:hover,
form .btn-rounded-degraded input[type=button]:focus,
form .btn-rounded-degraded input[type=submit]:focus { text-decoration: none }
.btn-read-digitalpaper {
    display: block;
    border: 1px solid;
    border-radius: 3px 3px 3px 3px;
    -moz-border-radius: 3px 3px 3px 3px;
    -webkit-border-radius: 3px 3px 3px 3px;
    padding: 5px 7px 7px;
}
.btn-read-digitalpaper span,
.btn-read-digitalpaper a {
    display: block;
    min-height: 32px;
    background: url('http://s0.libe.com/libe/img/common/reader_picto.png?8fdcc4850538') no-repeat right top;
    padding-right: 50px;
    font-size: 12px;
}
#core-liberation .pagination {
    float: none;
    margin-bottom: 14px;
    margin-top: 21px;
    border-top: 1px dotted;
    border-bottom: 1px dotted;
    padding-top: 3px;
    text-align: center;
}
#core-liberation .pagination .first {
    float: left;
    background-image: url('http://s0.libe.com/libe/img/common/bg-search-pagination-first.png?71b3279ad5d6');
    background-repeat: no-repeat;
    background-position: 0 5px;
    margin-left: 10px;
    padding-left: 20px;
}
#core-liberation .pagination .prev {
    float: left;
    background-image: url('http://s0.libe.com/libe/img/common/bg-search-pagination-prev.png?0ae4b5772718');
    background-repeat: no-repeat;
    background-position: 0 6px;
    margin-left: 10px;
    padding-left: 15px;
}
#core-liberation .pagination .next {
    float: right;
    background-image: url('http://s0.libe.com/libe/img/common/bg-search-pagination-next.png?363861606f55');
    background-repeat: no-repeat;
    background-position: right 6px;
    margin-right: 10px;
    padding-right: 15px;
}
#core-liberation .pagination .page {
    display: inline;
    float: none;
    height: auto;
    padding: 0 5px;
}
#core-liberation .block .pager ul { float: left }
#core-liberation .block .pager ul li {
    float: left;
    display: block;
    margin-right: 5px;
}
#core-liberation .block .pager ul.circle li a {
    display: block;
    width: 8px;
    height: 7px;
    background-image: url('http://s0.libe.com/libe/img/common/btn-circle-off.gif?36d3bb5f1d80');
    background-repeat: no-repeat;
}
#core-liberation .block .pager ul.circle li a.on { background-image: url('http://s0.libe.com/libe/img/common/btn-circle-on.gif?c66d45940adc') }
#core-liberation .block .pager ul.circle li a.prev { background-image: url('http://s0.libe.com/libe/img/common/bg-search-pagination-prev.png?0ae4b5772718') }
#core-liberation .block .pager ul.circle li a.next { background-image: url('http://s0.libe.com/libe/img/common/bg-search-pagination-next.png?363861606f55') }
#core-liberation .bg-sprites-icons a.twitter,
#core-liberation .bg-sprites-icons a.facebook,
#core-liberation .bg-sprites-icons a.mail,
#core-liberation .bg-sprites-icons a.star {
    display: block;
    background-image: url('http://s0.libe.com/libe/img/common/_sprites_icons/icons.png?9914d0d70a49');
    background-repeat: no-repeat;
}
#core-liberation .bg-sprites-icons a.twitter {
    background-position: -64px 0;
    width: 12px;
    height: 15px;
}
#core-liberation .bg-sprites-icons a.twitter:hover { background-position: -64px -17px }
#core-liberation .bg-sprites-icons a.facebook {
    background-position: -78px 0;
    width: 9px;
    height: 16px;
}
#core-liberation .bg-sprites-icons a.facebook:hover { background-position: -78px -18px }
#core-liberation .bg-sprites-icons a.mail {
    background-position: -89px 0;
    width: 21px;
    height: 14px;
}
#core-liberation .bg-sprites-icons a.mail:hover { background-position: -89px -16px }
#core-liberation .bg-sprites-icons a.star {
    background-position: -38px -56px;
    width: 20px;
    height: 18px;
}
#core-liberation .bg-sprites-icons .on a.star,
#core-liberation .bg-sprites-icons a.star:hover { background-position: -23px -36px }
#core-liberation .bg-sprites-icons .arrow-grey-l,
#core-liberation .bg-sprites-icons .arrow-grey-b {
    display: block;
    background-image: url('http://s0.libe.com/libe/img/common/_sprites_icons/icons.png?9914d0d70a49');
    background-repeat: no-repeat;
}
#core-liberation .bg-sprites-icons .arrow-grey-l {
    background-position: 0 -66px;
    width: 6px;
    height: 8px;
}
#core-liberation .bg-sprites-icons .arrow-grey-b {
    background-position: 0 -75px;
    width: 8px;
    height: 7px;
}
#core-liberation .bg-sprites-icons .community-bubble {
    display: block;
    background-image: url('http://s0.libe.com/libe/img/common/_sprites_icons/icons.png?9914d0d70a49');
    background-repeat: no-repeat;
}
#core-liberation .bg-sprites-icons .community-bubble {
    background-position: 0 -36px;
    width: 21px;
    height: 18px;
}
.site-liberation .toolbox {
    border-top: 1px solid;
    border-bottom: 1px solid;
    display: block;
    height: 30px;
    letter-spacing: -1px;
}
.site-liberation .toolbox li {
    float: left;
    display: block;
    margin: 0 4px;
    height: 30px;
}
#core-liberation .toolbox>li:first-child { margin-left: 0 }
#core-liberation .toolbox li.right { margin-right: 0 }
#core-liberation .toolbox li.spacer span {
    display: block;
    width: 1px;
    height: 20px;
    margin-top: 5px;
}
#core-liberation .toolbox .txt-min,
#core-liberation .toolbox .txt-plus {
    display: block;
    font-size: 15px;
    padding-top: 4px;
}
#core-liberation .toolbox .txt-reset {
    display: block;
    font-family: "Times New Roman",Times,Georgia,serif;
    font-size: 19px;
    padding: 4px 0 0 3px;
}
.site-liberation .toolbox .txt-min:hover,
.site-liberation .toolbox .txt-plus:hover,
.site-liberation .toolbox .txt-reset:hover,
.site-liberation .toolbox .comment:hover,
.site-liberation .toolbox .facebook:hover,
.site-liberation .toolbox .twitter { text-decoration: none }
.site-liberation .toolbox li a span { display: block }
.site-liberation .toolbox li a.print span {
    margin-top: 7px;
    width: 16px;
    height: 16px;
}
.site-liberation .toolbox li a.favorite span {
    margin-top: 5px;
    width: 20px;
    height: 18px;
}
.site-liberation .toolbox li a.comment span {
    float: left;
    margin-top: 9px;
    width: 14px;
    height: 12px;
}
.site-liberation .toolbox li a.comment strong {
    float: left;
    margin: 6px 0 6px 4px;
}
.site-liberation .toolbox li.btn-comment a {
    display: block;
    font-size: 12px;
    line-height: 1.25em;
    padding: 7px;
    height: 16px;
    font-weight: bold;
}
.site-liberation .toolbox li a.mail span {
    width: 21px;
    height: 14px;
    margin-top: 8px;
}
.site-liberation .toolbox li a.facebook,
.site-liberation .toolbox li a.twitter {
    display: block;
    margin-top: 4px;
    padding: 3px;
    border: 1px solid;
    font-size: 10px;
    border-radius: 3px;
    -moz-border-radius: 3px;
    -webkit-border-radius: 3px;
}
.site-liberation .toolbox li a.facebook span {
    margin: 1px 3px 0 0;
    float: left;
    width: 12px;
    height: 12px;
}
.site-liberation .toolbox li a.twitter span {
    margin: 1px 3px 0 0;
    float: left;
    width: 15px;
    height: 12px;
}
.site-liberation .toolbox li.abo-1-euro {
    display: block;
    font-size: 10px;
    line-height: 1.25em;
    padding: 0 7px;
    margin-left: 0;
}
.site-liberation .toolbox li.abo-1-euro span.ft-c { margin-top: 1px }
.site-liberation .toolbox li.fold-options {
    position: relative;
    display: block;
    font-size: 11px;
    padding: 0 7px;
    margin: 0;
    font-size: 12px;
}
.site-liberation .toolbox li.fold-options+li.fold-options { border-left: 1px solid }
.site-liberation .toolbox li.fold-options>a {
    display: inline-block;
    height: 24px;
    padding: 6px 0 0;
    font-weight: bold;
}
.site-liberation .toolbox li.fold-options ul {
    display: none;
    position: absolute;
    z-index: 1000;
    top: 30px;
    left: -1px;
    width: auto;
    min-width: 100%;
    border: 1px solid;
    border-top: 0;
}
.site-liberation .toolbox li.fold-options ul li {
    display: block;
    float: none;
    height: auto;
    margin: 7px;
    white-space: nowrap;
}
#core-liberation .sb-podcasts ul {
    display: block;
    height: 17px;
}
#core-liberation .sb-podcasts ul li {
    float: left;
    height: 17px;
    margin: 0 10px 0 0;
}
#core-liberation .sb-podcasts ul li a {
    display: block;
    background-image: url('http://s0.libe.com/libe/img/common/_sprites_podcasts/podcasts.png?6e3b93dc1f3c');
    background-repeat: no-repeat;
    height: 17px;
}
#core-liberation .sb-podcasts ul li a.google {
    background-position: 0 0;
    width: 104px;
}
#core-liberation .sb-podcasts ul li a.netvibes {
    background-position: -109px 0;
    width: 91px;
}
#core-liberation .sb-podcasts ul li a.miro {
    background-position: -205px 0;
    width: 57px;
}
#core-liberation .sb-podcasts ul li a.itunes {
    background-position: -267px 0;
    width: 50px;
}
#core-liberation .sb-podcasts ul li a.xml {
    background-position: -322px 0;
    width: 41px;
}
#bar-liberation {
    display: block;
    position: fixed;
    top: 0;
    left: 0;
    z-index: 10000;
    width: 100%;
    height: 40px;
    border-bottom: 1px solid;
    font-family: Arial,Verdana,sans-serif;
    font-size: 12px;
    line-height: 14px;
}
body.init-bar-is-closed #bar-liberation { height: 15px }
#bar-liberation a,
#bar-liberation a p {
    text-decoration: none;
    outline: none;
}
#bar-liberation a:hover { text-decoration: none }
#bar-liberation .content {
    position: relative;
    margin: auto;
    height: 40px;
    width: 1068px;
}
#bar-liberation .content .close,
#bar-liberation .content .open,
#bar-liberation .content .login,
#bar-liberation .content .personal-options,
#bar-liberation .content .mail-box,
#bar-liberation .content .activities-stream,
#bar-liberation .content .other {
    display: none;
    border-left: 1px solid;
    border-right: 1px solid;
    border-bottom: 1px solid;
    position: absolute;
    top: 0;
    height: 40px;
}
#bar-liberation .content .activities-stream .list .more { display: none }
#bar-liberation .content .activities-stream .list .text,
#bar-liberation .content .activities-stream .list p { display: inline }
#bar-liberation .content a.displayer .arrow {
    background: url('http://s0.libe.com/libe/img/common/_sprites_header/triangle_ferme.png?1ecaa0c231c9') no-repeat 0 0;
    display: block;
    position: absolute;
    right: 10px;
    top: 16px;
    width: 10px;
    height: 10px;
}
#bar-liberation .content a.displayer:hover .arrow { background: url('http://s0.libe.com/libe/img/common/_sprites_header/triangle_ferme_grey.png?a9a52344ba82') no-repeat 0 0 }
#bar-liberation .content a.displayer .arrow-displayed { background: url('http://s0.libe.com/libe/img/common/_sprites_header/triangle_ouvert.png?c782eb482038') no-repeat 1px 1px }
#bar-liberation .content a.displayer:hover .arrow-displayed { background: url('http://s0.libe.com/libe/img/common/_sprites_header/triangle_ouvert.png?c782eb482038') no-repeat 1px 1px }
#bar-liberation .content ul.list li {
    margin: 0 10px;
    min-height: 32px;
    padding: 6px 0 2px 0;
    border-bottom: 1px solid;
    line-height: 16px;
}
#core-liberation .block-activities .block-content ul li a,
#bar-liberation .content ul.list li a,
#core-liberation .block-activities .block-content ul li a:hover,
#bar-liberation .content ul.list li a:hover { text-decoration: underline }
#bar-liberation .content ul.list li:last-of-type { border-bottom: none }
#bar-liberation .content ul.list li:first-of-type { padding-right: 30px }
#bar-liberation .content .close {
    width: 28px;
    left: 0;
    z-index: 10010;
}
#bar-liberation .content .close a {
    display: block;
    text-align: center;
    padding-top: 12px;
    height: 28px;
}
#bar-liberation .content .open {
    display: none;
    height: 15px;
    left: 0;
    z-index: 10010;
    border: none;
}
#bar-liberation .content .open a {
    display: block;
    height: 100%;
    padding-left: 40px;
    font-size: 10px;
}
#bar-liberation .content .open a .arrow {
    position: absolute;
    display: block;
    width: 28px;
    height: 100%;
    left: 0;
    top: 0;
    border-left: 1px solid;
    border-right: 1px solid;
    background: url('http://s0.libe.com/libe/img/common/_sprites_header/triangle_ouvert.png?c782eb482038') no-repeat center center;
}
#bar-liberation .content .login {
    left: 29px;
    width: 1037px;
    z-index: 10020;
}
#bar-liberation .content .login h3 {
    font-family: Verdana,sans-serif;
    font-weight: normal;
    font-size: 12px;
    padding: 12px 10px 0;
}
#bar-liberation .content .login a.subscribe {
    position: absolute;
    display: block;
    top: 10px;
    right: 230px;
    padding: 3px 10px;
    border-radius: 5px 5px 5px 5px;
    -moz-border-radius: 5px 5px 5px 5px;
    -webkit-border-radius: 5px 5px 5px 5px;
}
#bar-liberation .content .login a.subscribe:hover { text-decoration: none }
#bar-liberation .content .login span {
    position: absolute;
    display: block;
    top: 13px;
    right: 205px;
}
#bar-liberation .content .login a.connect {
    position: absolute;
    display: block;
    top: 13px;
    right: 120px;
}
#bar-liberation .content .login a.connect { font-weight: bold }
#bar-liberation #login-box-content {
    display: none;
    position: absolute;
    border-left: 1px solid;
    border-right: 1px solid;
    border-bottom: 1px solid;
    top: 40px;
    right: 0;
    z-index: 10025;
    width: 184px;
    padding: 10px;
}
#bar-liberation #login-box-content form ul li {
    margin-bottom: 10px;
    clear: both;
}
#bar-liberation #login-box-content form label {
    display: block;
    float: left;
    width: 150px;
    margin-bottom: 3px;
}
#bar-liberation #login-box-content form input[type=text],
#bar-liberation #login-box-content form input[type=password] {
    display: block;
    clear: both;
    width: 175px;
}
#bar-liberation #login-box-content form input[type=checkbox] {
    display: block;
    float: right;
}
#bar-liberation #login-box-content form .btn-basic { margin: 10px 0 }
#bar-liberation #login-box-content p.forgot-password {
    font-size: 11px;
    text-align: right;
}
#bar-liberation #login-box-content p.forgot-password a:hover { text-decoration: underline }
#bar-liberation .content .personal-options {
    width: 189px;
    left: 29px;
    z-index: 10020;
}
#bar-liberation .content .personal-options a {
    display: block;
    width: 100%;
    height: 100%;
}
#bar-liberation .content .personal-options img.visual {
    display: block;
    position: absolute;
    top: 8px;
    left: 8px;
    width: 23px;
    height: 23px;
}
#bar-liberation .content .personal-options .text {
    display: block;
    position: absolute;
    top: 13px;
    left: 37px;
    right: 23px;
}
#bar-liberation #personal-options-content {
    display: none;
    position: absolute;
    border-left: 1px solid #dadada;
    border-right: 1px solid #dadada;
    border-bottom: 1px solid #dadada;
    top: 40px;
    left: 29px;
    z-index: 10025;
}
#bar-liberation #personal-options-content ul {
    display: block;
    float: left;
    height: auto;
    padding: 20px 0 16px;
}
#bar-liberation #personal-options-content ul.account {
    width: 160px;
    padding-left: 10px;
}
#bar-liberation #personal-options-content ul.subscription { width: 149px }
#bar-liberation #personal-options-content ul.subscription li.subscribe {
    position: absolute;
    bottom: 17px;
}
#bar-liberation #personal-options-content ul li a:hover { text-decoration: underline }
#bar-liberation #personal-options-content ul li { padding: 0 10px 4px }
#bar-liberation #personal-options-content ul li.spacer { height: 5px }
#bar-liberation #personal-options-content ul li.indent { padding-left: 20px }
#bar-liberation .content .mail-box {
    width: 75px;
    height: 40px;
    left: 219px;
    z-index: 10040;
    border-bottom: 1px solid;
}
#bar-liberation .content .mail-box a {
    display: block;
    height: 100%;
    width: 100%;
}
#bar-liberation .content .mail-box strong {
    display: block;
    position: absolute;
    right: 14px;
    top: 13px;
}
#bar-liberation .content .mail-box span.letter {
    display: block;
    position: absolute;
    top: 13px;
    left: 14px;
    width: 21px;
    height: 14px;
    background-image: url('http://s0.libe.com/libe/img/common/_sprites_icons/icons.png?9914d0d70a49');
    background-repeat: no-repeat;
    background-position: -89px 0;
}
#bar-liberation .content .mail-box a:hover span.letter { background-position: -112px 0 }
#bar-liberation .content .activities-stream {
    width: 503px;
    left: 295px;
    z-index: 10030;
    height: 40px;
    overflow: hidden;
    border-bottom: 1px solid;
}
#bar-liberation .content .activities-stream a.displayer {
    display: block;
    position: absolute;
    width: 40px;
    height: 100%;
    right: 0;
}
#bar-liberation .content .activities-stream a:hover { text-decoration: underline }
#bar-liberation .content .other {
    width: 267px;
    left: 799px;
    z-index: 10050;
}
#bar-liberation .content .other a {
    display: block;
    height: 100%;
    width: 100%;
}
#bar-liberation .content .other .ad-1 { padding: 6px 10px }
#page-404 { margin-bottom: 20px }
#page-404 .error {
    float: left;
    display: block;
    border-right: 1px solid;
    margin: 0 28px 0 0;
    padding: 0 14px 0 0;
    width: 97px;
    height: 160px;
    text-align: right;
}
#page-404 .error h2 {
    font-weight: normal;
    font-size: 22px;
    font-style: italic;
    line-height: 30px;
}
#page-404 .error h2 span {
    display: block;
    font-size: 47px;
    font-weight: bold;
}
#page-404 .text { padding-top: 5px }
#page-404 form {
    display: block;
    margin: 21px 0 0 140px;
    width: 298px;
    height: 22px;
    border: 1px solid;
}
#page-404 form input[type=text] {
    border: 0;
    height: 22px;
    width: 250px;
    padding: 0 5px;
}
#page-404 form input[type=submit] {
    background: url('http://s0.libe.com/libe/img/common/_sprites_header/header.png?df8de01457fa') no-repeat 0 -32px;
    display: block;
    float: right;
    width: 29px;
    height: 22px;
    border: 0;
}
#page-mailfriend {
    font-family: Verdana,sans-serif;
    font-size: 11px;
}
#page-mailfriend .content {
    width: 280px;
    padding: 10px;
    margin: auto;
}
#page-mailfriend .content h2 { margin-bottom: 10px }
#page-mailfriend .content a { font-weight: bold }
#page-mailfriend .content p {
    clear: both;
    margin-bottom: 10px;
}
#page-mailfriend .content input[type=text] { width: 275px }
#page-mailfriend .content input[type=checkbox] {
    float: right;
    margin-top: 5px;
}
#page-mailfriend .content label {
    float: left;
    display: block;
    width: 80%;
    font-weight: bold;
}
#page-paywall {
    width: 520px;
    font-family: Verdana,sans-serif;
    font-size: 12px;
}
#page-paywall .content {
    position: relative;
    padding: 20px 0;
}
#page-paywall .content a { text-decoration: none }
#page-paywall .content a.close {
    display: block;
    float: right;
}
#page-paywall .content a.close span {
    background: url('http://s0.libe.com/libe/img/common/_sprites_icons/icons.png?9914d0d70a49') no-repeat -20px -98px;
    display: block;
    margin: auto;
    width: 15px;
    height: 15px;
}
#page-paywall .content a.close strong {
    text-transform: uppercase;
    font-size: 8px;
}
#page-paywall .content .video {
    margin-bottom: 20px;
    width: 437px;
}
#page-paywall .content .video h5 {
    margin-bottom: 15px;
    padding: 3px 0 5px;
    border-top: 1px dotted;
    border-bottom: 1px dotted;
    float: right;
    font-family: Georgia,"Times New Roman",Times,serif;
    font-size: 16px;
    font-style: italic;
    font-weight: normal;
}
#page-paywall .content .video h4 {
    clear: both;
    margin-bottom: 20px;
}
#page-paywall .content .video h4 span {
    float: right;
    padding: 0 0 0 10px;
    text-transform: uppercase;
    line-height: 13px;
    font-size: 16px;
    font-weight: normal;
}
#page-paywall .content .video .player {
    width: 354px;
    height: 200px;
    float: right;
}
#page-paywall .content .arguments {
    clear: both;
    margin-bottom: 20px;
}
#page-paywall .content .arguments .arg {
    float: left;
    width: 240px;
    padding: 0 10px;
}
body.access-ess #page-paywall .content .arguments .arg {
    float: none;
    margin: auto;
}
#page-paywall .content .arguments .arg .visual {
    display: block;
    float: left;
    margin-right: 10px;
    width: 110px;
}
#page-paywall .content .arguments .arg .visual1 { height: 71px }
#page-paywall .content .arguments .arg .visual2 { height: 76px }
#page-paywall .content .arguments .arg h5 {
    margin-bottom: 10px;
    text-transform: uppercase;
    line-height: 13px;
    font-size: 14px;
    font-weight: normal;
}
#page-paywall .content .arguments .arg h4 {
    margin-bottom: 10px;
    font-family: Georgia,"Times New Roman",Times,serif;
    font-size: 13px;
    font-style: italic;
    font-weight: normal;
}
#page-paywall .content .arguments .arg .price {
    float: right;
    width: 120px;
    font-family: Georgia,"Times New Roman",Times,serif;
    font-size: 13px;
    margin-bottom: 15px;
}
#page-paywall .content .arguments .arg .price strong {
    display: block;
    float: left;
    margin-right: 10px;
    line-height: 25px;
    font-family: Verdana,sans-serif;
    font-size: 30px;
    letter-spacing: -3px;
}
#page-paywall .content .arguments .arg .price strong .currency,
#page-paywall .content .arguments .arg .price strong .decimals { font-size: 20px }
#page-paywall .content .arguments .arg .price strong .currency { padding-left: 3px }
#page-paywall .content .arguments .arg .price .total { font-size: 10px }
#page-paywall .content .arguments .arg .price .btn-rounded-degraded { margin-top: 10px }
#page-paywall .content .banner-degraded {
    clear: both;
    border-top: 1px solid;
    border-bottom: 1px solid;
    text-align: center;
    padding: 10px 0 12px;
}
#page-paywall .content .banner-degraded a { font-weight: bold }
#page-paywall .content .form-login { padding: 20px 20px 0 }
#page-paywall .content .form-login p { margin-bottom: 10px }
#page-paywall .content .form-login form p {
    float: left;
    width: 200px;
    margin-bottom: 0;
}
#page-paywall .content .form-login form p label {
    display: block;
    height: 20px;
}
#page-paywall .content .form-login form p input[type=text],
#page-paywall .content .form-login form p input[type=password] {
    border: 1px solid;
    padding: 0 10px 4px;
    width: 160px;
    height: 19px;
}
#page-paywall .content .form-login form p input[type=text]:focus,
#page-paywall .content .form-login form p input[type=password]:focus { border: 1px solid }
#page-paywall .content .form-login form .btn-basic {
    margin-top: 20px;
    float: right;
}
.site-liberation {
    font-family: Verdana,Arial,Helvetica,sans-serif;
    font-size: 12px;
}
.site-liberation h1,
.site-liberation h2 {
    font-family: Georgia,"Times New Roman",Times,serif;
    font-size: 26px;
}
.site-liberation h3 { font-family: Georgia,"Times New Roman",Times,serif }
.site-liberation h4 {
    font-family: Georgia,"Times New Roman",Times,serif;
    font-size: 14px;
    font-weight: normal;
}
.site-liberation h5 { font-size: 12px }
.site-liberation h5 .theme { text-transform: uppercase }
.site-liberation h5 a.theme:hover,
.site-liberation a:hover h5 .theme { text-decoration: none }
.site-liberation h5 .date {
    font-weight: normal;
    font-size: 10px;
}
.site-liberation p {
    font-family: Verdana,Arial,Helvetica,sans-serif;
    font-size: 12px;
}
.site-liberation p.subtitle { line-height: 16px }
.site-liberation .text p { margin-bottom: 7px }
.site-liberation .text-item img.i_orig { margin-bottom: 14px }
.site-liberation .text-item img.i_cg {
    float: left;
    margin-top: 4px;
    margin-right: 14px;
    width: 140px;
    height: 140px;
}
.site-liberation .text-item img.i_cd {
    margin-top: 4px;
    margin-left: 14px;
    float: right;
    width: 140px;
    height: 140px;
}
.site-liberation .text-item img.i_pdtg {
    float: left;
    width: 140px;
    margin-top: 4px;
    margin-right: 14px;
}
.site-liberation .text-item img.i_pdtd {
    width: 140px;
    float: right;
    margin-top: 4px;
    margin-left: 14px;
}
.site-liberation .text-item p.titre,
.site-liberation .text-item p.inter {
    margin-bottom: 14px;
    font-family: Georgia,"Times New Roman",Times,serif;
    font-size: 16px;
    font-weight: bold;
}
.site-liberation .text-item p {
    margin-bottom: 14px;
    line-height: 1.39em;
    font-size: 13px;
}
.site-liberation .text-item h3 {
    font-weight: bold;
    font-size: 16px;
}
.site-liberation .text-item h3 .complement {
    font-weight: normal;
    font-family: Verdana,Arial,Helvetica,sans-serif;
    font-size: 13px;
    color: #999;
}
.site-liberation .text-item h5,
.site-liberation .text-item .question {
    font-family: Georgia,"Times New Roman",Times,serif;
    font-size: 14px;
    font-weight: bold;
    margin: 21px 0 14px;
}
.site-liberation .text-item p span.nickname,
.site-liberation .text-item h5 span.nickname {
    font-family: Georgia,"Times New Roman",Times,serif;
    font-size: 14px;
    font-weight: bold;
    color: #999;
}
.site-liberation .text-item p span.inter-simple {
    padding-right: 7px;
    font-weight: bold;
    text-transform: uppercase;
}
.site-liberation .text-item p.note {
    margin: 21px 0;
    color: #999;
}
.site-liberation .text-item p.essential {
    padding-left: 28px;
    color: #818181;
}
.site-liberation .text-item p.essential strong {
    text-transform: uppercase;
    color: #e20000;
}
.site-liberation .text-item p.essential a { color: #818181 }
.site-liberation .text-item p.essential a:hover { color: #E20000 }
.site-liberation .text-item p.others {
    margin: 21px 0;
    border: 1px dotted #b3b3b3;
    border-left: 0;
    border-right: 0;
    padding: 7px 0 9px;
}
.site-liberation .text-item p.others span {
    text-transform: uppercase;
    padding-right: 7px;
}
.site-liberation .slug {
    background: url('http://s0.libe.com/libe/img/common/bg-puce-losange.png?099dfb8021ab') no-repeat right center;
    padding-right: 18px;
    margin-right: 3px;
    text-transform: uppercase;
    font-size: 10px;
}
.site-liberation .author { font-size: 10px }
.site-liberation .author strong { text-transform: uppercase }
.site-liberation a,
.site-liberation a p {
    text-decoration: none;
    outline: none;
}
.site-liberation a:hover,
.site-liberation a:hover p,
.site-liberation a:hover h6,
.site-liberation a:hover h5,
.site-liberation a:hover h4,
.site-liberation a:hover h3,
.site-liberation a:hover h2 { text-decoration: underline }
.site-liberation .lnk-comments {
    background: url('http://s0.libe.com/libe/img/common/ico-lnk-comment.png?48525c2557e6') no-repeat left 2px;
    padding-left: 20px;
    font-size: 10px;
    line-height: 15px;
}
.site-liberation .block-call-items .block-top { margin-bottom: 10px }
.site-liberation .block-call-items .block-top h5 {
    padding: 3px 10px;
    background-color: #e20000;
    color: #fff;
}
.site-liberation .col-contextual .block-call-items .block-top h5 {
    background: none;
    padding: 0;
}
.site-liberation .block-call-items .mini-tpl h6 {
    margin: 0;
    font-family: Georgia,"Times New Roman",Times,serif;
    font-weight: normal;
    font-size: 12px;
}
.site-liberation .block-call-items .mini-tpl {
    border-bottom: 1px dotted;
    margin-bottom: 14px;
    clear: both;
}
.site-liberation .block-call-items .mini-tpl:last-of-type {
    border-bottom: 0;
    margin-bottom: 0:;
}
.site-liberation .block-call-items .mini-tpl .right { float: right }
.site-liberation .block-call-items .mini-tpl .lnk-libeplus,
.site-liberation .block-call-items .mini-tpl .lnk-libeplus-big {
    background: none;
    padding: 0;
}
.site-liberation .block-call-items .mini-tpl h2.lnk-libeplus:after,
.site-liberation .block-call-items .mini-tpl h3.lnk-libeplus:after {
    content: '';
    display: inline-block;
    width: 56px;
    height: 14px;
    margin-left: 10px;
    background: url('http://s0.libe.com/libe/img/common/ico-lnk-libeplus-big2.png?d4d49ea9ef21') no-repeat 0 0;
}
.site-liberation .block-call-items .mini-tpl h5.lnk-libeplus:after,
.site-liberation .block-call-items .mini-tpl .list-linked-items a.lnk-libeplus:after {
    content: '';
    display: inline-block;
    width: 56px;
    height: 10px;
    margin-left: 5px;
    background: url('http://s0.libe.com/libe/img/common/ico-lnk-libeplus2.png?39fe048f4782') no-repeat 0 0;
}
* html .site-liberation .block-call-items .mini-tpl h2.lnk-libeplus {
    background-image: url('http://s0.libe.com/libe/img/common/ico-lnk-libeplus-big2.png?d4d49ea9ef21');
    background-repeat: no-repeat;
    background-position: right 4px;
    padding-right: 60px;
}
* html .site-liberation .block-call-items .mini-tpl h3.lnk-libeplus {
    background-image: url('http://s0.libe.com/libe/img/common/ico-lnk-libeplus-big2.png?d4d49ea9ef21');
    background-repeat: no-repeat;
    background-position: right 4px;
    padding-right: 60px;
}
* html .site-liberation .block-call-items .mini-tpl .list-linked-items a.lnk-libeplus {
    background-image: url('http://s0.libe.com/libe/img/common/ico-lnk-libeplus2.png?39fe048f4782');
    background-repeat: no-repeat;
    background-position: right 4px;
    padding-right: 60px;
}
* html .site-liberation .block-call-items .mini-tpl h5.lnk-libeplus {
    background-image: url('http://s0.libe.com/libe/img/common/ico-lnk-libeplus2.png?39fe048f4782');
    background-repeat: no-repeat;
    background-position: right 4px;
    padding-right: 60px;
}
*:first-child+html .site-liberation .block-call-items .mini-tpl h2.lnk-libeplus {
    background-image: url('http://s0.libe.com/libe/img/common/ico-lnk-libeplus-big2.png?d4d49ea9ef21');
    background-repeat: no-repeat;
    background-position: right 4px;
    padding-right: 60px;
}
*:first-child+html .site-liberation .block-call-items .mini-tpl h3.lnk-libeplus {
    background-image: url('http://s0.libe.com/libe/img/common/ico-lnk-libeplus-big2.png?d4d49ea9ef21');
    background-repeat: no-repeat;
    background-position: right 4px;
    padding-right: 60px;
}
*:first-child+html .site-liberation .block-call-items .mini-tpl .list-linked-items a.lnk-libeplus {
    background-image: url('http://s0.libe.com/libe/img/common/ico-lnk-libeplus2.png?39fe048f4782');
    background-repeat: no-repeat;
    background-position: right 4px;
    padding-right: 60px;
}
*:first-child+html .site-liberation .block-call-items .mini-tpl h5.lnk-libeplus {
    background-image: url('http://s0.libe.com/libe/img/common/ico-lnk-libeplus2.png?39fe048f4782');
    background-repeat: no-repeat;
    background-position: right 4px;
    padding-right: 60px;
}
.site-liberation .block-call-items .mini-tpl h1,
.site-liberation .block-call-items .mini-tpl h2 { margin-bottom: 14px }
.site-liberation .block-call-items .mini-tpl h3 {
    margin-bottom: 14px;
    font-weight: normal;
    font-size: 21px;
}
.site-liberation .block-call-items .mini-tpl h4 { margin-bottom: 7px }
.site-liberation .block-call-items .mini-tpl h5 {
    margin-bottom: 7px;
    text-transform: uppercase;
}
.site-liberation .block-call-items .mini-tpl h5 .date { text-transform: none }
.site-liberation .block-call-items .mini-tpl .light {
    font-weight: normal;
    font-size: 10px;
}
.site-liberation .block-call-items .mini-tpl .theme { text-transform: uppercase }
.site-liberation .block-call-items .mini-tpl .visual {
    display: block;
    float: left;
    margin: 4px 14px 0 0;
}
.site-liberation .block-call-items .mini-tpl .default {
    width: 168px;
    height: 112px;
}
.site-liberation .block-call-items .mini-tpl .big {
    width: 476px;
    height: 269px;
}
.site-liberation .block-call-items .mini-tpl .pano {
    width: 476px;
    height: 103px;
}
.site-liberation .block-call-items .mini-tpl .signature {
    width: 90px;
    height: 90px;
}
.site-liberation .block-call-items .mini-tpl .item,
.site-liberation .block-call-items .mini-tpl .others { margin-bottom: 14px }
.site-liberation .block-call-items .mini-tpl .others .list-linked-items { clear: right }
.site-liberation .block-call-items .mini-tpl .lnk-comments {
    float: right;
    margin: 14px 0 0;
}
.site-liberation .block-call-items .mini-tpl .subtitle .slug { font-weight: bold }
.site-liberation .block-call-items .mini-tpl .author {
    display: block;
    margin-bottom: 5px;
    padding-top: 1px;
}
.site-liberation .block-call-items .list-linked-items span {
    text-transform: uppercase;
    font-size: 11px;
    padding-right: 7px;
}
.site-liberation .block-call-items .mini-tpl .label {
    background: url('http://s0.libe.com/libe/img/common/bg-separateur.gif?e78a16835c55') no-repeat right center;
    border: 2px solid;
    min-height: 45px;
}
.site-liberation .block-call-items .mini-tpl .label h3 {
    font-size: 21px;
    font-weight: normal;
    margin-bottom: 0;
    margin-top: 8px;
    margin-left: 10px;
}
.site-liberation .block-call-items .mini-tpl .label .visual {
    width: 45px;
    margin: 0 10px 0 0;
}
.site-liberation .block-call-items .mini-tpl .whosaid {
    position: relative;
    margin-bottom: 7px;
    padding: 14px;
}
.site-liberation .block-call-items .mini-tpl .whosaid h5 .theme { font-size: 14px }
.site-liberation .block-call-items .mini-tpl .whosaid h5 a.theme:hover { text-decoration: underline }
.site-liberation .block-call-items .mini-tpl .whosaid h3 {
    font-size: 26px;
    font-weight: normal;
    margin-bottom: 28px;
}
.site-liberation .block-call-items .mini-tpl .whosaid a.zap {
    display: block;
    position: absolute;
    width: 78px;
    height: 21px;
    background: url('http://s0.libe.com/libe/img/common/btn_shaker.gif?6340e450364b') no-repeat 0 0;
    bottom: 14px;
    right: 14px;
}
.site-liberation .block-call-items .mini-tpl .whosaid .answer { margin-top: 10px }
.site-liberation .block-call-items .mini-tpl .whosaid .answer h4 { margin-bottom: 10px }
.site-liberation .block-call-items .mini-tpl .whosaid .answer a {
    float: right;
    font-size: 14px;
}
.site-liberation .block-call-items .mini-tpl .chat .contribute { display: block }
.site-liberation .block-call-items .mini-tpl .chat .contribute a {
    display: block;
    margin-top: 14px;
}
.site-liberation .block-call-items .mini-tpl .chat .contribute form { padding: 14px 0 }
.site-liberation .block-call-items .mini-tpl .chat .contribute form fieldset { border: 0 }
.site-liberation .block-call-items .mini-tpl .chat .contribute form fieldset input[type=text] {
    float: left;
    width: 216px;
    height: 18px;
}
.site-liberation .block-call-items .mini-tpl .chat .contribute form fieldset input[type=submit] { float: right }
.site-liberation .block-call-items .mini-tpl .chat .contribute .btn { float: left }
.site-liberation .w17unit .block-call-items .mini-tpl .others,
.site-liberation .w17unit .block-call-items .mini-tpl .others ul.list-linked-items { clear: both }
.site-liberation .w17unit .block-call-items .mini-tpl .big,
.site-liberation .w17unit .block-call-items .mini-tpl .pano {
    clear: both;
    margin: 0 0 14px 0;
}
.site-liberation .w14unit .block-call-items .mini-tpl .others,
.site-liberation .w14unit .block-call-items .mini-tpl .others ul.list-linked-items { clear: both }
.site-liberation .w14unit .block-call-items .mini-tpl .big,
.site-liberation .w14unit .block-call-items .mini-tpl .pano {
    clear: both;
    margin: 0 0 14px 0;
}
.site-liberation .w14unit .block-call-items .mini-tpl .big {
    width: 392px;
    height: 261px;
}
.site-liberation .w14unit .block-call-items .mini-tpl .pano {
    width: 392px;
    height: 85px;
}
.site-liberation .w11unit .block-call-items .mini-tpl .pano {
    width: 300px;
    height: 65px;
}
.site-liberation .block-call-items .tpl-visual-square-left h5 { text-transform: none }
.site-liberation .block-call-items .tpl-visual-square-left-arround h5 { text-transform: none }
.site-liberation .block-call-items .tpl-visual-square-left h5 {
    font-family: Georgia,"Times New Roman",Times,serif;
    font-size: 13px;
    font-weight: bold;
}
.site-liberation .block-call-items .tpl-visual-square-left-arround h5 {
    font-family: Georgia,"Times New Roman",Times,serif;
    font-size: 13px;
    font-weight: bold;
}
.site-liberation .block-call-items .mini-tpl h4 {
    font-size: 16px;
    font-weight: bold;
}
.site-liberation .block-call-items .tpl-flash-news-29unit,
.site-liberation .block-call-items .tpl-flash-news-29unit:last-of-type {
    border-bottom: 1px dotted #ddd;
    margin: 0 0 14px 0;
    clear: both;
}
.site-liberation .block-call-items .tpl-flash-news-29unit .big { margin-right: 28px }
.site-liberation .block-call-items .tpl-flash-news-29unit .item .clear { clear: right }
.site-liberation .block-call-items .tpl-flash-news-29unit .others { clear: none }
.site-liberation .block-call-items .tpl-breaking-news,
.site-liberation .block-call-items .tpl-breaking-news:last-of-type {
    border-bottom: 1px dotted;
    margin: 0 0 15px 0;
    clear: both;
}
.site-liberation .block-call-items .tpl-breaking-news h3 { font-weight: bold }
.site-liberation .block-call-items .tpl-breaking-news h5 .date {
    font-weight: bold;
    padding-left: 5px;
}
.site-liberation .block-call-items .tpl-breaking-news p.more {
    text-transform: uppercase;
    color: #e20000;
}
.site-liberation .block-call-items .tpl-spotlight { padding-bottom: 14px }
.site-liberation .block-call-items .tpl-spotlight .item {
    padding: 14px;
    margin-bottom: 0;
}
.site-liberation .block-call-items .tpl-spotlight .details {
    margin-bottom: 0;
    padding-top: 7px;
    margin-top: 14px;
    border-top: 1px solid;
    font-size: 10px;
}
.site-liberation .block-call-items .tpl-spotlight .lnk-comments { margin-top: 0 }
.site-liberation .block-call-items .tpl-labo {
    border-left: 6px solid;
    margin-bottom: 0;
    padding: 14px 0 14px 14px;
}
.site-liberation .block-call-items .tpl-labo:first-of-type { padding-top: 0 }
.site-liberation .block-call-items .tpl-labo h2 { margin-bottom: 7px }
.site-liberation .block-call-items .tpl-labo p.subtitle { margin-bottom: 14px }
.site-liberation .block-call-items .tpl-labo .visual {
    width: 90px;
    height: 60px;
}
.site-liberation .block-call-items .tpl-labo .subscribe {
    clear: both;
    margin-bottom: 14px;
}
.site-liberation .block-call-items .tpl-labo .subscribe p.infos { font-weight: bold }
.site-liberation .block-call-items .tpl-labo .subscribe p.infos span { text-transform: uppercase }
.site-liberation .block-call-items .tpl-labo .subscribe p .toggle { font-size: 10px }
.site-liberation .block-call-items .tpl-labo .subscribe .sb-podcasts {
    clear: both;
    display: none;
    margin-top: 10px;
}
.site-liberation .block-call-items .tpl-labo .episode h4 {
    font-weight: bold;
    min-height: 35px;
}
.site-liberation .block-call-items .tpl-labo .episode span {
    text-transform: uppercase;
    font-size: 10px;
}
.site-liberation .block-call-items .tpl-labo .episode .pager {
    margin-top: 14px;
    border-top: 1px solid;
}
.site-liberation .block-call-items .tpl-labo .episode .pager ul { margin-top: 7px }
.site-liberation .block-call-items .tpl-labo .episode .pager .lnk-readmore {
    float: right;
    font-size: 10px;
    padding-top: 3px;
}
.site-liberation .block-call-items .tpl-labo .episode .visual {
    width: 150px;
    height: 100px;
}
.site-liberation .block-call-items .tpl-labo-spotlight {
    margin-bottom: 15px;
    padding-right: 10px;
}
.site-liberation .block-call-items .tpl-labo-spotlight:first-of-type { padding-top: 8px }
.site-liberation .block-call-items .tpl-labo-spotlight .subscribe { margin-bottom: 5px }
.site-liberation .block-call-items .tpl-labo-spotlight .subscribe .toggle {
    font-size: 10px;
    float: right;
    margin-right: 10px;
}
.site-liberation .block-call-items .tpl-labo-spotlight .subscribe p.toggle a {
    background: url('http://s0.libe.com/libe/img/common/pi_arrow-down.gif?83c2b5fdcd15') no-repeat 0 5px;
    padding-left: 15px;
}
.site-liberation .block-call-items .tpl-labo-spotlight .subscribe .sb-podcasts {
    font-size: 10px;
    float: right;
    clear: both;
    display: none;
}
.site-liberation .block-call-items .tpl-labo-podcast {
    border-left: 6px solid #b30804;
    margin-bottom: 0;
    padding: 8px 0 7px 10px;
}
.site-liberation .block-call-items .tpl-labo-podcast:first-of-type { padding-top: 0 }
.site-liberation .block-call-items .tpl-labo-podcast .emission h2 { margin-bottom: 3px }
.site-liberation .block-call-items .tpl-labo-podcast .emission p.subtitle { margin-bottom: 10px }
.site-liberation .block-call-items .tpl-labo-podcast .emission .visual {
    width: 60px;
    height: 40px;
}
.site-liberation .block-call-items .tpl-labo-podcast .emission .subscribe { clear: both }
.site-liberation .block-call-items .tpl-labo-podcast .emission .subscribe p { color: #e20000 }
.site-liberation .block-call-items .tpl-labo-podcast .emission .subscribe p.infos {
    font-weight: bold;
    color: #222;
}
.site-liberation .block-call-items .tpl-labo-podcast .emission .subscribe p.infos span { text-transform: uppercase }
.site-liberation .block-call-items .tpl-labo-podcast .emission .subscribe .sb-podcasts { margin-top: 10px }
.site-liberation .block-call-items .tpl-labo-podcast .episode h4 {
    font-weight: bold;
    min-height: 35px;
}
.site-liberation .block-call-items .tpl-labo-podcast .episode span {
    text-transform: uppercase;
    font-size: 10px;
}
.site-liberation .block-call-items .tpl-labo-podcast .episode .pager {
    margin-top: 5px;
    border-top: 1px solid;
}
.site-liberation .block-call-items .tpl-labo-podcast .episode .pager ul { margin-top: 5px }
.site-liberation .block-call-items .tpl-labo-podcast .episode .pager .lnk-readmore {
    float: right;
    font-size: 10px;
}
.site-liberation .block-call-items .tpl-search-results {
    position: relative;
    border-bottom: 0;
}
.site-liberation .block-call-items .tpl-search-results .item { margin: 0 }
.site-liberation .block-call-items .tpl-search-results .object-content {
    border-bottom: 1px dotted;
    margin-right: 142px;
    padding: 0 14px 14px;
}
.site-liberation .block-call-items .tpl-search-results:last-of-type .object-content { border-bottom: 0 }
.site-liberation .block-call-items .tpl-search-results h3 {
    font-size: 16px;
    font-weight: bold;
}
.site-liberation .block-call-items .tpl-search-results h4 {
    font-family: Verdana,sans-serif;
    font-size: 12px;
    margin-bottom: 14px;
}
.site-liberation .block-call-items .tpl-search-results h4 span { text-transform: uppercase }
.site-liberation .block-call-items .tpl-search-results h4 strong {
    text-transform: uppercase;
    font-weight: normal;
}
.site-liberation .block-call-items .tpl-search-results h4 a:hover span { text-decoration: underline }
.site-liberation .block-call-items .tpl-search-results p { margin-top: 10px }
.site-liberation .block-call-items .tpl-search-results .object-picture {
    position: absolute;
    width: 87px;
    height: 116px;
    top: 0;
    right: 14px;
}
.site-liberation .block-call-items .tpl-search-results .object-picture img {
    display: block;
    width: 87px;
    height: 116px;
}
.site-liberation .block-call-items .tpl-search-results .folder-on-demand .object-content { margin-right: 160px }
.site-liberation .block-call-items .tpl-search-results .folder-on-demand .object-picture,
.site-liberation .block-call-items .tpl-search-results .folder-on-demand .object-picture img.default {
    width: 150px;
    height: 100px;
}
.site-liberation .block-call-items .tpl-search-results .object-picture .np { position: relative }
.site-liberation .block-call-items .tpl-search-results .object-picture .np .p1,
.site-liberation .block-call-items .tpl-search-results .object-picture .np .p2 {
    position: absolute;
    background-color: #fff;
    width: 79px;
    height: 102px;
    border: 7px solid;
    border-left-width: 4px;
    border-right-width: 4px;
}
.site-liberation .block-call-items .tpl-search-results .object-picture .np a.date {
    position: absolute;
    display: block;
    width: 80px;
    top: 10px;
    padding: 2px 2px 3px 4px;
}
.site-liberation .block-call-items .tpl-search-results .object-picture .np .p1 { z-index: 2000 }
.site-liberation .block-call-items .tpl-search-results .object-picture .np .p2 { z-index: 1000 }
.site-liberation .block-call-items .tpl-search-results .object-picture .np a.date { z-index: 500 }
.site-liberation .block-call-items .tpl-no-border { border-bottom: none }
.site-liberation .block-call-items .tpl-visual-square-left .visual {
    display: block;
    float: left;
    margin: 3px 14px 0 0;
    width: 84px;
    height: 84px;
}
.site-liberation .block-call-items .tpl-visual-square-left h5,
.site-liberation .block-call-items .tpl-visual-square-left h4,
.site-liberation .block-call-items .tpl-visual-square-left h3,
.site-liberation .block-call-items .tpl-visual-square-left .subtitle { margin-left: 98px }
.site-liberation .block-call-items .tpl-visual-square-left h5 { margin-bottom: 4px }
.site-liberation .block-call-items .tpl-visual-square-left .subtitle { font-size: 11px }
.site-liberation .block-call-items .tpl-visual-square-left .chat h5,
.site-liberation .block-call-items .tpl-visual-square-left .chat .subtitle {
    font-family: Verdana,sans-serif;
    font-size: 12px;
}
.site-liberation .block-call-items .tpl-visual-square-left .chat .contribute { clear: both }
.site-liberation .block-call-items .tpl-visual-square-left .chat .contribute form {
    margin: 14px 0;
    padding: 0;
}
.site-liberation .block-call-items .tpl-visual-square-left-arround .visual {
    display: block;
    float: left;
    margin: 3px 10px 0 0;
    width: 84px;
    height: 84px;
}
.site-liberation .block-call-items .tpl-visual-square-left-arround h5 { margin-bottom: 0 }
.site-liberation .block-call-items .tpl-visual-square-left-arround p.subtitle { font-size: 11px }
body.barry-white { background: #f8f8f8 url('http://s0.libe.com/libe/img/common/bg-body-fff.gif?62ad83bcadf5') repeat-y center 0 }
body.slideshow { background-color: #333 }
body.iframe { background-color: #fff }
.ad-top,
.ad-top .megaban { }
body.slideshow .ad-top .megaban { background: #333 }
.site-liberation .ad-google .googleBanner .annonce {
    background: #f3f3f3;
    border-color: #ccc;
    color: #666;
}
.site-liberation .ad-google .googleBanner .annonce:hover { background: #fff }
.site-liberation .ad-google .googleBanner .annonce .titre { color: #e20000 }
.site-liberation .ad-google .googleBanner .annonce .texte { color: #222 }
.site-liberation .ad-google .googleBanner .annonce .url { color: #ccc }
.site-liberation a,
.site-liberation a p { color: #222 }
.site-liberation .lnk-readmore a,
.site-liberation a.lnk-readmore { color: #e20000 }
.cat-laune .bg-c { background-color: #e20000 }
.cat-laune .ft-c { color: #e20000!important }
.cat-labo .bg-c { background-color: #006a96 }
.cat-labo .ft-c { color: #006a96!important }
.cat-culture .bg-c { background-color: #e52d83 }
.cat-culture .ft-c { color: #e52d83!important }
.cat-rebonds .bg-c { background-color: #00b3e2 }
.cat-rebonds .ft-c { color: #00b3e2!important }
.cat-ecrans .bg-c { background-color: #1d9b9a }
.cat-ecrans .ft-c { color: #1d9b9a!important }
.cat-mode .bg-c { background-color: #944d93 }
.cat-mode .ft-c { color: #944d93!important }
.cat-blogs .bg-c { background-color: #324c99 }
.cat-blogs .ft-c { color: #324c99!important }
.cat-voyages .bg-c { background-color: #7baf1f }
.cat-voyages .ft-c { color: #7baf1f!important }
.cat-regions .bg-c { background-color: #f2a787 }
.cat-regions .ft-c { color: #f2a787!important }
.cat-monlibe .bg-c { background-color: #fe9900 }
.cat-monlibe .ft-c { color: #fe9900!important }
.cat-zoneabo .bg-c { background-color: #a00 }
.cat-zoneabo .ft-c { color: #a00!important }
.cat-food .bg-c { background-color: #000 }
.cat-food .ft-c { color: #000!important }
.site-liberation .hot-topics { background-color: #f8f8f8 }
.site-liberation .hot-topics h1 { border-right-color: #bbbaba }
.site-liberation .hot-topics li { background: #fff }
.site-liberation .hot-topics .event { background: #b1b1b1 }
.site-liberation #footer-liberation .hot-topics .event a { color: #fff }
#header-liberation .header-base .links .lnk2 {
    box-shadow: -9px 0 10px -11px #6c6c6c;
    -moz-box-shadow: -9px 0 10px -11px #6c6c6c;
    -webkit-box-shadow: -9px 0 10px -11px #6c6c6c;
}
#header-liberation .header-base .digitalpaper a.dl,
#header-liberation .header-base .digitalpaper a.abo { color: #fff }
#header-liberation .header-base .digitalpaper a.abo {
    background-color: #f2f2f2;
    color: #2e2e2e;
}
#header-liberation .header-base .digitalpaper a.une {
    box-shadow: 0 -1px 7px 0 #808080;
    -webkit-box-shadow: 0 -1px 7px 0 #808080;
    -moz-box-shadow: 0 -1px 7px 0 #808080;
}
#header-liberation .header-base .digitalpaper .mask {
    background: #fff;
    box-shadow: 7px -12px 8px -10px #808080;
    -webkit-box-shadow: 7px -12px 8px -10px #808080;
    -moz-box-shadow: 7px -12px 8px -10px #808080;
}
#header-liberation .header-base .nav .on .nav1 a,
#header-liberation .header-base .nav-no-js>li:hover .nav1 a,
#header-liberation .header-base .nav .nav1 a:hover { color: #fff }
#header-liberation .header-base .nav .on .nav1 a span,
#header-liberation .header-base .nav-no-js>li:hover .nav1 a span,
#header-liberation .header-base .nav .nav1 a:hover span { background-color: #fff }
#header-liberation .header-base .nav .cat-laune .nav1 .on a,
#header-liberation .header-base .nav-no-js .cat-laune:hover .nav1 a,
#header-liberation .header-base .nav .cat-laune .nav1 a:hover { background-color: #e20000 }
#header-liberation .header-base .nav .cat-labo .nav1 .on a,
#header-liberation .header-base .nav-no-js .cat-labo:hover .nav1 a,
#header-liberation .header-base .nav .cat-labo .nav1 a:hover { background-color: #006a96 }
#header-liberation .header-base .nav .cat-culture .nav1 .on a,
#header-liberation .header-base .nav-no-js .cat-culture:hover .nav1 a,
#header-liberation .header-base .nav .cat-culture .nav1 a:hover { background-color: #e52d83 }
#header-liberation .header-base .nav .cat-rebonds .nav1 .on a,
#header-liberation .header-base .nav-no-js .cat-rebonds:hover .nav1 a,
#header-liberation .header-base .nav .cat-rebonds .nav1 a:hover { background-color: #00b3e2 }
#header-liberation .header-base .nav .cat-ecrans .nav1 .on a,
#header-liberation .header-base .nav-no-js .cat-ecrans:hover .nav1 a,
#header-liberation .header-base .nav .cat-ecrans .nav1 a:hover { background-color: #1d9b9a }
#header-liberation .header-base .nav .cat-mode .nav1 .on a,
#header-liberation .header-base .nav-no-js .cat-mode:hover .nav1 a,
#header-liberation .header-base .nav .cat-mode .nav1 a:hover { background-color: #944d93 }
#header-liberation .header-base .nav .cat-blogs .nav1 .on a,
#header-liberation .header-base .nav-no-js .cat-blogs:hover .nav1 a,
#header-liberation .header-base .nav .cat-blogs .nav1 a:hover { background-color: #324c99 }
#header-liberation .header-base .nav .cat-voyages .nav1 .on a,
#header-liberation .header-base .nav-no-js .cat-voyages:hover .nav1 a,
#header-liberation .header-base .nav .cat-voyages .nav1 a:hover { background-color: #7baf1f }
#header-liberation .header-base .nav .cat-regions .nav1 .on a,
#header-liberation .header-base .nav-no-js .cat-regions:hover .nav1 a,
#header-liberation .header-base .nav .cat-regions .nav1 a:hover { background-color: #f2a787 }
#header-liberation .header-base .nav .cat-monlibe .nav1 .on a,
#header-liberation .header-base .nav-no-js .cat-monlibe:hover .nav1 a,
#header-liberation .header-base .nav .cat-monlibe .nav1 a:hover { background-color: #fe9900 }
#header-liberation .header-base .nav .cat-zoneabo .nav1 .on a,
#header-liberation .header-base .nav-no-js .cat-zoneabo:hover .nav1 a,
#header-liberation .header-base .nav .cat-zoneabo .nav1 a:hover { background-color: #a00 }
#header-liberation .header-base .nav .cat-food .nav1 .on a,
#header-liberation .header-base .nav-no-js .cat-food:hover .nav1 a,
#header-liberation .header-base .nav .cat-food .nav1 a:hover { background-color: #000 }
#header-liberation .header-base .nav .cat-laune .nav2 { border-top: 3px solid #e20000 }
#header-liberation .header-base .nav .cat-labo .nav2 { border-top: 3px solid #006a96 }
#header-liberation .header-base .nav .cat-culture .nav2 { border-top: 3px solid #e52d83 }
#header-liberation .header-base .nav .cat-rebonds .nav2 { border-top: 3px solid #00b3e2 }
#header-liberation .header-base .nav .cat-ecrans .nav2 { border-top: 3px solid #1d9b9a }
#header-liberation .header-base .nav .cat-mode .nav2 { border-top: 3px solid #944d93 }
#header-liberation .header-base .nav .cat-blogs .nav2 { border-top: 3px solid #324c99 }
#header-liberation .header-base .nav .cat-voyages .nav2 { border-top: 3px solid #7baf1f }
#header-liberation .header-base .nav .cat-regions .nav2 { border-top: 3px solid #f2a787 }
#header-liberation .header-base .nav .cat-monlibe .nav2 { border-top: 3px solid #fe9900 }
#header-liberation .header-base .nav .cat-zoneabo .nav2 { border-top: 3px solid #a00 }
#header-liberation .header-base .nav .cat-food .nav2 { border-top: 3px solid #000 }
#header-liberation .header-base .nav .cat-laune .nav2 a:hover,
#header-liberation .header-base .nav .cat-laune .nav2 .on { color: #e20000 }
#header-liberation .header-base .nav .cat-labo .nav2 a:hover,
#header-liberation .header-base .nav .cat-labo .nav2 .on { color: #006a96 }
#header-liberation .header-base .nav .cat-culture .nav2 a:hover,
#header-liberation .header-base .nav .cat-culture .nav2 .on { color: #e52d83 }
#header-liberation .header-base .nav .cat-rebonds .nav2 a:hover,
#header-liberation .header-base .nav .cat-rebonds .nav2 .on { color: #00b3e2 }
#header-liberation .header-base .nav .cat-ecrans .nav2 a:hover,
#header-liberation .header-base .nav .cat-ecrans .nav2 .on { color: #1d9b9a }
#header-liberation .header-base .nav .cat-mode .nav2 a:hover,
#header-liberation .header-base .nav .cat-mode .nav2 .on { color: #944d93 }
#header-liberation .header-base .nav .cat-blogs .nav2 a:hover,
#header-liberation .header-base .nav .cat-blogs .nav2 .on { color: #324c99 }
#header-liberation .header-base .nav .cat-voyages .nav2 a:hover,
#header-liberation .header-base .nav .cat-voyages .nav2 .on { color: #7baf1f }
#header-liberation .header-base .nav .cat-regions .nav2 a:hover,
#header-liberation .header-base .nav .cat-regions .nav2 .on { color: #f2a787 }
#header-liberation .header-base .nav .cat-monlibe .nav2 a:hover,
#header-liberation .header-base .nav .cat-monlibe .nav2 .on { color: #fe9900 }
#header-liberation .header-base .nav .cat-zoneabo .nav2 a:hover,
#header-liberation .header-base .nav .cat-zoneabo .nav2 .on { color: #a00 }
#header-liberation .header-base .nav .cat-food .nav2 a:hover,
#header-liberation .header-base .nav .cat-food .nav2 .on { color: #000 }
#header-liberation .header-simple .header { background: url('http://s0.libe.com/libe/img/common/bg-e20000.png?020f61e6035c') repeat-x 0 39px }
#header-liberation .header-simple .logo { background-color: #fff }
#header-liberation .header-simple .back { background-color: #fff }
#header-liberation .header-simple .back a {
    color: #858585;
    background: url('http://s0.libe.com/libe/img/common/ico-lnk-arrow-back-grey.png?c8d5a4458a2c') no-repeat 0 16px;
}
#header-liberation .header-annex h1 { border-bottom-color: #e20000 }
#header-liberation .header-annex h1 a { color: #000 }
#footer-liberation .abo,
#footer-liberation a { color: #818181 }
#footer-liberation .monlibe,
#footer-liberation .news,
#footer-liberation .services {
    box-shadow: -12px 0 10px -11px #ccc;
    -moz-box-shadow: -12px 0 10px -11px #ccc;
    -webkit-box-shadow: -12px 0 10px -11px #ccc;
}
#footer-liberation .monlibe h5,
#footer-liberation .news h5,
#footer-liberation .services h5 { color: #818181 }
#footer-liberation .abo h2 { color: #333 }
#footer-liberation .news ul,
#footer-liberation .services ul { border-right-color: #ccc }
#footer-liberation .references ul { border-top-color: #ccc }
#footer-liberation .references ul li {
    color: #666;
    border-right-color: #ccc;
}
#footer-liberation .references ul li a { color: #666 }
.site-liberation { color: #222 }
.site-liberation h5 .theme { color: #e20000 }
.site-liberation h5 a.theme:hover,
.site-liberation a:hover h5 .theme { color: #222 }
.site-liberation h5 .date { color: #bbbaba }
#core-liberation .text-404 p { color: #808080 }
.site-liberation .text-item p.others { border-color: #b3b3b3 }
.site-liberation .text-item p.others span { color: #e20000 }
.site-liberation .text-item p.others li a:hover { color: #222 }
#core-liberation form input[type=text],
#core-liberation form input[type=password] { border-color: #888 }
#core-liberation form input[type=text]:focus,
#core-liberation form input[type=password]:focus,
#core-liberation form input[type=file]:focus,
#core-liberation form textarea:focus,
#core-liberation form select,
#core-liberation form checkbox { outline-color: silver }
#core-liberation .error_ajax,
#core-liberation .error_ajax_form {
    background-color: #ddd;
    border-color: #9d9d9d;
}
#core-liberation .error_ajax a,
#core-liberation .error_ajax_form a {
    color: #fe9900;
    font-weight: bold;
}
#core-liberation .form-monlibe {
    background-color: #f8f8f8;
    border-top-color: #9d9d9d;
    border-bottom-color: #9d9d9d;
}
#core-liberation .form-monlibe label { color: #555 }
#core-liberation .form-monlibe input[type=text],
#core-liberation .form-monlibe input[type=password],
#core-liberation .form-monlibe textarea {
    border-color: #9d9d9d;
    background-color: #fff;
}
#core-liberation .form-monlibe-unlogged input[type=button]:hover,
#core-liberation .form-monlibe-unlogged input[type=submit]:hover,
#core-liberation .form-monlibe-unlogged input[type=reset]:hover { background: #878787 }
#core-liberation .form-monlibe .note-unlogged {
    background-color: #fff;
    border-color: #eaeaea;
}
#core-liberation .form-monlibe .note-unlogged p { color: #555 }
#core-liberation .form-monlibe .note-unlogged p.cat-monlibe { color: #222 }
#core-liberation .form-https {
    background-color: #e0e0e0;
    border-color: #888;
}
#core-liberation ul.list-itemsmost li strong { color: #e20000 }
#core-liberation ul.list-latest-news span { color: #8f909d }
#core-liberation ul.list-forums span { color: #e20000 }
#core-liberation ul.list-items span { color: #e20000 }
#core-liberation ul.list-items-mosts li strong { color: #e20000 }
#core-liberation ul.list-labo-meetings li { border-bottom-color: #c6c6c6 }
#core-liberation .list-man-of-day a { border-left-color: #e20000 }
.site-liberation .block-solid-c2 { background-color: #c6c6c6 }
.site-liberation .block-solid-c2 hr {
    border-top-color: #c6c6c6;
    border-bottom-color: #c6c6c6;
}
.site-liberation .block-solid-c2 h5 a.theme:hover { color: #fff }
.site-liberation .col-contextual .block { background-color: #e7e7e7 }
.site-liberation .col-contextual .block .block-top {
    color: #e20000;
    border-bottom-color: #222;
}
.site-liberation .col-contextual .block .block-top a { color: #e20000 }
.site-liberation .col-contextual .block .block-bottom { border-top-color: #222 }
.site-liberation .col-contextual .block .block-top .right,
.site-liberation .col-contextual .block .block-top .right a { color: #7c8280 }
.site-liberation .col-contextual .block .block-top .right a.on { color: #222 }
#core-liberation .col-contextual .block-call-items .block-top h5 { color: #e20000 }
.site-liberation .col-contextual .block-iframe .block-top>div { border-bottom-color: #222 }
.site-liberation .col-contextual .block-nobg { background: none }
.site-liberation .col-contextual .block-nobg .block-top { border-bottom-color: #e20000 }
.site-liberation .col-contextual .block-solid-c2 {
    background-color: #333;
    color: #c6c6c6;
}
.site-liberation .col-contextual .block-solid-c2 .block-top {
    color: #c6c6c6;
    border-bottom-color: #c6c6c6;
}
.site-liberation .col-contextual .block-solid-c2 a,
.site-liberation .col-contextual .block-solid-c2 a p { color: #c6c6c6 }
.site-liberation .col-part .block { background-color: #d7d7d7 }
.site-liberation .col-part .block .block-top { color: #fff }
.site-liberation .col-part .block hr { border-top-color: #ccc }
.site-liberation .block-call-items .mini-tpl { border-bottom-color: #ddd }
.site-liberation .block-call-items .mini-tpl .light { color: #bbbaba }
.site-liberation .block-call-items .mini-tpl .label { border-color: #e7e7e7 }
.site-liberation .block-call-items .mini-tpl .whosaid { background-color: #e20000 }
.site-liberation .block-call-items .mini-tpl .whosaid h5 .theme { color: #fff }
.site-liberation .block-call-items .mini-tpl .whosaid h4 { color: #fff }
.site-liberation .block-call-items .mini-tpl .whosaid h3 a { color: #fafafa }
.site-liberation .block-call-items .mini-tpl .whosaid a { color: #2e2e2e }
.site-liberation .block-call-items .list-linked-items span { color: #e20000 }
.site-liberation .block-call-items .tpl-flash-news-29col,
.site-liberation .block-call-items .tpl-flash-news-29col:last-of-type { border-bottom-color: #ddd }
.site-liberation .block-call-items .tpl-breaking-news,
.site-liberation .block-call-items .tpl-breaking-news:last-of-type { border-bottom-color: #ddd }
.site-liberation .block-call-items .tpl-spotlight .item { background-color: #cecece }
.site-liberation .block-call-items .tpl-spotlight .details { border-top-color: #aaa }
.site-liberation .block-call-items .tpl-spotlight h5 .date { color: #555 }
.site-liberation .block-call-items .tpl-labo { border-left-color: #b30804 }
.site-liberation .block-call-items .tpl-labo .subscribe p { color: #e20000 }
.site-liberation .block-call-items .tpl-labo .subscribe .infos {
    font-weight: bold;
    color: #222;
}
.site-liberation .block-call-items .tpl-labo .episode .pager { border-top-color: #000 }
.site-liberation .block-call-items .tpl-labo-spotlight {
    background-color: #303030;
    color: #fff;
}
.site-liberation .block-call-items .tpl-labo-spotlight .subtitle { color: #c6c6c6 }
.site-liberation .block-call-items .tpl-labo-spotlight .subscribe .infos { color: #fff }
.site-liberation .block-call-items .tpl-labo-spotlight .subscribe p.toggle a { color: #fff }
.site-liberation .block-call-items .tpl-labo-podcast { border-left-color: #b30804 }
.site-liberation .block-call-items .tpl-labo-podcast .emission .subscribe p { color: #e20000 }
.site-liberation .block-call-items .tpl-labo-podcast .emission .subscribe p.infos { color: #222 }
.site-liberation .block-call-items .tpl-labo-podcast .episode .pager { border-top-color: #000 }
.site-liberation .block-call-items .tpl-search-results .object-content { border-bottom-color: #ddd }
.site-liberation .block-call-items .tpl-search-results h4,
.site-liberation .block-call-items .tpl-search-results h4 a { color: #959595 }
.site-liberation .block-call-items .tpl-search-results .object-picture .np .p1,
.site-liberation .block-call-items .tpl-search-results .object-picture .np .p2 {
    background-color: #fff;
    border-color: #c8c8c8;
}
.site-liberation .block-call-items .tpl-search-results .object-picture .np a.date { background-color: #c8c8c8 }
#core-liberation .block-item .object-picture .legende { color: #838383 }
.site-liberation .block-item .object-content a:hover { color: #e20000 }
#core-liberation .block-item-locked {
    border-top-color: #c1b0bb;
    border-bottom-color: #c1b0bb;
    background: #fff;
    background: -moz-linear-gradient(top,#dbdad6 0,#fff 2%,#fff 98%,#e1e0de 100%);
    background: -webkit-gradient(linear,left top,left bottom,color-stop(0%,#dbdad6),color-stop(2%,#fff),color-stop(98%,#fff),color-stop(100%,#e1e0de));
    background: -o-linear-gradient(top,#dbdad6 0,#fff 2%,#fff 98%,#e1e0de 100%);
}
#core-liberation .block-item-locked .block-top span { background-color: #fff }
#core-liberation .block-item-locked .btn-zoneabo a:hover { color: #fff }
#core-liberation .block-item-read-more { border-color: #ddd }
#core-liberation .block-item-read-more .block-top {
    background-color: #fff;
    color: #555;
}
#core-liberation .block-item-read-more .block-content .mini-tpl hr { border-top-color: #ddd }
#core-liberation .block-comments .block-content .comment_reply,
#core-liberation .block-comments .block-content .comment_reply a,
#core-liberation .block-comments .block-content .comment_flag,
#core-liberation .block-comments .block-content .comment_flag a,
#core-liberation .block-comments .block-content .comment_post_new,
#core-liberation .block-comments .block-content .comment_post_new a { color: #878787 }
#core-liberation .block-comments .block-content .comment { border-left-color: #ddd }
#core-liberation .block-comments .block-content .comment_outer { border-color: #ddd }
#core-liberation .flat-comments .comment,
#core-liberation .block-comments .comment_level_0 { border-top-color: #878787 }
#core-liberation .flat-comments .comment>.comment_outer,
#core-liberation .block-comments .comment_level_0>.comment_outer { border-color: #878787 }
#core-liberation .block-comments .block-content .detail_comment { border-top-color: #fe9900 }
#core-liberation .block-comments .block-content .detail_comment>.comment_outer { border-color: #fe9900 }
#core-liberation .block-comments .block-content .detail_comment { border-top-color: #fe9900 }
#core-liberation .block-comments .block-content .detail_comment>.comment_outer { border-color: #fe9900 }
#core-liberation .block-comments .block-content .meta .who,
#core-liberation .block-comments .block-content .meta .who a { color: #878787 }
#core-liberation .block-comments .block-content .meta .details { color: #b2b2b2 }
#core-liberation .block-comments .block-content .meta .details a.profile { color: #b2b2b2 }
#core-liberation .block-comments .block-content .comment_selected>.comment_outer .meta .note,
#core-liberation .block-comments .block-content .comment_libe>.comment_outer .meta .note { color: #e20000 }
#core-liberation .block-comments .block-content .is_removed>.comment_outer>.meta .who a { color: #333 }
#core-liberation .block-comments .block-content .comment_reply_links .comment_flag:hover { color: #3c3c3b }
#core-liberation .block-comments .block-content .comment_reply_links .comment_reply { background-color: #878787 }
#core-liberation .block-comments .block-content .comment_reply_links .comment_reply,
#core-liberation .block-comments .block-content .comment_reply_links .comment_reply a { color: #fff }
#core-liberation .block-comments .block-content .comment_reply_links .comment_reply:hover { background: #3c3c3c }
#core-liberation .block-comments .block-content .comment_hover { background: #fdfdfd }
#core-liberation .block-comments .block-content .comment_libe>.comment_outer { background: #f8f8f8 }
#core-liberation .block-comments .block-content .is_removed>.comment_outer {
    background-color: #878787;
    color: #fff;
}
#core-liberation .block-comments .comment_replies_count { background: #F8F8F8 }
#core-liberation .block-comments .comment_replies { border-bottom-color: #ddd }
#core-liberation .block-comments .headrest-community h3 a { color: #555 }
#core-liberation .block-pager-labo { background-color: #e7e7e7 }
#core-liberation .block-pager-labo .block-bottom { border-top-color: #222 }
#core-liberation .block-podcast .block-content a { color: #666 }
#core-liberation .block-benefits .block-content ul li.b-top { border-top-color: #ddd }
#core-liberation .block-label a strong { color: #e20000 }
.site-liberation .block-np .block-top h5 .right { color: #222 }
#core-liberation .block-np .tomorrow .progress-bar { background-color: #fff }
#core-liberation .block-np .tomorrow .progress-bar .done { background-color: #ee3e30 }
#core-liberation .block-np .block-content .railway ul li img { border-color: #222 }
#core-liberation .block-np .from ul li img.visual { border-color: #878787 }
#core-liberation .block-all-forums .headrest { border-bottom-color: #ddd }
#core-liberation .block-all-forums .headrest h4 { color: #555 }
#core-liberation .block-all-forums .headrest h5 { color: #fa9900 }
#core-liberation .block-all-forums .forum { border-bottom-color: #ddd }
#core-liberation .block-all-forums .forum h5.title { color: #555 }
#core-liberation .block-all-forums .forum span.infos { color: #555 }
#core-liberation .block-all-forums .forum span.infos a { color: #555 }
#core-liberation .block-all-blogs .block-content .headrest { border-bottom-color: #ddd }
#core-liberation .block-all-blogs .headrest h4 { color: #e20000 }
#core-liberation .block-all-blogs .headrest h5 {
    color: #fff;
    background-color: #575757;
}
#core-liberation .block-all-blogs .list li .blog-libe h5 { background-color: #f5f5f5 }
#core-liberation .block-search-head form input[type=submit],
#core-liberation .block-search-results form input[type=submit] { border-color: #888 }
#core-liberation .block-search-head .pagination,
#core-liberation .block-search-results .pagination {
    background: none;
    border-color: #b7b7b7;
}
#core-liberation .block-search-head .pagination .disabled,
#core-liberation .block-search-results .pagination .disabled { color: #c8c8c8 }
#core-liberation .block-search-head .pagination .current,
#core-liberation .block-search-results .pagination .current { color: #e20000 }
#core-liberation .block-search-head .pagination .disabled,
#core-liberation .block-search-results .pagination .disabled,
#core-liberation .block-search-head .pagination .current,
#core-liberation .block-search-results .pagination .current { background-color: transparent }
#core-liberation .block-search-head p.opinion span { color: #707070 }
#core-liberation .block-search-head p.opinion a { color: #e20000 }
#core-liberation .block-search-head .advanced { border-top-color: #b7b7b7 }
#core-liberation .block-search-head .advanced .note { background-color: #e5e5e5 }
#core-liberation .block-search-head .advanced .note a.displayer { color: #87888a }
#core-liberation .block-search-head .advanced .note .links,
#core-liberation .block-search-head .advanced .note .links a { color: #87888a }
#core-liberation .block-search-head .advanced .searchform { background-color: #e5e5e5 }
#core-liberation .block-search-head .advanced .searchform .period,
#core-liberation .block-search-head .advanced .searchform .between,
#core-liberation .block-search-head .advanced .searchform .source,
#core-liberation .block-search-head .advanced .searchform .category { border-bottom-color: #fff }
#core-liberation .block-search-head .results { margin-bottom: 15px }
#core-liberation .block-search-head .results p { color: #87888a }
#core-liberation .block-search-head .results p.filters strong { color: #2e2e2e }
#core-liberation .block-search-results .block-top h2 { border-bottom-color: #e20000 }
#core-liberation .block-search-results .block-top h2,
#core-liberation .block-search-results .block-top h2 a { color: #e20000 }
#core-liberation .block-search-results .block-content .object-content { border-bottom-color: #b7b7b7 }
#core-liberation .block-search-results .block-content .category,
#core-liberation .block-search-results .block-content .folder,
#core-liberation .block-search-results .block-content .emission { background-color: #f9f9f9 }
#core-liberation .block-search-results .block-content h4,
#core-liberation .block-search-results .block-content h4 a { color: #959595 }
#core-liberation .block-search-results .block-content .object-picture .np .p1,
#core-liberation .block-search-results .block-content .object-picture .np .p2 {
    background-color: #fff;
    border-color: #c8c8c8;
}
#core-liberation .block-search-results .block-content .object-picture .np a.date { background-color: #c8c8c8 }
#core-liberation .headrest h5 { border-bottom-color: #ddd }
#core-liberation .headrest .folder { background-color: #e7e7e7 }
#core-liberation .headrest-basic-striked h5 span { background-color: #fff }
#core-liberation .headrest-community h3,
#core-liberation .headrest-community a.lnk-back,
#core-liberation .headrest-community a.lnk-com { color: #555 }
#core-liberation .headrest-community h3 span { color: #fe9900 }
#core-liberation .headrest-basic-zoneabo h4 {
    border-bottom-color: #ddd;
    color: #555;
}
#core-liberation .cartridge a.btn-comment,
#core-liberation .cartridge a.btn-back { color: #878787 }
#core-liberation .cartridge a.btn-comment:hover,
#core-liberation .cartridge a.btn-back:hover { color: #fa9900 }
#core-liberation .cartridge a.btn-comment-disabled:hover { color: #878787 }
#core-liberation .cartridge .options-tab-content {
    background-color: #fff;
    border-color: #b1b1b1;
    box-shadow: 0 2px 4px 1px #b1b1b1;
    -webkit-box-shadow: 0 2px 4px 1px #b1b1b1;
    -moz-box-shadow: 0 2px 4px 1px #b1b1b1;
}
#core-liberation .cartridge a.options-tab-label {
    background-color: #9c9c9c;
    color: #fff;
}
#core-liberation .cartridge a.options-tab-label:hover { background-color: #6c6c6c }
#core-liberation .cartridge-basic-rounded {
    border-color: #d4d4d4;
    background-color: #f8f8f8;
}
#core-liberation .cartridge-basic-rounded p,
#core-liberation .cartridge-basic-rounded p a { color: #878787 }
#core-liberation .cartridge-basic-rounded .segment { border-left-color: 1px dotted #d4d4d4 }
#core-liberation .cartridge-basic-bubble .segment,
#core-liberation .cartridge-basic-bubble .plain {
    border-color: #ddd;
    background-color: #fdfdfd;
}
#core-liberation .cartridge-basic-bubble p,
#core-liberation .cartridge-basic-bubble p a { color: #878787 }
#core-liberation .cartridge-basic-bubble .share li.spacer { background-color: #ddd }
.site-liberation .btn-basic span,
.site-liberation .btn-basic a,
.site-liberation form .btn-basic input[type=button],
.site-liberation form .btn-basic input[type=submit],
.site-liberation form .btn-basic input[type=reset] {
    background: #ccc;
    background: -moz-linear-gradient(top,#f2f2f2 0,#f2f2f2 50%,#ccc 51%,#ccc 100%);
    background: -webkit-gradient(linear,left top,left bottom,color-stop(0%,#f2f2f2),color-stop(50%,#f2f2f2),color-stop(51%,#ccc),color-stop(100%,#ccc));
    background: -webkit-linear-gradient(top,#f2f2f2 0,#f2f2f2 50%,#ccc 51%,#ccc 100%);
    background: -o-linear-gradient(top,#f2f2f2 0,#f2f2f2 50%,#ccc 51%,#ccc 100%);
    background: -ms-linear-gradient(top,#f2f2f2 0,#f2f2f2 50%,#ccc 51%,#ccc 100%);
    background: linear-gradient(top,#f2f2f2 0,#f2f2f2 50%,#ccc 51%,#ccc 100%);
    border-color: #888;
    color: #222;
}
.site-liberation .btn-laune span,
.site-liberation .btn-laune a,
.site-liberation .btn-monlibe span,
.site-liberation .btn-monlibe a,
.site-liberation .btn-zoneabo span,
.site-liberation .btn-zoneabo a { color: #fff }
.site-liberation .btn-laune a:hover,
.site-liberation .btn-monlibe a:hover,
.site-liberation .btn-zoneabo a:hover { color: #fff }
.site-liberation form .btn-laune input[type=button],
.site-liberation form .btn-laune input[type=submit],
.site-liberation form .btn-laune input[type=reset],
.site-liberation form .btn-monlibe input[type=button],
.site-liberation form .btn-monlibe input[type=submit],
.site-liberation form .btn-monlibe input[type=reset],
.site-liberation form .btn-zoneabo input[type=button],
.site-liberation form .btn-zoneabo input[type=submit],
.site-liberation form .btn-zoneabo input[type=reset] { color: #fff }
.site-liberation .btn-laune span,
.site-liberation .btn-laune a { background: #e20000 }
.site-liberation form .btn-laune input[type=button],
.site-liberation form .btn-laune input[type=submit] { background: #e20000!important }
.site-liberation form .btn-laune input[type=button]:hover,
.site-liberation form .btn-laune input[type=submit]:hover { background: #3c3c3c }
.site-liberation .btn-monlibe span,
.site-liberation .btn-monlibe a { background: #878787 }
.site-liberation form .btn-monlibe input[type=button],
.site-liberation form .btn-monlibe input[type=submit],
.site-liberation form .btn-monlibe input[type=reset] { background: #878787 }
.site-liberation form .btn-monlibe input[type=button]:hover,
.site-liberation form .btn-monlibe input[type=submit]:hover,
.site-liberation form .btn-monlibe input[type=reset]:hover { background: #3c3c3c }
.site-liberation .btn-zoneabo span,
.site-liberation .btn-zoneabo a { background: #a00 }
.site-liberation #core-liberation form .btn-zoneabo input[type=button],
.site-liberation #core-liberation form .btn-zoneabo input[type=submit] { background: #a00 }
.site-liberation #core-liberation form .btn-zoneabo input[type=button]:hover,
.site-liberation #core-liberation form .btn-zoneabo input[type=submit]:hover { background: #a00 }
.site-liberation .btn-rounded-degraded span,
.site-liberation .btn-rounded-degraded a {
    background: #e20000;
    background: -moz-linear-gradient(top,#f33333 0,#b33 100%);
    background: -webkit-gradient(linear,left top,left bottom,color-stop(0%,#f33333),color-stop(100%,#b33));
    background: -webkit-linear-gradient(top,#f33333 0,#b33 100%);
    background: -o-linear-gradient(top,#f33333 0,#b33 100%);
    background: -ms-linear-gradient(top,#f33333 0,#b33 100%);
    background: linear-gradient(top,#f33333 0,#b33 100%);
    color: #fff;
}
.site-liberation .btn-rounded-degraded span:hover,
.site-liberation .btn-rounded-degraded a:hover {
    background: #e20000;
    background: -moz-linear-gradient(top,#b33 0,#f33333 100%);
    background: -webkit-gradient(linear,left top,left bottom,color-stop(0%,#b33),color-stop(100%,#f33333));
    background: -webkit-linear-gradient(top,#b33 0,#f33333 100%);
    background: -o-linear-gradient(top,#b33 0,#f33333 100%);
    background: -ms-linear-gradient(top,#b33 0,#f33333 100%);
    background: linear-gradient(top,#b33 0,#f33333 100%);
    color: #fff;
}
.site-liberation form .btn-rounded-degraded input[type=button],
.site-liberation form .btn-rounded-degraded input[type=submit] {
    background: #e20000;
    background: -moz-linear-gradient(top,#f33333 0,#b33 100%);
    background: -webkit-gradient(linear,left top,left bottom,color-stop(0%,#f33333),color-stop(100%,#b33));
    background: -webkit-linear-gradient(top,#f33333 0,#b33 100%);
    background: -o-linear-gradient(top,#f33333 0,#b33 100%);
    background: -ms-linear-gradient(top,#f33333 0,#b33 100%);
    background: linear-gradient(top,#f33333 0,#b33 100%);
    color: #fff;
}
.site-liberation form .btn-rounded-degraded input[type=button]:hover,
.site-liberation form .btn-rounded-degraded input[type=submit]:hover,
.site-liberation form .btn-rounded-degraded input[type=button]:focus,
.site-liberation form .btn-rounded-degraded input[type=submit]:focus {
    background: #e20000;
    background: -moz-linear-gradient(top,#b33 0,#f33333 100%);
    background: -webkit-gradient(linear,left top,left bottom,color-stop(0%,#b33),color-stop(100%,#f33333));
    background: -webkit-linear-gradient(top,#b33 0,#f33333 100%);
    background: -o-linear-gradient(top,#b33 0,#f33333 100%);
    background: -ms-linear-gradient(top,#b33 0,#f33333 100%);
    background: linear-gradient(top,#b33 0,#f33333 100%);
    color: #fff;
}
.site-liberation .btn-read-digitalpaper { border-color: #878787 }
.site-liberation .btn-read-digitalpaper span,
.site-liberation .btn-read-digitalpaper a { color: #2e2e2e }
#core-liberation .pagination {
    background-color: #e7e7e7;
    border-top-color: #b7b7b7;
    border-bottom-color: #b7b7b7;
}
#core-liberation .pagination .disabled {
    background-color: transparent;
    color: #c8c8c8;
}
#core-liberation .pagination .current {
    background-color: transparent;
    color: #e20000;
}
.site-liberation .bg-sprites-icons .icon {
    display: block;
    background-image: url('http://s0.libe.com/libe/img/common/_sprites_icons/icons.png?9914d0d70a49');
    background-repeat: no-repeat;
}
.site-liberation .bg-sprites-icons .folder1,
.site-liberation .bg-sprites-icons .folder1-black,
.site-liberation .bg-sprites-icons .folder1-monlibe {
    width: 19px;
    height: 15px;
}
.site-liberation .bg-sprites-icons .folder1 { background-position: -110px -84px }
.site-liberation .bg-sprites-icons .folder1-black { background-position: -152px -84px }
.site-liberation .bg-sprites-icons .folder1-monlibe { background-position: -131px -84px }
.site-liberation .cat-monlibe .bg-sprites-icons .on .folder1,
.site-liberation .cat-monlibe .bg-sprites-icons a:hover .folder1 { background-position: -131px -84px }
.site-liberation .bg-sprites-icons .close1,
.site-liberation .bg-sprites-icons .close1-black,
.site-liberation .bg-sprites-icons .close1-monlibe {
    width: 15px;
    height: 15px;
}
.site-liberation .bg-sprites-icons .close1 { background-position: -59px -99px }
.site-liberation .bg-sprites-icons .close1-black { background-position: -93px -99px }
.site-liberation .bg-sprites-icons .close1-monlibe { background-position: -76px -99px }
.site-liberation .cat-monlibe .bg-sprites-icons .on .close1,
.site-liberation .cat-monlibe .bg-sprites-icons a:hover .close1 { background-position: -76px -99px }
.site-liberation .bg-sprites-icons .edit1,
.site-liberation .bg-sprites-icons .edit1-black,
.site-liberation .bg-sprites-icons .edit1-monlibe {
    width: 15px;
    height: 15px;
}
.site-liberation .bg-sprites-icons .edit1 { background-position: -110px -101px }
.site-liberation .bg-sprites-icons .edit1-black { background-position: -145px -101px }
.site-liberation .bg-sprites-icons .edit1-monlibe { background-position: -128px -101px }
.site-liberation .cat-monlibe .bg-sprites-icons .on .edit1,
.site-liberation .cat-monlibe .bg-sprites-icons a:hover .edit1 { background-position: -128px -101px }
.site-liberation .bg-sprites-icons .heart1,
.site-liberation .bg-sprites-icons .heart1-laune,
.site-liberation .bg-sprites-icons .heart1-black {
    width: 12px;
    height: 12px;
}
.site-liberation .bg-sprites-icons .heart1-laune { background-position: -82px -84px }
.site-liberation .bg-sprites-icons .heart1-black { background-position: -96px -84px }
.site-liberation .cat-laune .bg-sprites-icons .heart1 { background-position: -96px -84px }
.site-liberation .cat-laune .bg-sprites-icons .on .heart1,
.site-liberation .cat-laune .bg-sprites-icons a:hover .heart1 { background-position: -82px -84px }
.site-liberation .toolbox { border-color: #d7d7d7 }
.site-liberation .toolbox li.spacer span { background-color: #d7d7d7 }
.site-liberation .toolbox .txt-min,
.site-liberation .toolbox .txt-plus,
.site-liberation .toolbox .txt-reset,
.site-liberation .toolbox .comment,
.site-liberation .toolbox .facebook,
.site-liberation .toolbox .twitter { color: #818181 }
.site-liberation .toolbox .txt-min:hover,
.site-liberation .toolbox .txt-plus:hover,
.site-liberation .toolbox .txt-reset:hover,
.site-liberation .toolbox .comment:hover { color: #000 }
.site-liberation .toolbox li a span { background: url('http://s0.libe.com/libe/img/common/_sprites_icons/icons.png?9914d0d70a49') no-repeat }
.site-liberation .toolbox li a.print span { background-position: -76px -118px }
.site-liberation .toolbox li a.print:hover span { background-position: -94px -118px }
.site-liberation .toolbox li a.favorite span { background-position: -22px -120px }
.site-liberation .toolbox li a.favorite:hover span { background-position: -44px -120px }
.site-liberation .toolbox li a.comment span { background-position: -189px -84px }
.site-liberation .toolbox li a.comment:hover span { background-position: -205px -84px }
.site-liberation .toolbox li a.mail span { background-position: -89px 0 }
.site-liberation .toolbox li a.mail:hover span { background-position: -89px -16px }
.site-liberation .toolbox li a.facebook span { background: url('http://s0.libe.com/libe/img/common/_sprites_icons/icons_share.png?edeb5617b880') no-repeat -74px 0 }
.site-liberation .toolbox li a.twitter span { background: url('http://s0.libe.com/libe/img/common/_sprites_icons/icons_share.png?edeb5617b880') no-repeat -74px -14px }
.site-liberation .toolbox li a.facebook,
.site-liberation .toolbox li a.twitter {
    background-color: #f7f7f7;
    border-color: #d7d7d7;
}
.site-liberation .toolbox li a.facebook:hover,
.site-liberation .toolbox li a.twitter:hover {
    background-color: #818181;
    color: #F7F7F7;
}
.site-liberation .toolbox li.btn-comment,
.site-liberation .toolbox li.abo-1-euro { background: #f8f8f8 }
.site-liberation .toolbox li.btn-comment a { color: #808080 }
.site-liberation .toolbox li.btn-comment a:hover {
    color: #f8f8f8;
    background: #808080;
    text-decoration: none;
}
.site-liberation .toolbox li.abo-1-euro a span { background: none }
.site-liberation .toolbox li.fold-options,
.site-liberation .toolbox li.fold-options ul { background: #f8f8f8 }
.site-liberation .toolbox li.fold-options+li.fold-options,
.site-liberation .toolbox li.fold-options ul { border-color: #d7d7d7 }
.site-liberation .toolbox li.fold-options>a { color: #818181 }
#bar-liberation {
    border-bottom-color: #dadada;
    background-color: #fff;
    box-shadow: 0 1px 2px 0 #E2E2E2;
    -webkit-box-shadow: 0 1px 2px 0 #E2E2E2;
    -moz-box-shadow: 0 1px 2px 0 #E2E2E2;
}
#bar-liberation,
#bar-liberation a { color: #3c3c3c }
#bar-liberation .content .close,
#bar-liberation .content .open,
#bar-liberation .content .login,
#bar-liberation .content .personal-options,
#bar-liberation .content .mail-box,
#bar-liberation .content .activities-stream,
#bar-liberation .content .other {
    background: #fff;
    border-left-color: #dadada;
    border-right-color: #dadada;
    border-bottom-color: #dadada;
}
#bar-liberation .content ul.list li { border-bottom-color: #dadada }
#core-liberation .block-activities .block-content ul li,
#core-liberation .block-activities .block-content ul li a,
#bar-liberation .content ul.list li,
#bar-liberation .content ul.list li a { color: #222 }
#core-liberation .block-activities .block-content ul li span,
#bar-liberation .content ul.list li span { color: #878787 }
#bar-liberation .content .open a .arrow {
    border-left-color: 1px solid #dadada;
    border-right-color: 1px solid #dadada;
}
#bar-liberation .content .login a.subscribe {
    background-color: #656565;
    color: #fff;
}
#bar-liberation .content .login a.subscribe:hover { background-color: #3c3c3c }
#bar-liberation #login-box-content {
    background-color: #fff;
    border-left-color: #dadada;
    border-right-color: #dadada;
    border-bottom-color: #dadada;
    box-shadow: 0 1px 1px 0 #E2E2E2;
    -webkit-box-shadow: 0 1px 1px 0 #E2E2E2;
    -moz-box-shadow: 0 1px 1px 0 #E2E2E2;
}
#bar-liberation #personal-options-content {
    background-color: #fff;
    border-left-color: 1px solid #dadada;
    border-right-color: 1px solid #dadada;
    border-bottom-color: 1px solid #dadada;
    box-shadow: 0 1px 1px 0 #E2E2E2;
    -webkit-box-shadow: 0 1px 1px 0 #E2E2E2;
    -moz-box-shadow: 0 1px 1px 0 #E2E2E2;
}
#bar-liberation #personal-options-content ul.subscription strong,
#bar-liberation #personal-options-content ul.subscription li.subscribe,
#bar-liberation #personal-options-content ul.subscription li.subscribe a { color: #a40000 }
#bar-liberation #personal-options-content ul li { color: #878787 }
#bar-liberation #personal-options-content ul li a,
#bar-liberation #personal-options-content ul li strong { color: #3c3c3c }
#bar-liberation #personal-options-content ul.inactive li { color: #b2b2b2 }
#bar-liberation .content .mail-box { border-bottom-color: #dadada }
#bar-liberation .content .activities-stream { border-bottom-color: #dadada }
#bar-liberation .content .unfolded {
    box-shadow: 0 1px 1px 0 #E2E2E2;
    -webkit-box-shadow: 0 1px 2px 0 #E2E2E2;
    -moz-box-shadow: 0 1px 2px 0 #E2E2E2;
}
#bar-liberation .content .other a span { color: #a40000 }
#page-404 .error { border-right-color: #ddd }
#page-404 form { border-color: #808080 }
#page-404 form input[type=text] { color: #808080 }
#page-mailfriend .content a { color: #e20000 }
#page-mailfriend .content p.note { color: #999 }
#page-paywall .content a.close strong { color: #666 }
#page-paywall .content .video h5 {
    border-top-color: #ccc;
    border-bottom-color: #ccc;
    color: #222;
}
#page-paywall .content .video h4 span { background-color: #fff }
#page-paywall .content .arguments .arg h4,
#page-paywall .content .arguments .arg .price { color: #222 }
#page-paywall .content .arguments .arg .price .total { color: #999 }
#page-paywall .content .banner-degraded {
    border-top-color: #c1b0bb;
    border-bottom-color: #c1b0bb;
    background: #fff;
    background: -moz-linear-gradient(top,#dbdad6 0,#fff 10%,#fff 90%,#e1e0de 100%);
    background: -webkit-gradient(linear,left top,left bottom,color-stop(0%,#dbdad6),color-stop(10%,#fff),color-stop(90%,#fff),color-stop(100%,#e1e0de));
    background: -webkit-linear-gradient(top,#dbdad6 0,#fff 10%,#fff 90%,#e1e0de 100%);
    background: -o-linear-gradient(top,#dbdad6 0,#fff 10%,#fff 90%,#e1e0de 100%);
    background: -ms-linear-gradient(top,#dbdad6 0,#fff 10%,#fff 90%,#e1e0de 100%);
    background: linear-gradient(top,#dbdad6 0,#fff 10%,#fff 90%,#e1e0de 100%);
    color: #777;
}
#page-paywall .content .banner-degraded a { color: #777 }
#page-paywall .content .form-login form p input[type=text],
#page-paywall .content .form-login form p input[type=password] { border-color: #888 }
#page-paywall .content .form-login form p input[type=text]:focus,
#page-paywall .content .form-login form p input[type=password]:focus { border-color: silver }
#DOMWindow { }
.autopromo-7days {
    border: 2px solid #ddd;
    clear: both;
}
.autopromo-7days .btn-laune,
.autopromo-7days .btn-zoneabo {
    float: right;
    width: 90px;
    margin: 5px 5px 5px 10px;
    text-align: center;
}
.autopromo-7days img.visual {
    display: block;
    float: left;
    width: 40px;
    margin: 5px 10px;
}
.autopromo-7days p { padding: 2px }
.autopromo-7days .hp span.ft-c { text-transform: uppercase }
.site-liberation .block-partnership .block-content .autopromo-7days .hp p,
.site-liberation .block-promo .block-content .autopromo-7days .hp p {
    margin: 0;
    padding: 3px 0 3px 6px;
    font-size: 10px;
}
.autopromo-libe1euro {
    background: #fafafa;
    border: 1px solid #ddd;
}
.autopromo-libe1euro .btn-laune,
.autopromo-libe1euro .btn-zoneabo {
    float: right;
    width: 90px;
    margin: 5px 5px 5px 10px;
    text-align: center;
}
.autopromo-libe1euro img.visual {
    display: block;
    float: left;
    width: 40px;
    margin: 5px 10px;
}
.site-liberation .autopromo-libe1euro p {
    padding: 3px;
    font-size: 11px;
}
.site-liberation .autopromo-libe1euro a { display: block }
.autopromo-libe1euro .hp span.ft-c { text-transform: uppercase }
.site-liberation .block-partnership .autopromo-libe1euro .hp p,
.site-liberation .block-promo .autopromo-libe1euro .hp p {
    margin: 0;
    padding: 3px 0 3px 6px;
    font-size: 10px;
}
.site-liberation .autopromo-35unit {
    margin-top: 28px;
    position: relative;
}
.site-liberation .autopromo-35unit img.visual {
    width: 140px;
    margin: 5px 28px;
    position: relative;
    top: -28px;
}
.site-liberation .autopromo-35unit h2,
.site-liberation .autopromo-35unit p {
    display: inline-block;
    font-family: Georgia,"Times New Roman",Times,serif;
    margin-left: 28px;
}
.site-liberation .autopromo-35unit div.btn-rounded-degraded {
    position: absolute;
    top: 13px;
    right: 28px;
}
.site-liberation .autopromo-35unit h2 span { display: block }
.site-liberation .autopromo-35unit p { font-size: 16px }
.site-liberation .autopromo-35unit p+p { margin-left: 0 }
.site-liberation .autopromo-35unit h2 {
    line-height: 20px;
    font-weight: normal;
}
.site-liberation .autopromo-libe1euro .digit {
    font-size: 68px;
    line-height: 40px;
}
.site-liberation .autopromo-libe1euro .currency { font-size: 40px }
html.js body.dummy div#mainContent div#core-liberation div.col9 div.block div.block-content div.favorites-articles div.col-left div.block-call-items div.block-content div.mini-tpl div.article div.object-content {
    min-height: 0;
    margin-right: 0;
    padding: 0;
}
#mainContent #core-liberation .favorites-folders .object-content { margin-right: 0 }
#mainContent #core-liberation .favorites-folders .block-content .cartridge { width: 210px }
html.js body.dummy div#mainContent div#core-liberation div.col9 div.block div.block-content div.favorites-folders div.block-call-items div.block-content div.mini-tpl div.folder-on-demand div.object-content { min-height: 0 }
html.js body.dummy div#mainContent div#core-liberation div.col9 div.block div.block-content div.favorites-frontpages div.col-left div.cartridge { width: 388px }
html.js body.dummy div#mainContent div#core-liberation div.col9 div.block div.block-content div.favorites-folders div.block-call-items div.block-content div.mini-tpl div.cartridge {
    margin-left: 0;
    width: 129px;
}
html.js body.dummy div#mainContent div#core-liberation div.col7 div.block-call-items div.block-content div.mini-tpl div.folder-on-demand div.object-content {
    margin-right: 0;
    min-height: 0;
    border-bottom: 0;
}
html.js body.dummy div#mainContent div#core-liberation div.col7 div.block-call-items div.block-content div.mini-tpl div.folder-on-demand { border-bottom: 1px solid #E7E7E7 }